@@ -2,13 +2,14 @@
 
 namespace Doctrine\DBAL\Platforms;
 
-use Doctrine\DBAL\DBALException;
+use Doctrine\DBAL\Exception;
 use Doctrine\DBAL\Schema\ColumnDiff;
 use Doctrine\DBAL\Schema\Identifier;
 use Doctrine\DBAL\Schema\Index;
 use Doctrine\DBAL\Schema\TableDiff;
 use Doctrine\DBAL\Types\Type;
 use Doctrine\DBAL\Types\Types;
+
 use function array_merge;
 use function count;
 use function current;
@@ -22,10 +23,7 @@ use function strtoupper;
 
 class DB2Platform extends AbstractPlatform
 {
-    /**
-     * {@inheritdoc}
-     */
-    public function getCharMaxLength() : int
+    public function getCharMaxLength(): int
     {
         return 254;
     }
@@ -49,22 +47,22 @@ class DB2Platform extends AbstractPlatform
     /**
      * {@inheritDoc}
      */
-    public function getVarcharTypeDeclarationSQL(array $field)
+    public function getVarcharTypeDeclarationSQL(array $column)
     {
         // for IBM DB2, the CHAR max length is less than VARCHAR default length
-        if (! isset($field['length']) && ! empty($field['fixed'])) {
-            $field['length'] = $this->getCharMaxLength();
+        if (! isset($column['length']) && ! empty($column['fixed'])) {
+            $column['length'] = $this->getCharMaxLength();
         }
 
-        return parent::getVarcharTypeDeclarationSQL($field);
+        return parent::getVarcharTypeDeclarationSQL($column);
     }
 
     /**
      * {@inheritDoc}
      */
-    public function getBlobTypeDeclarationSQL(array $field)
+    public function getBlobTypeDeclarationSQL(array $column)
     {
-        // todo blob(n) with $field['length'];
+        // todo blob(n) with $column['length'];
         return 'BLOB(1M)';
     }
 
@@ -126,9 +124,9 @@ class DB2Platform extends AbstractPlatform
     /**
      * {@inheritDoc}
      */
-    public function getClobTypeDeclarationSQL(array $field)
+    public function getClobTypeDeclarationSQL(array $column)
     {
-        // todo clob(n) with $field['length'];
+        // todo clob(n) with $column['length'];
         return 'CLOB(1M)';
     }
 
@@ -143,7 +141,7 @@ class DB2Platform extends AbstractPlatform
     /**
      * {@inheritDoc}
      */
-    public function getBooleanTypeDeclarationSQL(array $columnDef)
+    public function getBooleanTypeDeclarationSQL(array $column)
     {
         return 'SMALLINT';
     }
@@ -151,34 +149,34 @@ class DB2Platform extends AbstractPlatform
     /**
      * {@inheritDoc}
      */
-    public function getIntegerTypeDeclarationSQL(array $columnDef)
+    public function getIntegerTypeDeclarationSQL(array $column)
     {
-        return 'INTEGER' . $this->_getCommonIntegerTypeDeclarationSQL($columnDef);
+        return 'INTEGER' . $this->_getCommonIntegerTypeDeclarationSQL($column);
     }
 
     /**
      * {@inheritDoc}
      */
-    public function getBigIntTypeDeclarationSQL(array $columnDef)
+    public function getBigIntTypeDeclarationSQL(array $column)
     {
-        return 'BIGINT' . $this->_getCommonIntegerTypeDeclarationSQL($columnDef);
+        return 'BIGINT' . $this->_getCommonIntegerTypeDeclarationSQL($column);
     }
 
     /**
      * {@inheritDoc}
      */
-    public function getSmallIntTypeDeclarationSQL(array $columnDef)
+    public function getSmallIntTypeDeclarationSQL(array $column)
     {
-        return 'SMALLINT' . $this->_getCommonIntegerTypeDeclarationSQL($columnDef);
+        return 'SMALLINT' . $this->_getCommonIntegerTypeDeclarationSQL($column);
     }
 
     /**
      * {@inheritDoc}
      */
-    protected function _getCommonIntegerTypeDeclarationSQL(array $columnDef)
+    protected function _getCommonIntegerTypeDeclarationSQL(array $column)
     {
         $autoinc = '';
-        if (! empty($columnDef['autoincrement'])) {
+        if (! empty($column['autoincrement'])) {
             $autoinc = ' GENERATED BY DEFAULT AS IDENTITY';
         }
 
@@ -232,9 +230,9 @@ class DB2Platform extends AbstractPlatform
     /**
      * {@inheritDoc}
      */
-    public function getDateTimeTypeDeclarationSQL(array $fieldDeclaration)
+    public function getDateTimeTypeDeclarationSQL(array $column)
     {
-        if (isset($fieldDeclaration['version']) && $fieldDeclaration['version'] === true) {
+        if (isset($column['version']) && $column['version'] === true) {
             return 'TIMESTAMP(0) WITH DEFAULT';
         }
 
@@ -244,7 +242,7 @@ class DB2Platform extends AbstractPlatform
     /**
      * {@inheritDoc}
      */
-    public function getDateTypeDeclarationSQL(array $fieldDeclaration)
+    public function getDateTypeDeclarationSQL(array $column)
     {
         return 'DATE';
     }
@@ -252,7 +250,7 @@ class DB2Platform extends AbstractPlatform
     /**
      * {@inheritDoc}
      */
-    public function getTimeTypeDeclarationSQL(array $fieldDeclaration)
+    public function getTimeTypeDeclarationSQL(array $column)
     {
         return 'TIME';
     }
@@ -342,7 +340,7 @@ class DB2Platform extends AbstractPlatform
     /**
      * {@inheritDoc}
      */
-    public function getListTableIndexesSQL($table, $currentDatabase = null)
+    public function getListTableIndexesSQL($table, $database = null)
     {
         $table = $this->quoteStringLiteral($table);
 
@@ -483,24 +481,25 @@ class DB2Platform extends AbstractPlatform
     public function getIndexDeclarationSQL($name, Index $index)
     {
         // Index declaration in statements like CREATE TABLE is not supported.
-        throw DBALException::notSupported(__METHOD__);
+        throw Exception::notSupported(__METHOD__);
     }
 
     /**
      * {@inheritDoc}
      */
-    protected function _getCreateTableSQL($tableName, array $columns, array $options = [])
+    protected function _getCreateTableSQL($name, array $columns, array $options = [])
     {
         $indexes = [];
         if (isset($options['indexes'])) {
             $indexes = $options['indexes'];
         }
+
         $options['indexes'] = [];
 
-        $sqls = parent::_getCreateTableSQL($tableName, $columns, $options);
+        $sqls = parent::_getCreateTableSQL($name, $columns, $options);
 
         foreach ($indexes as $definition) {
-            $sqls[] = $this->getCreateIndexSQL($definition, $tableName);
+            $sqls[] = $this->getCreateIndexSQL($definition, $name);
         }
 
         return $sqls;
@@ -525,7 +524,8 @@ class DB2Platform extends AbstractPlatform
             $queryPart = 'ADD COLUMN ' . $this->getColumnDeclarationSQL($column->getQuotedName($this), $columnDef);
 
             // Adding non-nullable columns to a table requires a default value to be specified.
-            if (! empty($columnDef['notnull']) &&
+            if (
+                ! empty($columnDef['notnull']) &&
                 ! isset($columnDef['default']) &&
                 empty($columnDef['autoincrement'])
             ) {
@@ -628,8 +628,12 @@ class DB2Platform extends AbstractPlatform
      * @param string[]   $sql        The sequence of table alteration statements to fill.
      * @param mixed[]    $queryParts The sequence of column alteration clauses to fill.
      */
-    private function gatherAlterColumnSQL(Identifier $table, ColumnDiff $columnDiff, array &$sql, array &$queryParts)
-    {
+    private function gatherAlterColumnSQL(
+        Identifier $table,
+        ColumnDiff $columnDiff,
+        array &$sql,
+        array &$queryParts
+    ): void {
         $alterColumnClauses = $this->getAlterColumnClausesSQL($columnDiff);
 
         if (empty($alterColumnClauses)) {
@@ -670,7 +674,8 @@ class DB2Platform extends AbstractPlatform
 
         $clauses = [];
 
-        if ($columnDiff->hasChanged('type') ||
+        if (
+            $columnDiff->hasChanged('type') ||
             $columnDiff->hasChanged('length') ||
             $columnDiff->hasChanged('precision') ||
             $columnDiff->hasChanged('scale') ||
@@ -708,21 +713,23 @@ class DB2Platform extends AbstractPlatform
 
         foreach ($diff->removedIndexes as $remKey => $remIndex) {
             foreach ($diff->addedIndexes as $addKey => $addIndex) {
-                if ($remIndex->getColumns() === $addIndex->getColumns()) {
-                    if ($remIndex->isPrimary()) {
-                        $sql[] = 'ALTER TABLE ' . $table . ' DROP PRIMARY KEY';
-                    } elseif ($remIndex->isUnique()) {
-                        $sql[] = 'ALTER TABLE ' . $table . ' DROP UNIQUE ' . $remIndex->getQuotedName($this);
-                    } else {
-                        $sql[] = $this->getDropIndexSQL($remIndex, $table);
-                    }
-
-                    $sql[] = $this->getCreateIndexSQL($addIndex, $table);
-
-                    unset($diff->removedIndexes[$remKey], $diff->addedIndexes[$addKey]);
-
-                    break;
+                if ($remIndex->getColumns() !== $addIndex->getColumns()) {
+                    continue;
                 }
+
+                if ($remIndex->isPrimary()) {
+                    $sql[] = 'ALTER TABLE ' . $table . ' DROP PRIMARY KEY';
+                } elseif ($remIndex->isUnique()) {
+                    $sql[] = 'ALTER TABLE ' . $table . ' DROP UNIQUE ' . $remIndex->getQuotedName($this);
+                } else {
+                    $sql[] = $this->getDropIndexSQL($remIndex, $table);
+                }
+
+                $sql[] = $this->getCreateIndexSQL($addIndex, $table);
+
+                unset($diff->removedIndexes[$remKey], $diff->addedIndexes[$addKey]);
+
+                break;
             }
         }
 
@@ -747,27 +754,27 @@ class DB2Platform extends AbstractPlatform
     /**
      * {@inheritDoc}
      */
-    public function getDefaultValueDeclarationSQL($field)
+    public function getDefaultValueDeclarationSQL($column)
     {
-        if (! empty($field['autoincrement'])) {
+        if (! empty($column['autoincrement'])) {
             return '';
         }
 
-        if (isset($field['version']) && $field['version']) {
-            if ((string) $field['type'] !== 'DateTime') {
-                $field['default'] = '1';
+        if (isset($column['version']) && $column['version']) {
+            if ((string) $column['type'] !== 'DateTime') {
+                $column['default'] = '1';
             }
         }
 
-        return parent::getDefaultValueDeclarationSQL($field);
+        return parent::getDefaultValueDeclarationSQL($column);
     }
 
     /**
      * {@inheritDoc}
      */
-    public function getEmptyIdentityInsertSQL($tableName, $identifierColumnName)
+    public function getEmptyIdentityInsertSQL($quotedTableName, $quotedIdentifierColumnName)
     {
-        return 'INSERT INTO ' . $tableName . ' (' . $identifierColumnName . ') VALUES (DEFAULT)';
+        return 'INSERT INTO ' . $quotedTableName . ' (' . $quotedIdentifierColumnName . ') VALUES (DEFAULT)';
     }
 
     /**
@@ -828,13 +835,13 @@ class DB2Platform extends AbstractPlatform
     /**
      * {@inheritDoc}
      */
-    public function getSubstringExpression($value, $from, $length = null)
+    public function getSubstringExpression($string, $start, $length = null)
     {
         if ($length === null) {
-            return 'SUBSTR(' . $value . ', ' . $from . ')';
+            return 'SUBSTR(' . $string . ', ' . $start . ')';
         }
 
-        return 'SUBSTR(' . $value . ', ' . $from . ', ' . $length . ')';
+        return 'SUBSTR(' . $string . ', ' . $start . ', ' . $length . ')';
     }
 
     /**
@@ -857,6 +864,8 @@ class DB2Platform extends AbstractPlatform
      * {@inheritDoc}
      *
      * DB2 returns all column names in SQL result sets in uppercase.
+     *
+     * @deprecated
      */
     public function getSQLResultCasing($column)
     {
@@ -901,7 +910,7 @@ class DB2Platform extends AbstractPlatform
         return Keywords\DB2Keywords::class;
     }
 
-    public function getListTableCommentsSQL(string $table) : string
+    public function getListTableCommentsSQL(string $table): string
     {
         return sprintf(
             <<<'SQL'
