@@ -2,7 +2,7 @@
 
 namespace Doctrine\DBAL\Platforms;
 
-use Doctrine\DBAL\DBALException;
+use Doctrine\DBAL\Exception;
 use Doctrine\DBAL\LockMode;
 use Doctrine\DBAL\Schema\Column;
 use Doctrine\DBAL\Schema\ColumnDiff;
@@ -14,9 +14,11 @@ use Doctrine\DBAL\Schema\Table;
 use Doctrine\DBAL\Schema\TableDiff;
 use Doctrine\DBAL\TransactionIsolationLevel;
 use InvalidArgumentException;
+
 use function array_merge;
 use function array_unique;
 use function array_values;
+use function assert;
 use function count;
 use function explode;
 use function func_get_args;
@@ -33,6 +35,8 @@ use function substr;
 /**
  * The SQLAnywherePlatform provides the behavior, features and SQL dialect of the
  * SAP Sybase SQL Anywhere 10 database platform.
+ *
+ * @deprecated Use SQLAnywhere 16 or newer
  */
 class SQLAnywherePlatform extends AbstractPlatform
 {
@@ -48,7 +52,7 @@ class SQLAnywherePlatform extends AbstractPlatform
     {
         switch (true) {
             case $lockMode === LockMode::NONE:
-                return $fromClause . ' WITH (NOLOCK)';
+                return $fromClause;
 
             case $lockMode === LockMode::PESSIMISTIC_READ:
                 return $fromClause . ' WITH (UPDLOCK)';
@@ -296,11 +300,11 @@ class SQLAnywherePlatform extends AbstractPlatform
     /**
      * {@inheritdoc}
      */
-    public function getBigIntTypeDeclarationSQL(array $columnDef)
+    public function getBigIntTypeDeclarationSQL(array $column)
     {
-        $columnDef['integer_type'] = 'BIGINT';
+        $column['integer_type'] = 'BIGINT';
 
-        return $this->_getCommonIntegerTypeDeclarationSQL($columnDef);
+        return $this->_getCommonIntegerTypeDeclarationSQL($column);
     }
 
     /**
@@ -322,7 +326,7 @@ class SQLAnywherePlatform extends AbstractPlatform
     /**
      * {@inheritdoc}
      */
-    public function getBlobTypeDeclarationSQL(array $field)
+    public function getBlobTypeDeclarationSQL(array $column)
     {
         return 'LONG BINARY';
     }
@@ -335,9 +339,9 @@ class SQLAnywherePlatform extends AbstractPlatform
      * Otherwise by just omitting the NOT NULL clause,
      * SQL Anywhere will declare them NOT NULL nonetheless.
      */
-    public function getBooleanTypeDeclarationSQL(array $columnDef)
+    public function getBooleanTypeDeclarationSQL(array $column)
     {
-        $nullClause = isset($columnDef['notnull']) && (bool) $columnDef['notnull'] === false ? ' NULL' : '';
+        $nullClause = isset($column['notnull']) && (bool) $column['notnull'] === false ? ' NULL' : '';
 
         return 'BIT' . $nullClause;
     }
@@ -345,7 +349,7 @@ class SQLAnywherePlatform extends AbstractPlatform
     /**
      * {@inheritdoc}
      */
-    public function getClobTypeDeclarationSQL(array $field)
+    public function getClobTypeDeclarationSQL(array $column)
     {
         return 'TEXT';
     }
@@ -497,7 +501,7 @@ class SQLAnywherePlatform extends AbstractPlatform
     /**
      * {@inheritdoc}
      */
-    public function getDateTimeTypeDeclarationSQL(array $fieldDeclaration)
+    public function getDateTimeTypeDeclarationSQL(array $column)
     {
         return 'DATETIME';
     }
@@ -513,7 +517,7 @@ class SQLAnywherePlatform extends AbstractPlatform
     /**
      * {@inheritdoc}
      */
-    public function getDateTypeDeclarationSQL(array $fieldDeclaration)
+    public function getDateTypeDeclarationSQL(array $column)
     {
         return 'DATE';
     }
@@ -547,7 +551,7 @@ class SQLAnywherePlatform extends AbstractPlatform
 
         if (! is_string($index)) {
             throw new InvalidArgumentException(
-                'SQLAnywherePlatform::getDropIndexSQL() expects $index parameter to be string or ' . Index::class . '.'
+                __METHOD__ . '() expects $index parameter to be string or ' . Index::class . '.'
             );
         }
 
@@ -561,7 +565,7 @@ class SQLAnywherePlatform extends AbstractPlatform
 
         if (! is_string($table)) {
             throw new InvalidArgumentException(
-                'SQLAnywherePlatform::getDropIndexSQL() expects $table parameter to be string or ' . Index::class . '.'
+                __METHOD__ . '() expects $table parameter to be string or ' . Index::class . '.'
             );
         }
 
@@ -628,17 +632,15 @@ class SQLAnywherePlatform extends AbstractPlatform
             case self::FOREIGN_KEY_MATCH_SIMPLE:
                 return 'SIMPLE';
 
-                break;
             case self::FOREIGN_KEY_MATCH_FULL:
                 return 'FULL';
 
-                break;
             case self::FOREIGN_KEY_MATCH_SIMPLE_UNIQUE:
                 return 'UNIQUE SIMPLE';
 
-                break;
             case self::FOREIGN_KEY_MATCH_FULL_UNIQUE:
                 return 'UNIQUE FULL';
+
             default:
                 throw new InvalidArgumentException('Invalid foreign key match type: ' . $type);
         }
@@ -678,7 +680,7 @@ class SQLAnywherePlatform extends AbstractPlatform
     /**
      * {@inheritdoc}
      */
-    public function getGuidTypeDeclarationSQL(array $field)
+    public function getGuidTypeDeclarationSQL(array $column)
     {
         return 'UNIQUEIDENTIFIER';
     }
@@ -689,17 +691,17 @@ class SQLAnywherePlatform extends AbstractPlatform
     public function getIndexDeclarationSQL($name, Index $index)
     {
         // Index declaration in statements like CREATE TABLE is not supported.
-        throw DBALException::notSupported(__METHOD__);
+        throw Exception::notSupported(__METHOD__);
     }
 
     /**
      * {@inheritdoc}
      */
-    public function getIntegerTypeDeclarationSQL(array $columnDef)
+    public function getIntegerTypeDeclarationSQL(array $column)
     {
-        $columnDef['integer_type'] = 'INT';
+        $column['integer_type'] = 'INT';
 
-        return $this->_getCommonIntegerTypeDeclarationSQL($columnDef);
+        return $this->_getCommonIntegerTypeDeclarationSQL($column);
     }
 
     /**
@@ -874,7 +876,7 @@ SQL
     /**
      * {@inheritdoc}
      */
-    public function getListTableIndexesSQL($table, $currentDatabase = null)
+    public function getListTableIndexesSQL($table, $database = null)
     {
         $user = '';
 
@@ -1039,11 +1041,11 @@ SQL
     /**
      * {@inheritdoc}
      */
-    public function getSmallIntTypeDeclarationSQL(array $columnDef)
+    public function getSmallIntTypeDeclarationSQL(array $column)
     {
-        $columnDef['integer_type'] = 'SMALLINT';
+        $column['integer_type'] = 'SMALLINT';
 
-        return $this->_getCommonIntegerTypeDeclarationSQL($columnDef);
+        return $this->_getCommonIntegerTypeDeclarationSQL($column);
     }
 
     /**
@@ -1088,13 +1090,13 @@ SQL
     /**
      * {@inheritdoc}
      */
-    public function getSubstringExpression($value, $from, $length = null)
+    public function getSubstringExpression($string, $start, $length = null)
     {
         if ($length === null) {
-            return 'SUBSTRING(' . $value . ', ' . $from . ')';
+            return 'SUBSTRING(' . $string . ', ' . $start . ')';
         }
 
-        return 'SUBSTRING(' . $value . ', ' . $from . ', ' . $length . ')';
+        return 'SUBSTRING(' . $string . ', ' . $start . ', ' . $length . ')';
     }
 
     /**
@@ -1116,7 +1118,7 @@ SQL
     /**
      * {@inheritdoc}
      */
-    public function getTimeTypeDeclarationSQL(array $fieldDeclaration)
+    public function getTimeTypeDeclarationSQL(array $column)
     {
         return 'TIME';
     }
@@ -1124,14 +1126,16 @@ SQL
     /**
      * {@inheritdoc}
      */
-    public function getTrimExpression($str, $pos = TrimMode::UNSPECIFIED, $char = false)
+    public function getTrimExpression($str, $mode = TrimMode::UNSPECIFIED, $char = false)
     {
         if (! $char) {
-            switch ($pos) {
+            switch ($mode) {
                 case TrimMode::LEADING:
                     return $this->getLtrimExpression($str);
+
                 case TrimMode::TRAILING:
                     return $this->getRtrimExpression($str);
+
                 default:
                     return 'TRIM(' . $str . ')';
             }
@@ -1139,14 +1143,17 @@ SQL
 
         $pattern = "'%[^' + " . $char . " + ']%'";
 
-        switch ($pos) {
+        switch ($mode) {
             case TrimMode::LEADING:
                 return 'SUBSTR(' . $str . ', PATINDEX(' . $pattern . ', ' . $str . '))';
+
             case TrimMode::TRAILING:
                 return 'REVERSE(SUBSTR(REVERSE(' . $str . '), PATINDEX(' . $pattern . ', REVERSE(' . $str . '))))';
+
             default:
                 return 'REVERSE(SUBSTR(REVERSE(SUBSTR(' . $str . ', PATINDEX(' . $pattern . ', ' . $str . '))), ' .
-                    'PATINDEX(' . $pattern . ', REVERSE(SUBSTR(' . $str . ', PATINDEX(' . $pattern . ', ' . $str . '))))))';
+                    'PATINDEX(' . $pattern . ', ' .
+                    'REVERSE(SUBSTR(' . $str . ', PATINDEX(' . $pattern . ', ' . $str . '))))))';
         }
     }
 
@@ -1232,18 +1239,18 @@ SQL
     /**
      * {@inheritdoc}
      */
-    protected function _getCommonIntegerTypeDeclarationSQL(array $columnDef)
+    protected function _getCommonIntegerTypeDeclarationSQL(array $column)
     {
-        $unsigned      = ! empty($columnDef['unsigned']) ? 'UNSIGNED ' : '';
-        $autoincrement = ! empty($columnDef['autoincrement']) ? ' IDENTITY' : '';
+        $unsigned      = ! empty($column['unsigned']) ? 'UNSIGNED ' : '';
+        $autoincrement = ! empty($column['autoincrement']) ? ' IDENTITY' : '';
 
-        return $unsigned . $columnDef['integer_type'] . $autoincrement;
+        return $unsigned . $column['integer_type'] . $autoincrement;
     }
 
     /**
      * {@inheritdoc}
      */
-    protected function _getCreateTableSQL($tableName, array $columns, array $options = [])
+    protected function _getCreateTableSQL($name, array $columns, array $options = [])
     {
         $columnListSql = $this->getColumnDeclarationListSQL($columns);
         $indexSql      = [];
@@ -1255,9 +1262,9 @@ SQL
         }
 
         if (! empty($options['indexes'])) {
-            /** @var Index $index */
             foreach ((array) $options['indexes'] as $index) {
-                $indexSql[] = $this->getCreateIndexSQL($index, $tableName);
+                assert($index instanceof Index);
+                $indexSql[] = $this->getCreateIndexSQL($index, $name);
             }
         }
 
@@ -1268,7 +1275,8 @@ SQL
                 $flags = ' CLUSTERED ';
             }
 
-            $columnListSql .= ', PRIMARY KEY' . $flags . ' (' . implode(', ', array_unique(array_values((array) $options['primary']))) . ')';
+            $columnListSql .= ', PRIMARY KEY' . $flags
+                . ' (' . implode(', ', array_unique(array_values((array) $options['primary']))) . ')';
         }
 
         if (! empty($options['foreignKeys'])) {
@@ -1277,7 +1285,7 @@ SQL
             }
         }
 
-        $query = 'CREATE TABLE ' . $tableName . ' (' . $columnListSql;
+        $query = 'CREATE TABLE ' . $name . ' (' . $columnListSql;
         $check = $this->getCheckDeclarationSQL($columns);
 
         if (! empty($check)) {
@@ -1296,13 +1304,17 @@ SQL
     {
         switch ($level) {
             case TransactionIsolationLevel::READ_UNCOMMITTED:
-                return 0;
+                return '0';
+
             case TransactionIsolationLevel::READ_COMMITTED:
-                return 1;
+                return '1';
+
             case TransactionIsolationLevel::REPEATABLE_READ:
-                return 2;
+                return '2';
+
             case TransactionIsolationLevel::SERIALIZABLE:
-                return 3;
+                return '3';
+
             default:
                 throw new InvalidArgumentException('Invalid isolation level:' . $level);
         }
@@ -1326,7 +1338,7 @@ SQL
         return $matches[1] . $limitOffsetClause . ' ' . $matches[3];
     }
 
-    private function getTopClauseSQL(?int $limit, ?int $offset) : string
+    private function getTopClauseSQL(?int $limit, ?int $offset): string
     {
         if ($offset > 0) {
             return sprintf('TOP %s START AT %d', $limit ?? 'ALL', $offset + 1);
@@ -1386,8 +1398,8 @@ SQL
 
         if (! $constraint->isPrimary() && ! $constraint->isUnique()) {
             throw new InvalidArgumentException(
-                'Can only create primary, unique or foreign key constraint declarations, no common index declarations ' .
-                'with getTableConstraintDeclarationSQL().'
+                'Can only create primary, unique or foreign key constraint declarations, no common index declarations'
+                    . ' with getTableConstraintDeclarationSQL().'
             );
         }
 
@@ -1410,7 +1422,8 @@ SQL
         }
 
         if ($constraint->isPrimary()) {
-            return $sql . 'PRIMARY KEY ' . $flags . '(' . $this->getIndexFieldDeclarationListSQL($constraintColumns) . ')';
+            return $sql . 'PRIMARY KEY ' . $flags
+                . '(' . $this->getIndexFieldDeclarationListSQL($constraintColumns) . ')';
         }
 
         return $sql . 'UNIQUE ' . $flags . '(' . $this->getIndexFieldDeclarationListSQL($constraintColumns) . ')';
