@@ -9,24 +9,23 @@ use Doctrine\DBAL\Cache\QueryCacheProfile;
 use Doctrine\DBAL\Configuration;
 use Doctrine\DBAL\Connection;
 use Doctrine\DBAL\ConnectionException;
-use Doctrine\DBAL\DBALException;
 use Doctrine\DBAL\Driver;
 use Doctrine\DBAL\Driver\Connection as DriverConnection;
 use Doctrine\DBAL\Driver\ServerInfoAwareConnection;
 use Doctrine\DBAL\Driver\Statement;
 use Doctrine\DBAL\DriverManager;
 use Doctrine\DBAL\Events;
+use Doctrine\DBAL\Exception;
 use Doctrine\DBAL\Exception\InvalidArgumentException;
 use Doctrine\DBAL\FetchMode;
 use Doctrine\DBAL\Logging\DebugStack;
 use Doctrine\DBAL\Logging\EchoSQLLogger;
 use Doctrine\DBAL\ParameterType;
 use Doctrine\DBAL\Platforms\AbstractPlatform;
-use Doctrine\DBAL\VersionAwarePlatformDriver;
 use Doctrine\Tests\DbalTestCase;
-use Exception;
 use PHPUnit\Framework\MockObject\MockObject;
 use stdClass;
+
 use function call_user_func_array;
 
 /**
@@ -37,7 +36,7 @@ class ConnectionTest extends DbalTestCase
     /** @var Connection */
     private $connection;
 
-    /** @var string[] */
+    /** @var array{wrapperClass?: class-string<Connection>} */
     protected $params = [
         'driver' => 'pdo_mysql',
         'host' => 'localhost',
@@ -46,15 +45,15 @@ class ConnectionTest extends DbalTestCase
         'port' => '1234',
     ];
 
-    protected function setUp() : void
+    protected function setUp(): void
     {
         $this->connection = DriverManager::getConnection($this->params);
     }
 
     /**
-     * @return Connection|MockObject
+     * @return Connection&MockObject
      */
-    private function getExecuteUpdateMockConnection()
+    private function getExecuteStatementMockConnection()
     {
         $driverMock = $this->createMock(Driver::class);
 
@@ -67,111 +66,107 @@ class ConnectionTest extends DbalTestCase
         $platform = $this->getMockForAbstractClass(AbstractPlatform::class);
 
         return $this->getMockBuilder(Connection::class)
-            ->onlyMethods(['executeUpdate'])
+            ->onlyMethods(['executeStatement'])
             ->setConstructorArgs([['platform' => $platform], $driverMock])
             ->getMock();
     }
 
-    public function testIsConnected() : void
+    public function testIsConnected(): void
     {
         self::assertFalse($this->connection->isConnected());
     }
 
-    public function testNoTransactionActiveByDefault() : void
+    public function testNoTransactionActiveByDefault(): void
     {
         self::assertFalse($this->connection->isTransactionActive());
     }
 
-    public function testCommitWithNoActiveTransactionThrowsException() : void
+    public function testCommitWithNoActiveTransactionThrowsException(): void
     {
         $this->expectException(ConnectionException::class);
         $this->connection->commit();
     }
 
-    public function testRollbackWithNoActiveTransactionThrowsException() : void
+    public function testRollbackWithNoActiveTransactionThrowsException(): void
     {
         $this->expectException(ConnectionException::class);
         $this->connection->rollBack();
     }
 
-    public function testSetRollbackOnlyNoActiveTransactionThrowsException() : void
+    public function testSetRollbackOnlyNoActiveTransactionThrowsException(): void
     {
         $this->expectException(ConnectionException::class);
         $this->connection->setRollbackOnly();
     }
 
-    public function testIsRollbackOnlyNoActiveTransactionThrowsException() : void
+    public function testIsRollbackOnlyNoActiveTransactionThrowsException(): void
     {
         $this->expectException(ConnectionException::class);
         $this->connection->isRollbackOnly();
     }
 
-    public function testGetConfiguration() : void
+    public function testGetConfiguration(): void
     {
         $config = $this->connection->getConfiguration();
 
         self::assertInstanceOf(Configuration::class, $config);
     }
 
-    public function testGetHost() : void
+    public function testGetHost(): void
     {
         self::assertEquals('localhost', $this->connection->getHost());
     }
 
-    public function testGetPort() : void
+    public function testGetPort(): void
     {
         self::assertEquals('1234', $this->connection->getPort());
     }
 
-    public function testGetUsername() : void
+    public function testGetUsername(): void
     {
         self::assertEquals('root', $this->connection->getUsername());
     }
 
-    public function testGetPassword() : void
+    public function testGetPassword(): void
     {
         self::assertEquals('password', $this->connection->getPassword());
     }
 
-    public function testGetDriver() : void
+    public function testGetDriver(): void
     {
-        self::assertInstanceOf(\Doctrine\DBAL\Driver\PDOMySql\Driver::class, $this->connection->getDriver());
+        self::assertInstanceOf(Driver\PDO\MySQL\Driver::class, $this->connection->getDriver());
     }
 
-    public function testGetEventManager() : void
+    public function testGetEventManager(): void
     {
         self::assertInstanceOf(EventManager::class, $this->connection->getEventManager());
     }
 
-    public function testConnectDispatchEvent() : void
+    public function testConnectDispatchEvent(): void
     {
-        $listenerMock = $this->getMockBuilder($this->getMockClass('ConnectDispatchEventListener'))
-            ->addMethods(['postConnect'])
-            ->getMock();
+        $listenerMock = $this->createMock(ConnectDispatchEventListener::class);
         $listenerMock->expects($this->once())->method('postConnect');
 
         $eventManager = new EventManager();
         $eventManager->addEventListener([Events::postConnect], $listenerMock);
 
         $driverMock = $this->createMock(Driver::class);
-        $driverMock->expects($this->at(0))
+        $driverMock->expects($this->once())
                    ->method('connect');
 
         $conn = new Connection([], $driverMock, new Configuration(), $eventManager);
         $conn->connect();
     }
 
-    public function testEventManagerPassedToPlatform() : void
+    public function testEventManagerPassedToPlatform(): void
     {
         $eventManager = new EventManager();
 
-        /** @var AbstractPlatform|MockObject $driver */
         $platform = $this->createMock(AbstractPlatform::class);
         $platform->expects($this->once())
             ->method('setEventManager')
             ->with($eventManager);
 
-        /** @var Driver|MockObject $driver */
         $driver = $this->createMock(Driver::class);
         $driver->expects($this->any())
             ->method('getDatabasePlatform')
@@ -185,10 +180,15 @@ class ConnectionTest extends DbalTestCase
      * @requires extension pdo_sqlite
      * @dataProvider getQueryMethods
      */
-    public function testDriverExceptionIsWrapped(string $method) : void
+    public function testDriverExceptionIsWrapped(string $method): void
     {
-        $this->expectException(DBALException::class);
-        $this->expectExceptionMessage("An exception occurred while executing 'MUUHAAAAHAAAA':\n\nSQLSTATE[HY000]: General error: 1 near \"MUUHAAAAHAAAA\"");
+        $this->expectException(Exception::class);
+        $this->expectExceptionMessage(<<<EOF
+An exception occurred while executing 'MUUHAAAAHAAAA':
+
+SQLSTATE[HY000]: General error: 1 near "MUUHAAAAHAAAA"
+EOF
+        );
 
         $connection = DriverManager::getConnection([
             'driver' => 'pdo_sqlite',
@@ -201,23 +201,21 @@ class ConnectionTest extends DbalTestCase
     /**
      * @return array<int, array<int, mixed>>
      */
-    public static function getQueryMethods() : iterable
+    public static function getQueryMethods(): iterable
     {
         return [
             ['exec'],
             ['query'],
             ['executeQuery'],
-            ['executeUpdate'],
+            ['executeStatement'],
             ['prepare'],
         ];
     }
 
     /**
      * Pretty dumb test, however we want to check that the EchoSQLLogger correctly implements the interface.
-     *
-     * @group DBAL-11
      */
-    public function testEchoSQLLogger() : void
+    public function testEchoSQLLogger(): void
     {
         $logger = new EchoSQLLogger();
         $this->connection->getConfiguration()->setSQLLogger($logger);
@@ -226,39 +224,26 @@ class ConnectionTest extends DbalTestCase
 
     /**
      * Pretty dumb test, however we want to check that the DebugStack correctly implements the interface.
-     *
-     * @group DBAL-11
      */
-    public function testDebugSQLStack() : void
+    public function testDebugSQLStack(): void
     {
         $logger = new DebugStack();
         $this->connection->getConfiguration()->setSQLLogger($logger);
         self::assertSame($logger, $this->connection->getConfiguration()->getSQLLogger());
     }
 
-    /**
-     * @group DBAL-81
-     */
-    public function testIsAutoCommit() : void
+    public function testIsAutoCommit(): void
     {
         self::assertTrue($this->connection->isAutoCommit());
     }
 
-    /**
-     * @group DBAL-81
-     */
-    public function testSetAutoCommit() : void
+    public function testSetAutoCommit(): void
     {
         $this->connection->setAutoCommit(false);
         self::assertFalse($this->connection->isAutoCommit());
-        $this->connection->setAutoCommit(0);
-        self::assertFalse($this->connection->isAutoCommit());
     }
 
-    /**
-     * @group DBAL-81
-     */
-    public function testConnectStartsTransactionInNoAutoCommitMode() : void
+    public function testConnectStartsTransactionInNoAutoCommitMode(): void
     {
         $driverMock = $this->createMock(Driver::class);
         $driverMock->expects($this->any())
@@ -277,10 +262,7 @@ class ConnectionTest extends DbalTestCase
         self::assertTrue($conn->isTransactionActive());
     }
 
-    /**
-     * @group DBAL-81
-     */
-    public function testCommitStartsTransactionInNoAutoCommitMode() : void
+    public function testCommitStartsTransactionInNoAutoCommitMode(): void
     {
         $driverMock = $this->createMock(Driver::class);
         $driverMock->expects($this->any())
@@ -300,7 +282,7 @@ class ConnectionTest extends DbalTestCase
     /**
      * @dataProvider resultProvider
      */
-    public function testCommitReturn(bool $expectedResult) : void
+    public function testCommitReturn(bool $expectedResult): void
     {
         $driverConnection = $this->createMock(DriverConnection::class);
         $driverConnection->expects($this->once())
@@ -322,15 +304,12 @@ class ConnectionTest extends DbalTestCase
     /**
      * @return bool[][]
      */
-    public function resultProvider() : array
+    public function resultProvider(): array
     {
         return [[true], [false]];
     }
 
-    /**
-     * @group DBAL-81
-     */
-    public function testRollBackStartsTransactionInNoAutoCommitMode() : void
+    public function testRollBackStartsTransactionInNoAutoCommitMode(): void
     {
         $driverMock = $this->createMock(Driver::class);
         $driverMock->expects($this->any())
@@ -347,10 +326,7 @@ class ConnectionTest extends DbalTestCase
         self::assertTrue($conn->isTransactionActive());
     }
 
-    /**
-     * @group DBAL-81
-     */
-    public function testSwitchingAutoCommitModeCommitsAllCurrentTransactions() : void
+    public function testSwitchingAutoCommitModeCommitsAllCurrentTransactions(): void
     {
         $driverMock = $this->createMock(Driver::class);
         $driverMock->expects($this->any())
@@ -374,26 +350,23 @@ class ConnectionTest extends DbalTestCase
         self::assertFalse($conn->isTransactionActive());
     }
 
-    public function testEmptyInsert() : void
+    public function testEmptyInsert(): void
     {
-        $conn = $this->getExecuteUpdateMockConnection();
+        $conn = $this->getExecuteStatementMockConnection();
 
         $conn->expects($this->once())
-            ->method('executeUpdate')
+            ->method('executeStatement')
             ->with('INSERT INTO footable () VALUES ()');
 
         $conn->insert('footable', []);
     }
 
-    /**
-     * @group DBAL-2511
-     */
-    public function testUpdateWithDifferentColumnsInDataAndIdentifiers() : void
+    public function testUpdateWithDifferentColumnsInDataAndIdentifiers(): void
     {
-        $conn = $this->getExecuteUpdateMockConnection();
+        $conn = $this->getExecuteStatementMockConnection();
 
         $conn->expects($this->once())
-            ->method('executeUpdate')
+            ->method('executeStatement')
             ->with(
                 'UPDATE TestTable SET text = ?, is_edited = ? WHERE id = ? AND name = ?',
                 [
@@ -429,15 +402,12 @@ class ConnectionTest extends DbalTestCase
         );
     }
 
-    /**
-     * @group DBAL-2511
-     */
-    public function testUpdateWithSameColumnInDataAndIdentifiers() : void
+    public function testUpdateWithSameColumnInDataAndIdentifiers(): void
     {
-        $conn = $this->getExecuteUpdateMockConnection();
+        $conn = $this->getExecuteStatementMockConnection();
 
         $conn->expects($this->once())
-            ->method('executeUpdate')
+            ->method('executeStatement')
             ->with(
                 'UPDATE TestTable SET text = ?, is_edited = ? WHERE id = ? AND is_edited = ?',
                 [
@@ -472,15 +442,12 @@ class ConnectionTest extends DbalTestCase
         );
     }
 
-    /**
-     * @group DBAL-2688
-     */
-    public function testUpdateWithIsNull() : void
+    public function testUpdateWithIsNull(): void
     {
-        $conn = $this->getExecuteUpdateMockConnection();
+        $conn = $this->getExecuteStatementMockConnection();
 
         $conn->expects($this->once())
-            ->method('executeUpdate')
+            ->method('executeStatement')
             ->with(
                 'UPDATE TestTable SET text = ?, is_edited = ? WHERE id IS NULL AND name = ?',
                 [
@@ -514,15 +481,12 @@ class ConnectionTest extends DbalTestCase
         );
     }
 
-    /**
-     * @group DBAL-2688
-     */
-    public function testDeleteWithIsNull() : void
+    public function testDeleteWithIsNull(): void
     {
-        $conn = $this->getExecuteUpdateMockConnection();
+        $conn = $this->getExecuteStatementMockConnection();
 
         $conn->expects($this->once())
-            ->method('executeUpdate')
+            ->method('executeStatement')
             ->with(
                 'DELETE FROM TestTable WHERE id IS NULL AND name = ?',
                 ['foo'],
@@ -542,7 +506,7 @@ class ConnectionTest extends DbalTestCase
         );
     }
 
-    public function testFetchAssoc() : void
+    public function testFetchAssoc(): void
     {
         $statement = 'SELECT * FROM foo WHERE bar = ?';
         $params    = [666];
@@ -564,7 +528,6 @@ class ConnectionTest extends DbalTestCase
             ->with(FetchMode::ASSOCIATIVE)
             ->will($this->returnValue($result));
 
-        /** @var Connection|MockObject $conn */
         $conn = $this->getMockBuilder(Connection::class)
             ->onlyMethods(['executeQuery'])
             ->setConstructorArgs([[], $driverMock])
@@ -578,7 +541,7 @@ class ConnectionTest extends DbalTestCase
         self::assertSame($result, $conn->fetchAssoc($statement, $params, $types));
     }
 
-    public function testFetchArray() : void
+    public function testFetchArray(): void
     {
         $statement = 'SELECT * FROM foo WHERE bar = ?';
         $params    = [666];
@@ -600,7 +563,6 @@ class ConnectionTest extends DbalTestCase
             ->with(FetchMode::NUMERIC)
             ->will($this->returnValue($result));
 
-        /** @var Connection|MockObject $conn */
         $conn = $this->getMockBuilder(Connection::class)
             ->onlyMethods(['executeQuery'])
             ->setConstructorArgs([[], $driverMock])
@@ -614,7 +576,7 @@ class ConnectionTest extends DbalTestCase
         self::assertSame($result, $conn->fetchArray($statement, $params, $types));
     }
 
-    public function testFetchColumn() : void
+    public function testFetchColumn(): void
     {
         $statement = 'SELECT * FROM foo WHERE bar = ?';
         $params    = [666];
@@ -637,7 +599,6 @@ class ConnectionTest extends DbalTestCase
             ->with($column)
             ->will($this->returnValue($result));
 
-        /** @var Connection|MockObject $conn */
         $conn = $this->getMockBuilder(Connection::class)
             ->onlyMethods(['executeQuery'])
             ->setConstructorArgs([[], $driverMock])
@@ -651,7 +612,7 @@ class ConnectionTest extends DbalTestCase
         self::assertSame($result, $conn->fetchColumn($statement, $params, $column, $types));
     }
 
-    public function testFetchAll() : void
+    public function testFetchAll(): void
     {
         $statement = 'SELECT * FROM foo WHERE bar = ?';
         $params    = [666];
@@ -672,7 +633,6 @@ class ConnectionTest extends DbalTestCase
             ->method('fetchAll')
             ->will($this->returnValue($result));
 
-        /** @var Connection|MockObject $conn */
         $conn = $this->getMockBuilder(Connection::class)
             ->onlyMethods(['executeQuery'])
             ->setConstructorArgs([[], $driverMock])
@@ -686,31 +646,26 @@ class ConnectionTest extends DbalTestCase
         self::assertSame($result, $conn->fetchAll($statement, $params, $types));
     }
 
-    public function testConnectionDoesNotMaintainTwoReferencesToExternalPDO() : void
+    public function testConnectionDoesNotMaintainTwoReferencesToExternalPDO(): void
     {
-        $params['pdo'] = new stdClass();
-
         $driverMock = $this->createMock(Driver::class);
 
-        $conn = new Connection($params, $driverMock);
+        $conn = new Connection(['pdo' => new stdClass()], $driverMock);
 
-        self::assertArrayNotHasKey('pdo', $conn->getParams(), 'Connection is maintaining additional reference to the PDO connection');
+        self::assertArrayNotHasKey('pdo', $conn->getParams());
     }
 
-    public function testPassingExternalPDOMeansConnectionIsConnected() : void
+    public function testPassingExternalPDOMeansConnectionIsConnected(): void
     {
-        $params['pdo'] = new stdClass();
-
         $driverMock = $this->createMock(Driver::class);
 
-        $conn = new Connection($params, $driverMock);
+        $conn = new Connection(['pdo' => new stdClass()], $driverMock);
 
         self::assertTrue($conn->isConnected(), 'Connection is not connected after passing external PDO');
     }
 
-    public function testCallingDeleteWithNoDeletionCriteriaResultsInInvalidArgumentException() : void
+    public function testCallingDeleteWithNoDeletionCriteriaResultsInInvalidArgumentException(): void
     {
-        /** @var Driver $driver */
         $driver  = $this->createMock(Driver::class);
         $pdoMock = $this->createMock(\Doctrine\DBAL\Driver\Connection::class);
 
@@ -727,14 +682,14 @@ class ConnectionTest extends DbalTestCase
     /**
      * @return array<int, array<int, mixed>>
      */
-    public static function dataCallConnectOnce() : iterable
+    public static function dataCallConnectOnce(): iterable
     {
         return [
             ['delete', ['tbl', ['id' => 12345]]],
             ['insert', ['tbl', ['data' => 'foo']]],
             ['update', ['tbl', ['data' => 'bar'], ['id' => 12345]]],
             ['prepare', ['select * from dual']],
-            ['executeUpdate', ['insert into tbl (id) values (?)'], [123]],
+            ['executeStatement', ['insert into tbl (id) values (?)'], [123]],
         ];
     }
 
@@ -743,7 +698,7 @@ class ConnectionTest extends DbalTestCase
      *
      * @dataProvider dataCallConnectOnce
      */
-    public function testCallConnectOnce(string $method, array $params) : void
+    public function testCallConnectOnce(string $method, array $params): void
     {
         $driverMock   = $this->createMock(Driver::class);
         $pdoMock      = $this->createMock(Connection::class);
@@ -764,18 +719,12 @@ class ConnectionTest extends DbalTestCase
         call_user_func_array([$conn, $method], $params);
     }
 
-    /**
-     * @group DBAL-1127
-     */
-    public function testPlatformDetectionIsTriggerOnlyOnceOnRetrievingPlatform() : void
+    public function testPlatformDetectionIsTriggerOnlyOnceOnRetrievingPlatform(): void
     {
-        /** @var Driver|VersionAwarePlatformDriver|MockObject $driverMock */
-        $driverMock = $this->createMock([Driver::class, VersionAwarePlatformDriver::class]);
+        $driverMock = $this->createMock(FutureVersionAwarePlatformDriver::class);
 
-        /** @var ServerInfoAwareConnection|MockObject $driverConnectionMock */
         $driverConnectionMock = $this->createMock(ServerInfoAwareConnection::class);
 
-        /** @var AbstractPlatform|MockObject $platformMock */
         $platformMock = $this->getMockForAbstractClass(AbstractPlatform::class);
 
         $connection = new Connection([], $driverMock);
@@ -800,7 +749,7 @@ class ConnectionTest extends DbalTestCase
         self::assertSame($platformMock, $connection->getDatabasePlatform());
     }
 
-    public function testConnectionParamsArePassedToTheQueryCacheProfileInExecuteCacheQuery() : void
+    public function testConnectionParamsArePassedToTheQueryCacheProfileInExecuteCacheQuery(): void
     {
         $resultCacheDriverMock = $this->createMock(Cache::class);
 
@@ -814,7 +763,6 @@ class ConnectionTest extends DbalTestCase
         $params = [666];
         $types  = [ParameterType::INTEGER];
 
-        /** @var QueryCacheProfile|MockObject $queryCacheProfileMock */
         $queryCacheProfileMock = $this->createMock(QueryCacheProfile::class);
 
         $queryCacheProfileMock
@@ -829,7 +777,6 @@ class ConnectionTest extends DbalTestCase
             ->with($query, $params, $types, $this->params)
             ->will($this->returnValue(['cacheKey', 'realKey']));
 
-        /** @var Driver $driver */
         $driver = $this->createMock(Driver::class);
 
         self::assertInstanceOf(
@@ -838,10 +785,7 @@ class ConnectionTest extends DbalTestCase
         );
     }
 
-    /**
-     * @group #2821
-     */
-    public function testShouldNotPassPlatformInParamsToTheQueryCacheProfileInExecuteCacheQuery() : void
+    public function testShouldNotPassPlatformInParamsToTheQueryCacheProfileInExecuteCacheQuery(): void
     {
         $resultCacheDriverMock = $this->createMock(Cache::class);
 
@@ -851,7 +795,6 @@ class ConnectionTest extends DbalTestCase
             ->with('cacheKey')
             ->will($this->returnValue(['realKey' => []]));
 
-        /** @var QueryCacheProfile|MockObject $queryCacheProfileMock */
         $queryCacheProfileMock = $this->createMock(QueryCacheProfile::class);
 
         $queryCacheProfileMock
@@ -871,68 +814,50 @@ class ConnectionTest extends DbalTestCase
 
         $connectionParams['platform'] = $this->createMock(AbstractPlatform::class);
 
-        /** @var Driver $driver */
         $driver = $this->createMock(Driver::class);
 
         (new Connection($connectionParams, $driver))->executeCacheQuery($query, [], [], $queryCacheProfileMock);
     }
 
-    /**
-     * @group #2821
-     */
-    public function testThrowsExceptionWhenInValidPlatformSpecified() : void
+    public function testThrowsExceptionWhenInValidPlatformSpecified(): void
     {
         $connectionParams             = $this->params;
         $connectionParams['platform'] = new stdClass();
 
-        /** @var Driver $driver */
         $driver = $this->createMock(Driver::class);
 
-        $this->expectException(DBALException::class);
+        $this->expectException(Exception::class);
 
         new Connection($connectionParams, $driver);
     }
 
-    /**
-     * @group DBAL-990
-     */
-    public function testRethrowsOriginalExceptionOnDeterminingPlatformWhenConnectingToNonExistentDatabase() : void
+    public function testRethrowsOriginalExceptionOnDeterminingPlatformWhenConnectingToNonExistentDatabase(): void
     {
-        /** @var Driver|VersionAwarePlatformDriver|MockObject $driverMock */
-        $driverMock = $this->createMock([Driver::class, VersionAwarePlatformDriver::class]);
+        $driverMock = $this->createMock(FutureVersionAwarePlatformDriver::class);
 
         $connection        = new Connection(['dbname' => 'foo'], $driverMock);
-        $originalException = new Exception('Original exception');
-        $fallbackException = new Exception('Fallback exception');
+        $originalException = new \Exception('Original exception');
+        $fallbackException = new \Exception('Fallback exception');
 
-        $driverMock->expects($this->at(0))
-            ->method('connect')
-            ->willThrowException($originalException);
-
-        $driverMock->expects($this->at(1))
-            ->method('connect')
-            ->willThrowException($fallbackException);
+        $driverMock->method('connect')
+            ->will(self::onConsecutiveCalls(
+                self::throwException($originalException),
+                self::throwException($fallbackException)
+            ));
 
         $this->expectExceptionMessage($originalException->getMessage());
 
         $connection->getDatabasePlatform();
     }
 
-    /**
-     * @group #3194
-     */
-    public function testExecuteCacheQueryStripsPlatformFromConnectionParamsBeforeGeneratingCacheKeys() : void
+    public function testExecuteCacheQueryStripsPlatformFromConnectionParamsBeforeGeneratingCacheKeys(): void
     {
-        /** @var Driver|MockObject $driver */
         $driver = $this->createMock(Driver::class);
 
-        /** @var AbstractPlatform|MockObject $platform */
         $platform = $this->createMock(AbstractPlatform::class);
 
-        /** @var QueryCacheProfile|MockObject $queryCacheProfile */
         $queryCacheProfile = $this->createMock(QueryCacheProfile::class);
 
-        /** @var Cache|MockObject $resultCacheDriver */
         $resultCacheDriver = $this->createMock(Cache::class);
 
         $queryCacheProfile
@@ -969,3 +894,8 @@ class ConnectionTest extends DbalTestCase
         $connection->executeCacheQuery($query, [], [], $queryCacheProfile);
     }
 }
+
+interface ConnectDispatchEventListener
+{
+    public function postConnect(): void;
+}
