@@ -3,17 +3,17 @@
 namespace Doctrine\Tests\DBAL\Driver\PDOMySql;
 
 use Doctrine\DBAL\Driver as DriverInterface;
-use Doctrine\DBAL\Driver\PDOMySql\Driver;
+use Doctrine\DBAL\Driver\PDO\MySQL\Driver;
 use Doctrine\Tests\DBAL\Driver\AbstractMySQLDriverTest;
 
 class DriverTest extends AbstractMySQLDriverTest
 {
-    public function testReturnsName() : void
+    public function testReturnsName(): void
     {
         self::assertSame('pdo_mysql', $this->driver->getName());
     }
 
-    protected function createDriver() : DriverInterface
+    protected function createDriver(): DriverInterface
     {
         return new Driver();
     }
