@@ -3,17 +3,17 @@
 namespace Doctrine\Tests\DBAL\Driver\PDOOracle;
 
 use Doctrine\DBAL\Driver as DriverInterface;
-use Doctrine\DBAL\Driver\PDOOracle\Driver;
+use Doctrine\DBAL\Driver\PDO\OCI\Driver;
 use Doctrine\Tests\DBAL\Driver\AbstractOracleDriverTest;
 
 class DriverTest extends AbstractOracleDriverTest
 {
-    public function testReturnsName() : void
+    public function testReturnsName(): void
     {
         self::assertSame('pdo_oracle', $this->driver->getName());
     }
 
-    protected function createDriver() : DriverInterface
+    protected function createDriver(): DriverInterface
     {
         return new Driver();
     }
