@@ -5,23 +5,21 @@ namespace Doctrine\Tests\DBAL\Driver\SQLAnywhere;
 use Doctrine\DBAL\Driver\SQLAnywhere\SQLAnywhereConnection;
 use Doctrine\Tests\DbalTestCase;
 use PHPUnit\Framework\MockObject\MockObject;
-use function extension_loaded;
 
+/**
+ * @requires extension sqlanywhere
+ */
 class SQLAnywhereConnectionTest extends DbalTestCase
 {
     /**
      * The sqlanywhere driver connection mock under test.
      *
-     * @var SQLAnywhereConnection|MockObject
+     * @var SQLAnywhereConnection&MockObject
      */
     private $connectionMock;
 
-    protected function setUp() : void
+    protected function setUp(): void
     {
-        if (! extension_loaded('sqlanywhere')) {
-            $this->markTestSkipped('sqlanywhere is not installed.');
-        }
-
         parent::setUp();
 
         $this->connectionMock = $this->getMockBuilder(SQLAnywhereConnection::class)
@@ -29,7 +27,7 @@ class SQLAnywhereConnectionTest extends DbalTestCase
             ->getMockForAbstractClass();
     }
 
-    public function testRequiresQueryForServerVersion() : void
+    public function testRequiresQueryForServerVersion(): void
     {
         self::assertTrue($this->connectionMock->requiresQueryForServerVersion());
     }
