@@ -10,11 +10,11 @@ use Doctrine\Tests\DbalTestCase;
 
 class MysqlSessionInitTest extends DbalTestCase
 {
-    public function testPostConnect() : void
+    public function testPostConnect(): void
     {
         $connectionMock = $this->createMock(Connection::class);
         $connectionMock->expects($this->once())
-                       ->method('executeUpdate')
+                       ->method('executeStatement')
                        ->with($this->equalTo('SET NAMES foo COLLATE bar'));
 
         $eventArgs = new ConnectionEventArgs($connectionMock);
@@ -23,7 +23,7 @@ class MysqlSessionInitTest extends DbalTestCase
         $listener->postConnect($eventArgs);
     }
 
-    public function testGetSubscribedEvents() : void
+    public function testGetSubscribedEvents(): void
     {
         $listener = new MysqlSessionInit();
         self::assertEquals([Events::postConnect], $listener->getSubscribedEvents());
