@@ -5,16 +5,14 @@ namespace Doctrine\Tests\DBAL\Functional\Driver\Mysqli;
 use Doctrine\DBAL\Driver as DriverInterface;
 use Doctrine\DBAL\Driver\Mysqli\Driver;
 use Doctrine\Tests\DBAL\Functional\Driver\AbstractDriverTest;
-use function extension_loaded;
 
+/**
+ * @requires extension mysqli
+ */
 class DriverTest extends AbstractDriverTest
 {
-    protected function setUp() : void
+    protected function setUp(): void
     {
-        if (! extension_loaded('mysqli')) {
-            $this->markTestSkipped('mysqli is not installed.');
-        }
-
         parent::setUp();
 
         if ($this->connection->getDriver() instanceof Driver) {
@@ -24,10 +22,7 @@ class DriverTest extends AbstractDriverTest
         $this->markTestSkipped('MySQLi only test.');
     }
 
-    /**
-     * {@inheritdoc}
-     */
-    protected function createDriver() : DriverInterface
+    protected function createDriver(): DriverInterface
     {
         return new Driver();
     }
