@@ -3,18 +3,16 @@
 namespace Doctrine\Tests\DBAL\Functional\Driver\PDOOracle;
 
 use Doctrine\DBAL\Driver as DriverInterface;
-use Doctrine\DBAL\Driver\PDOOracle\Driver;
+use Doctrine\DBAL\Driver\PDO\OCI\Driver;
 use Doctrine\Tests\DBAL\Functional\Driver\AbstractDriverTest;
-use function extension_loaded;
 
+/**
+ * @requires extension pdo_oci
+ */
 class DriverTest extends AbstractDriverTest
 {
-    protected function setUp() : void
+    protected function setUp(): void
     {
-        if (! extension_loaded('PDO_OCI')) {
-            $this->markTestSkipped('PDO_OCI is not installed.');
-        }
-
         parent::setUp();
 
         if ($this->connection->getDriver() instanceof Driver) {
@@ -24,26 +22,17 @@ class DriverTest extends AbstractDriverTest
         $this->markTestSkipped('PDO_OCI only test.');
     }
 
-    /**
-     * {@inheritdoc}
-     */
-    public function testConnectsWithoutDatabaseNameParameter() : void
+    public function testConnectsWithoutDatabaseNameParameter(): void
     {
         $this->markTestSkipped('Oracle does not support connecting without database name.');
     }
 
-    /**
-     * {@inheritdoc}
-     */
-    public function testReturnsDatabaseNameWithoutDatabaseNameParameter() : void
+    public function testReturnsDatabaseNameWithoutDatabaseNameParameter(): void
     {
         $this->markTestSkipped('Oracle does not support connecting without database name.');
     }
 
-    /**
-     * {@inheritdoc}
-     */
-    protected function createDriver() : DriverInterface
+    protected function createDriver(): DriverInterface
     {
         return new Driver();
     }
