@@ -5,16 +5,14 @@ namespace Doctrine\Tests\DBAL\Functional\Driver\SQLAnywhere;
 use Doctrine\DBAL\Driver\SQLAnywhere\Driver;
 use Doctrine\DBAL\DriverManager;
 use Doctrine\Tests\DbalFunctionalTestCase;
-use function extension_loaded;
 
+/**
+ * @requires extension sqlanywhere
+ */
 class ConnectionTest extends DbalFunctionalTestCase
 {
-    protected function setUp() : void
+    protected function setUp(): void
     {
-        if (! extension_loaded('sqlanywhere')) {
-            $this->markTestSkipped('sqlanywhere is not installed.');
-        }
-
         parent::setUp();
 
         if ($this->connection->getDriver() instanceof Driver) {
@@ -24,7 +22,7 @@ class ConnectionTest extends DbalFunctionalTestCase
         $this->markTestSkipped('sqlanywhere only test.');
     }
 
-    public function testNonPersistentConnection() : void
+    public function testNonPersistentConnection(): void
     {
         $params               = $this->connection->getParams();
         $params['persistent'] = false;
@@ -36,7 +34,7 @@ class ConnectionTest extends DbalFunctionalTestCase
         self::assertTrue($conn->isConnected(), 'No SQLAnywhere-nonpersistent connection established');
     }
 
-    public function testPersistentConnection() : void
+    public function testPersistentConnection(): void
     {
         $params               = $this->connection->getParams();
         $params['persistent'] = true;
