@@ -5,16 +5,14 @@ namespace Doctrine\Tests\DBAL\Functional\Driver\SQLAnywhere;
 use Doctrine\DBAL\Driver\SQLAnywhere\Driver;
 use Doctrine\DBAL\DriverManager;
 use Doctrine\Tests\DbalFunctionalTestCase;
-use function extension_loaded;
 
+/**
+ * @requires extension sqlanywhere
+ */
 class StatementTest extends DbalFunctionalTestCase
 {
-    protected function setUp() : void
+    protected function setUp(): void
     {
-        if (! extension_loaded('sqlanywhere')) {
-            $this->markTestSkipped('sqlanywhere is not installed.');
-        }
-
         parent::setUp();
 
         if ($this->connection->getDriver() instanceof Driver) {
@@ -24,7 +22,7 @@ class StatementTest extends DbalFunctionalTestCase
         $this->markTestSkipped('sqlanywhere only test.');
     }
 
-    public function testNonPersistentStatement() : void
+    public function testNonPersistentStatement(): void
     {
         $params               = $this->connection->getParams();
         $params['persistent'] = false;
@@ -39,7 +37,7 @@ class StatementTest extends DbalFunctionalTestCase
         self::assertTrue($prepStmt->execute(), ' Statement non-persistent failed');
     }
 
-    public function testPersistentStatement() : void
+    public function testPersistentStatement(): void
     {
         $params               = $this->connection->getParams();
         $params['persistent'] = true;
