@@ -5,16 +5,14 @@ namespace Doctrine\Tests\DBAL\Functional\Driver\SQLSrv;
 use Doctrine\DBAL\Driver\SQLSrv\Driver;
 use Doctrine\DBAL\Driver\SQLSrv\SQLSrvException;
 use Doctrine\Tests\DbalFunctionalTestCase;
-use function extension_loaded;
 
+/**
+ * @requires extension sqlsrv
+ */
 class StatementTest extends DbalFunctionalTestCase
 {
-    protected function setUp() : void
+    protected function setUp(): void
     {
-        if (! extension_loaded('sqlsrv')) {
-            self::markTestSkipped('sqlsrv is not installed.');
-        }
-
         parent::setUp();
 
         if ($this->connection->getDriver() instanceof Driver) {
@@ -24,10 +22,10 @@ class StatementTest extends DbalFunctionalTestCase
         self::markTestSkipped('sqlsrv only test');
     }
 
-    public function testFailureToPrepareResultsInException() : void
+    public function testFailureToPrepareResultsInException(): void
     {
         // use the driver connection directly to avoid having exception wrapped
-        $stmt = $this->connection->getWrappedConnection()->prepare(null);
+        $stmt = $this->connection->getWrappedConnection()->prepare('');
 
         // it's impossible to prepare the statement without bound variables for SQL Server,
         // so the preparation happens before the first execution when variables are already in place
