@@ -2,23 +2,21 @@
 
 namespace Doctrine\Tests\DBAL\Functional;
 
-use Doctrine\DBAL\Driver\PDOConnection;
+use Doctrine\DBAL\Driver\PDO\Connection;
 use Doctrine\DBAL\Schema\Table;
 use Doctrine\Tests\DbalFunctionalTestCase;
 use PDO;
-use function extension_loaded;
 
+/**
+ * @requires extension pdo
+ */
 class PDOStatementTest extends DbalFunctionalTestCase
 {
-    protected function setUp() : void
+    protected function setUp(): void
     {
-        if (! extension_loaded('pdo')) {
-            $this->markTestSkipped('PDO is not installed');
-        }
-
         parent::setUp();
 
-        if (! $this->connection->getWrappedConnection() instanceof PDOConnection) {
+        if (! $this->connection->getWrappedConnection() instanceof Connection) {
             $this->markTestSkipped('PDO-only test');
         }
 
@@ -28,11 +26,7 @@ class PDOStatementTest extends DbalFunctionalTestCase
         $this->connection->getSchemaManager()->dropAndCreateTable($table);
     }
 
-    /**
-     * @group legacy
-     * @expectedDeprecation Using a PDO fetch mode or their combination (%d given) is deprecated and will cause an error in Doctrine DBAL 3.0
-     */
-    public function testPDOSpecificModeIsAccepted() : void
+    public function testPDOSpecificModeIsAccepted(): void
     {
         $this->connection->insert('stmt_test', [
             'id' => 1,
