@@ -2,6 +2,8 @@
 
 namespace Doctrine\Tests\DBAL\Platforms;
 
+use Doctrine\DBAL\Platforms\AbstractPlatform;
+use Doctrine\DBAL\Platforms\PostgreSqlPlatform;
 use Doctrine\DBAL\Schema\Column;
 use Doctrine\DBAL\Schema\ColumnDiff;
 use Doctrine\DBAL\Schema\Comparator;
@@ -12,11 +14,20 @@ use Doctrine\DBAL\Schema\TableDiff;
 use Doctrine\DBAL\TransactionIsolationLevel;
 use Doctrine\DBAL\Types\Type;
 use UnexpectedValueException;
+
 use function sprintf;
 
 abstract class AbstractPostgreSqlPlatformTestCase extends AbstractPlatformTestCase
 {
-    public function getGenerateTableSql() : string
+    /** @var PostgreSqlPlatform */
+    protected $platform;
+
+    /**
+     * @return PostgreSqlPlatform
+     */
+    abstract public function createPlatform(): AbstractPlatform;
+
+    public function getGenerateTableSql(): string
     {
         return 'CREATE TABLE test (id SERIAL NOT NULL, test VARCHAR(255) DEFAULT NULL, PRIMARY KEY(id))';
     }
@@ -24,7 +35,7 @@ abstract class AbstractPostgreSqlPlatformTestCase extends AbstractPlatformTestCa
     /**
      * {@inheritDoc}
      */
-    public function getGenerateTableWithMultiColumnUniqueIndexSql() : array
+    public function getGenerateTableWithMultiColumnUniqueIndexSql(): array
     {
         return [
             'CREATE TABLE test (foo VARCHAR(255) DEFAULT NULL, bar VARCHAR(255) DEFAULT NULL)',
@@ -35,7 +46,7 @@ abstract class AbstractPostgreSqlPlatformTestCase extends AbstractPlatformTestCa
     /**
      * {@inheritDoc}
      */
-    public function getGenerateAlterTableSql() : array
+    public function getGenerateAlterTableSql(): array
     {
         return [
             'ALTER TABLE mytable ADD quota INT DEFAULT NULL',
@@ -50,17 +61,18 @@ abstract class AbstractPostgreSqlPlatformTestCase extends AbstractPlatformTestCa
         ];
     }
 
-    public function getGenerateIndexSql() : string
+    public function getGenerateIndexSql(): string
     {
         return 'CREATE INDEX my_idx ON mytable (user_name, last_login)';
     }
 
-    public function getGenerateForeignKeySql() : string
+    protected function getGenerateForeignKeySql(): string
     {
-        return 'ALTER TABLE test ADD FOREIGN KEY (fk_name_id) REFERENCES other_table (id) NOT DEFERRABLE INITIALLY IMMEDIATE';
+        return 'ALTER TABLE test ADD FOREIGN KEY (fk_name_id)'
+            . ' REFERENCES other_table (id) NOT DEFERRABLE INITIALLY IMMEDIATE';
     }
 
-    public function testGeneratesForeignKeySqlForNonStandardOptions() : void
+    public function testGeneratesForeignKeySqlForNonStandardOptions(): void
     {
         $foreignKey = new ForeignKeyConstraint(
             ['foreign_id'],
@@ -70,7 +82,8 @@ abstract class AbstractPostgreSqlPlatformTestCase extends AbstractPlatformTestCa
             ['onDelete' => 'CASCADE']
         );
         self::assertEquals(
-            'CONSTRAINT my_fk FOREIGN KEY (foreign_id) REFERENCES my_table (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE',
+            'CONSTRAINT my_fk FOREIGN KEY (foreign_id)'
+                . ' REFERENCES my_table (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE',
             $this->platform->getForeignKeyDeclarationSQL($foreignKey)
         );
 
@@ -82,7 +95,8 @@ abstract class AbstractPostgreSqlPlatformTestCase extends AbstractPlatformTestCa
             ['match' => 'full']
         );
         self::assertEquals(
-            'CONSTRAINT my_fk FOREIGN KEY (foreign_id) REFERENCES my_table (id) MATCH full NOT DEFERRABLE INITIALLY IMMEDIATE',
+            'CONSTRAINT my_fk FOREIGN KEY (foreign_id)'
+                . ' REFERENCES my_table (id) MATCH full NOT DEFERRABLE INITIALLY IMMEDIATE',
             $this->platform->getForeignKeyDeclarationSQL($foreignKey)
         );
 
@@ -94,7 +108,8 @@ abstract class AbstractPostgreSqlPlatformTestCase extends AbstractPlatformTestCa
             ['deferrable' => true]
         );
         self::assertEquals(
-            'CONSTRAINT my_fk FOREIGN KEY (foreign_id) REFERENCES my_table (id) DEFERRABLE INITIALLY IMMEDIATE',
+            'CONSTRAINT my_fk FOREIGN KEY (foreign_id)'
+                . ' REFERENCES my_table (id) DEFERRABLE INITIALLY IMMEDIATE',
             $this->platform->getForeignKeyDeclarationSQL($foreignKey)
         );
 
@@ -106,7 +121,8 @@ abstract class AbstractPostgreSqlPlatformTestCase extends AbstractPlatformTestCa
             ['deferred' => true]
         );
         self::assertEquals(
-            'CONSTRAINT my_fk FOREIGN KEY (foreign_id) REFERENCES my_table (id) NOT DEFERRABLE INITIALLY DEFERRED',
+            'CONSTRAINT my_fk FOREIGN KEY (foreign_id)'
+                . ' REFERENCES my_table (id) NOT DEFERRABLE INITIALLY DEFERRED',
             $this->platform->getForeignKeyDeclarationSQL($foreignKey)
         );
 
@@ -118,7 +134,8 @@ abstract class AbstractPostgreSqlPlatformTestCase extends AbstractPlatformTestCa
             ['feferred' => true]
         );
         self::assertEquals(
-            'CONSTRAINT my_fk FOREIGN KEY (foreign_id) REFERENCES my_table (id) NOT DEFERRABLE INITIALLY DEFERRED',
+            'CONSTRAINT my_fk FOREIGN KEY (foreign_id)'
+                . ' REFERENCES my_table (id) NOT DEFERRABLE INITIALLY DEFERRED',
             $this->platform->getForeignKeyDeclarationSQL($foreignKey)
         );
 
@@ -130,21 +147,27 @@ abstract class AbstractPostgreSqlPlatformTestCase extends AbstractPlatformTestCa
             ['deferrable' => true, 'deferred' => true, 'match' => 'full']
         );
         self::assertEquals(
-            'CONSTRAINT my_fk FOREIGN KEY (foreign_id) REFERENCES my_table (id) MATCH full DEFERRABLE INITIALLY DEFERRED',
+            'CONSTRAINT my_fk FOREIGN KEY (foreign_id)'
+                . ' REFERENCES my_table (id) MATCH full DEFERRABLE INITIALLY DEFERRED',
             $this->platform->getForeignKeyDeclarationSQL($foreignKey)
         );
     }
 
-    public function testGeneratesSqlSnippets() : void
+    public function testGeneratesSqlSnippets(): void
     {
-        self::assertEquals('SIMILAR TO', $this->platform->getRegexpExpression(), 'Regular expression operator is not correct');
-        self::assertEquals('"', $this->platform->getIdentifierQuoteCharacter(), 'Identifier quote character is not correct');
-        self::assertEquals('column1 || column2 || column3', $this->platform->getConcatExpression('column1', 'column2', 'column3'), 'Concatenation expression is not correct');
-        self::assertEquals('SUBSTRING(column FROM 5)', $this->platform->getSubstringExpression('column', 5), 'Substring expression without length is not correct');
-        self::assertEquals('SUBSTRING(column FROM 1 FOR 5)', $this->platform->getSubstringExpression('column', 1, 5), 'Substring expression with length is not correct');
+        self::assertEquals('SIMILAR TO', $this->platform->getRegexpExpression());
+        self::assertEquals('"', $this->platform->getIdentifierQuoteCharacter());
+
+        self::assertEquals(
+            'column1 || column2 || column3',
+            $this->platform->getConcatExpression('column1', 'column2', 'column3')
+        );
+
+        self::assertEquals('SUBSTRING(column FROM 5)', $this->platform->getSubstringExpression('column', 5));
+        self::assertEquals('SUBSTRING(column FROM 1 FOR 5)', $this->platform->getSubstringExpression('column', 1, 5));
     }
 
-    public function testGeneratesTransactionCommands() : void
+    public function testGeneratesTransactionCommands(): void
     {
         self::assertEquals(
             'SET SESSION CHARACTERISTICS AS TRANSACTION ISOLATION LEVEL READ UNCOMMITTED',
@@ -164,26 +187,29 @@ abstract class AbstractPostgreSqlPlatformTestCase extends AbstractPlatformTestCa
         );
     }
 
-    public function testGeneratesDDLSnippets() : void
+    public function testGeneratesDDLSnippets(): void
     {
         self::assertEquals('CREATE DATABASE foobar', $this->platform->getCreateDatabaseSQL('foobar'));
         self::assertEquals('DROP DATABASE foobar', $this->platform->getDropDatabaseSQL('foobar'));
         self::assertEquals('DROP TABLE foobar', $this->platform->getDropTableSQL('foobar'));
     }
 
-    public function testGenerateTableWithAutoincrement() : void
+    public function testGenerateTableWithAutoincrement(): void
     {
         $table  = new Table('autoinc_table');
         $column = $table->addColumn('id', 'integer');
         $column->setAutoincrement(true);
 
-        self::assertEquals(['CREATE TABLE autoinc_table (id SERIAL NOT NULL)'], $this->platform->getCreateTableSQL($table));
+        self::assertEquals(
+            ['CREATE TABLE autoinc_table (id SERIAL NOT NULL)'],
+            $this->platform->getCreateTableSQL($table)
+        );
     }
 
     /**
      * @return mixed[][]
      */
-    public static function serialTypes() : iterable
+    public static function serialTypes(): iterable
     {
         return [
             ['integer', 'SERIAL'],
@@ -193,9 +219,8 @@ abstract class AbstractPostgreSqlPlatformTestCase extends AbstractPlatformTestCa
 
     /**
      * @dataProvider serialTypes
-     * @group 2906
      */
-    public function testGenerateTableWithAutoincrementDoesNotSetDefault(string $type, string $definition) : void
+    public function testGenerateTableWithAutoincrementDoesNotSetDefault(string $type, string $definition): void
     {
         $table  = new Table('autoinc_table_notnull');
         $column = $table->addColumn('id', $type);
@@ -209,9 +234,8 @@ abstract class AbstractPostgreSqlPlatformTestCase extends AbstractPlatformTestCa
 
     /**
      * @dataProvider serialTypes
-     * @group 2906
      */
-    public function testCreateTableWithAutoincrementAndNotNullAddsConstraint(string $type, string $definition) : void
+    public function testCreateTableWithAutoincrementAndNotNullAddsConstraint(string $type, string $definition): void
     {
         $table  = new Table('autoinc_table_notnull_enabled');
         $column = $table->addColumn('id', $type);
@@ -225,9 +249,8 @@ abstract class AbstractPostgreSqlPlatformTestCase extends AbstractPlatformTestCa
 
     /**
      * @dataProvider serialTypes
-     * @group 2906
      */
-    public function testGetDefaultValueDeclarationSQLIgnoresTheDefaultKeyWhenTheFieldIsSerial(string $type) : void
+    public function testGetDefaultValueDeclarationSQLIgnoresTheDefaultKeyWhenTheFieldIsSerial(string $type): void
     {
         $sql = $this->platform->getDefaultValueDeclarationSQL(
             [
@@ -240,7 +263,7 @@ abstract class AbstractPostgreSqlPlatformTestCase extends AbstractPlatformTestCa
         self::assertSame('', $sql);
     }
 
-    public function testGeneratesTypeDeclarationForIntegers() : void
+    public function testGeneratesTypeDeclarationForIntegers(): void
     {
         self::assertEquals(
             'INT',
@@ -258,7 +281,7 @@ abstract class AbstractPostgreSqlPlatformTestCase extends AbstractPlatformTestCa
         );
     }
 
-    public function testGeneratesTypeDeclarationForStrings() : void
+    public function testGeneratesTypeDeclarationForStrings(): void
     {
         self::assertEquals(
             'CHAR(10)',
@@ -268,22 +291,20 @@ abstract class AbstractPostgreSqlPlatformTestCase extends AbstractPlatformTestCa
         );
         self::assertEquals(
             'VARCHAR(50)',
-            $this->platform->getVarcharTypeDeclarationSQL(['length' => 50]),
-            'Variable string declaration is not correct'
+            $this->platform->getVarcharTypeDeclarationSQL(['length' => 50])
         );
         self::assertEquals(
             'VARCHAR(255)',
-            $this->platform->getVarcharTypeDeclarationSQL([]),
-            'Long string declaration is not correct'
+            $this->platform->getVarcharTypeDeclarationSQL([])
         );
     }
 
-    public function getGenerateUniqueIndexSql() : string
+    public function getGenerateUniqueIndexSql(): string
     {
         return 'CREATE UNIQUE INDEX index_name ON test (test, test2)';
     }
 
-    public function testGeneratesSequenceSqlCommands() : void
+    public function testGeneratesSequenceSqlCommands(): void
     {
         $sequence = new Sequence('myseq', 20, 1);
         self::assertEquals(
@@ -300,46 +321,43 @@ abstract class AbstractPostgreSqlPlatformTestCase extends AbstractPlatformTestCa
         );
     }
 
-    public function testDoesNotPreferIdentityColumns() : void
+    public function testDoesNotPreferIdentityColumns(): void
     {
         self::assertFalse($this->platform->prefersIdentityColumns());
     }
 
-    public function testPrefersSequences() : void
+    public function testPrefersSequences(): void
     {
         self::assertTrue($this->platform->prefersSequences());
     }
 
-    public function testSupportsIdentityColumns() : void
+    public function testSupportsIdentityColumns(): void
     {
         self::assertTrue($this->platform->supportsIdentityColumns());
     }
 
-    public function testSupportsSavePoints() : void
+    public function testSupportsSavePoints(): void
     {
         self::assertTrue($this->platform->supportsSavepoints());
     }
 
-    public function testSupportsSequences() : void
+    public function testSupportsSequences(): void
     {
         self::assertTrue($this->platform->supportsSequences());
     }
 
-    /**
-     * {@inheritdoc}
-     */
-    protected function supportsCommentOnStatement() : bool
+    protected function supportsCommentOnStatement(): bool
     {
         return true;
     }
 
-    public function testModifyLimitQuery() : void
+    public function testModifyLimitQuery(): void
     {
         $sql = $this->platform->modifyLimitQuery('SELECT * FROM user', 10, 0);
         self::assertEquals('SELECT * FROM user LIMIT 10', $sql);
     }
 
-    public function testModifyLimitQueryWithEmptyOffset() : void
+    public function testModifyLimitQueryWithEmptyOffset(): void
     {
         $sql = $this->platform->modifyLimitQuery('SELECT * FROM user', 10);
         self::assertEquals('SELECT * FROM user LIMIT 10', $sql);
@@ -348,7 +366,7 @@ abstract class AbstractPostgreSqlPlatformTestCase extends AbstractPlatformTestCa
     /**
      * {@inheritDoc}
      */
-    public function getCreateTableColumnCommentsSQL() : array
+    public function getCreateTableColumnCommentsSQL(): array
     {
         return [
             'CREATE TABLE test (id INT NOT NULL, PRIMARY KEY(id))',
@@ -359,7 +377,7 @@ abstract class AbstractPostgreSqlPlatformTestCase extends AbstractPlatformTestCa
     /**
      * {@inheritDoc}
      */
-    public function getAlterTableColumnCommentsSQL() : array
+    public function getAlterTableColumnCommentsSQL(): array
     {
         return [
             'ALTER TABLE mytable ADD quota INT NOT NULL',
@@ -372,7 +390,7 @@ abstract class AbstractPostgreSqlPlatformTestCase extends AbstractPlatformTestCa
     /**
      * {@inheritDoc}
      */
-    public function getCreateTableColumnTypeCommentsSQL() : array
+    public function getCreateTableColumnTypeCommentsSQL(): array
     {
         return [
             'CREATE TABLE test (id INT NOT NULL, data TEXT NOT NULL, PRIMARY KEY(id))',
@@ -383,7 +401,7 @@ abstract class AbstractPostgreSqlPlatformTestCase extends AbstractPlatformTestCa
     /**
      * {@inheritDoc}
      */
-    protected function getQuotedColumnInPrimaryKeySQL() : array
+    protected function getQuotedColumnInPrimaryKeySQL(): array
     {
         return ['CREATE TABLE "quoted" ("create" VARCHAR(255) NOT NULL, PRIMARY KEY("create"))'];
     }
@@ -391,7 +409,7 @@ abstract class AbstractPostgreSqlPlatformTestCase extends AbstractPlatformTestCa
     /**
      * {@inheritDoc}
      */
-    protected function getQuotedColumnInIndexSQL() : array
+    protected function getQuotedColumnInIndexSQL(): array
     {
         return [
             'CREATE TABLE "quoted" ("create" VARCHAR(255) NOT NULL)',
@@ -402,7 +420,7 @@ abstract class AbstractPostgreSqlPlatformTestCase extends AbstractPlatformTestCa
     /**
      * {@inheritDoc}
      */
-    protected function getQuotedNameInIndexSQL() : array
+    protected function getQuotedNameInIndexSQL(): array
     {
         return [
             'CREATE TABLE test (column1 VARCHAR(255) NOT NULL)',
@@ -413,20 +431,23 @@ abstract class AbstractPostgreSqlPlatformTestCase extends AbstractPlatformTestCa
     /**
      * {@inheritDoc}
      */
-    protected function getQuotedColumnInForeignKeySQL() : array
+    protected function getQuotedColumnInForeignKeySQL(): array
     {
         return [
-            'CREATE TABLE "quoted" ("create" VARCHAR(255) NOT NULL, foo VARCHAR(255) NOT NULL, "bar" VARCHAR(255) NOT NULL)',
-            'ALTER TABLE "quoted" ADD CONSTRAINT FK_WITH_RESERVED_KEYWORD FOREIGN KEY ("create", foo, "bar") REFERENCES "foreign" ("create", bar, "foo-bar") NOT DEFERRABLE INITIALLY IMMEDIATE',
-            'ALTER TABLE "quoted" ADD CONSTRAINT FK_WITH_NON_RESERVED_KEYWORD FOREIGN KEY ("create", foo, "bar") REFERENCES foo ("create", bar, "foo-bar") NOT DEFERRABLE INITIALLY IMMEDIATE',
-            'ALTER TABLE "quoted" ADD CONSTRAINT FK_WITH_INTENDED_QUOTATION FOREIGN KEY ("create", foo, "bar") REFERENCES "foo-bar" ("create", bar, "foo-bar") NOT DEFERRABLE INITIALLY IMMEDIATE',
+            'CREATE TABLE "quoted" ("create" VARCHAR(255) NOT NULL, '
+            . 'foo VARCHAR(255) NOT NULL, "bar" VARCHAR(255) NOT NULL)',
+            'ALTER TABLE "quoted" ADD CONSTRAINT FK_WITH_RESERVED_KEYWORD FOREIGN KEY ("create", foo, "bar")'
+                . ' REFERENCES "foreign" ("create", bar, "foo-bar") NOT DEFERRABLE INITIALLY IMMEDIATE',
+            'ALTER TABLE "quoted" ADD CONSTRAINT FK_WITH_NON_RESERVED_KEYWORD FOREIGN KEY ("create", foo, "bar")'
+                . ' REFERENCES foo ("create", bar, "foo-bar") NOT DEFERRABLE INITIALLY IMMEDIATE',
+            'ALTER TABLE "quoted" ADD CONSTRAINT FK_WITH_INTENDED_QUOTATION FOREIGN KEY ("create", foo, "bar")'
+                . ' REFERENCES "foo-bar" ("create", bar, "foo-bar") NOT DEFERRABLE INITIALLY IMMEDIATE',
         ];
     }
 
     /**
      * @param string|bool $databaseValue
      *
-     * @group DBAL-457
      * @dataProvider pgBooleanProvider
      */
     public function testConvertBooleanAsLiteralStrings(
@@ -434,16 +455,13 @@ abstract class AbstractPostgreSqlPlatformTestCase extends AbstractPlatformTestCa
         string $preparedStatementValue,
         ?int $integerValue,
         ?bool $booleanValue
-    ) : void {
+    ): void {
         $platform = $this->createPlatform();
 
         self::assertEquals($preparedStatementValue, $platform->convertBooleans($databaseValue));
     }
 
-    /**
-     * @group DBAL-457
-     */
-    public function testConvertBooleanAsLiteralIntegers() : void
+    public function testConvertBooleanAsLiteralIntegers(): void
     {
         $platform = $this->createPlatform();
         $platform->setUseBooleanTrueFalseStrings(false);
@@ -458,7 +476,6 @@ abstract class AbstractPostgreSqlPlatformTestCase extends AbstractPlatformTestCa
     /**
      * @param string|bool $databaseValue
      *
-     * @group DBAL-630
      * @dataProvider pgBooleanProvider
      */
     public function testConvertBooleanAsDatabaseValueStrings(
@@ -466,16 +483,13 @@ abstract class AbstractPostgreSqlPlatformTestCase extends AbstractPlatformTestCa
         string $preparedStatementValue,
         ?int $integerValue,
         ?bool $booleanValue
-    ) : void {
+    ): void {
         $platform = $this->createPlatform();
 
         self::assertSame($integerValue, $platform->convertBooleansToDatabaseValue($booleanValue));
     }
 
-    /**
-     * @group DBAL-630
-     */
-    public function testConvertBooleanAsDatabaseValueIntegers() : void
+    public function testConvertBooleanAsDatabaseValueIntegers(): void
     {
         $platform = $this->createPlatform();
         $platform->setUseBooleanTrueFalseStrings(false);
@@ -489,14 +503,18 @@ abstract class AbstractPostgreSqlPlatformTestCase extends AbstractPlatformTestCa
      *
      * @dataProvider pgBooleanProvider
      */
-    public function testConvertFromBoolean($databaseValue, string $prepareStatementValue, ?int $integerValue, ?bool $booleanValue) : void
-    {
+    public function testConvertFromBoolean(
+        $databaseValue,
+        string $prepareStatementValue,
+        ?int $integerValue,
+        ?bool $booleanValue
+    ): void {
         $platform = $this->createPlatform();
 
         self::assertSame($booleanValue, $platform->convertFromBoolean($databaseValue));
     }
 
-    public function testThrowsExceptionWithInvalidBooleanLiteral() : void
+    public function testThrowsExceptionWithInvalidBooleanLiteral(): void
     {
         $platform = $this->createPlatform();
 
@@ -506,14 +524,14 @@ abstract class AbstractPostgreSqlPlatformTestCase extends AbstractPlatformTestCa
         $platform->convertBooleansToDatabaseValue('my-bool');
     }
 
-    public function testGetCreateSchemaSQL() : void
+    public function testGetCreateSchemaSQL(): void
     {
         $schemaName = 'schema';
         $sql        = $this->platform->getCreateSchemaSQL($schemaName);
         self::assertEquals('CREATE SCHEMA ' . $schemaName, $sql);
     }
 
-    public function testAlterDecimalPrecisionScale() : void
+    public function testAlterDecimalPrecisionScale(): void
     {
         $table = new Table('mytable');
         $table->addColumn('dfoo1', 'decimal');
@@ -572,10 +590,7 @@ abstract class AbstractPostgreSqlPlatformTestCase extends AbstractPlatformTestCa
         self::assertEquals($expectedSql, $sql);
     }
 
-    /**
-     * @group DBAL-365
-     */
-    public function testDroppingConstraintsBeforeColumns() : void
+    public function testDroppingConstraintsBeforeColumns(): void
     {
         $newTable = new Table('mytable');
         $newTable->addColumn('id', 'integer');
@@ -585,10 +600,10 @@ abstract class AbstractPostgreSqlPlatformTestCase extends AbstractPlatformTestCa
         $oldTable->addColumn('parent_id', 'integer');
         $oldTable->addUnnamedForeignKeyConstraint('mytable', ['parent_id'], ['id']);
 
-        $comparator = new Comparator();
-        $tableDiff  = $comparator->diffTable($oldTable, $newTable);
+        $diff = (new Comparator())->diffTable($oldTable, $newTable);
+        self::assertNotFalse($diff);
 
-        $sql = $this->platform->getAlterTableSQL($tableDiff);
+        $sql = $this->platform->getAlterTableSQL($diff);
 
         $expectedSql = [
             'ALTER TABLE mytable DROP CONSTRAINT FK_6B2BD609727ACA70',
@@ -599,27 +614,20 @@ abstract class AbstractPostgreSqlPlatformTestCase extends AbstractPlatformTestCa
         self::assertEquals($expectedSql, $sql);
     }
 
-    /**
-     * @group DBAL-563
-     */
-    public function testUsesSequenceEmulatedIdentityColumns() : void
+    public function testUsesSequenceEmulatedIdentityColumns(): void
     {
         self::assertTrue($this->platform->usesSequenceEmulatedIdentityColumns());
     }
 
-    /**
-     * @group DBAL-563
-     */
-    public function testReturnsIdentitySequenceName() : void
+    public function testReturnsIdentitySequenceName(): void
     {
         self::assertSame('mytable_mycolumn_seq', $this->platform->getIdentitySequenceName('mytable', 'mycolumn'));
     }
 
     /**
      * @dataProvider dataCreateSequenceWithCache
-     * @group DBAL-139
      */
-    public function testCreateSequenceWithCache(int $cacheSize, string $expectedSql) : void
+    public function testCreateSequenceWithCache(int $cacheSize, string $expectedSql): void
     {
         $sequence = new Sequence('foo', 1, 1, $cacheSize);
         self::assertStringContainsString($expectedSql, $this->platform->getCreateSequenceSQL($sequence));
@@ -628,24 +636,24 @@ abstract class AbstractPostgreSqlPlatformTestCase extends AbstractPlatformTestCa
     /**
      * @return mixed[][]
      */
-    public static function dataCreateSequenceWithCache() : iterable
+    public static function dataCreateSequenceWithCache(): iterable
     {
         return [
             [3, 'CACHE 3'],
         ];
     }
 
-    protected function getBinaryDefaultLength() : int
+    protected function getBinaryDefaultLength(): int
     {
         return 0;
     }
 
-    protected function getBinaryMaxLength() : int
+    protected function getBinaryMaxLength(): int
     {
         return 0;
     }
 
-    public function testReturnsBinaryTypeDeclarationSQL() : void
+    public function testReturnsBinaryTypeDeclarationSQL(): void
     {
         self::assertSame('BYTEA', $this->platform->getBinaryTypeDeclarationSQL([]));
         self::assertSame('BYTEA', $this->platform->getBinaryTypeDeclarationSQL(['length' => 0]));
@@ -656,7 +664,7 @@ abstract class AbstractPostgreSqlPlatformTestCase extends AbstractPlatformTestCa
         self::assertSame('BYTEA', $this->platform->getBinaryTypeDeclarationSQL(['fixed' => true, 'length' => 9999999]));
     }
 
-    public function testDoesNotPropagateUnnecessaryTableAlterationOnBinaryType() : void
+    public function testDoesNotPropagateUnnecessaryTableAlterationOnBinaryType(): void
     {
         $table1 = new Table('mytable');
         $table1->addColumn('column_varbinary', 'binary');
@@ -673,7 +681,9 @@ abstract class AbstractPostgreSqlPlatformTestCase extends AbstractPlatformTestCa
         // VARBINARY -> BINARY
         // BINARY    -> VARBINARY
         // BLOB      -> VARBINARY
-        self::assertEmpty($this->platform->getAlterTableSQL($comparator->diffTable($table1, $table2)));
+        $diff = $comparator->diffTable($table1, $table2);
+        self::assertNotFalse($diff);
+        self::assertEmpty($this->platform->getAlterTableSQL($diff));
 
         $table2 = new Table('mytable');
         $table2->addColumn('column_varbinary', 'binary', ['length' => 42]);
@@ -683,7 +693,9 @@ abstract class AbstractPostgreSqlPlatformTestCase extends AbstractPlatformTestCa
         // VARBINARY -> VARBINARY with changed length
         // BINARY    -> BLOB
         // BLOB      -> BINARY
-        self::assertEmpty($this->platform->getAlterTableSQL($comparator->diffTable($table1, $table2)));
+        $diff = $comparator->diffTable($table1, $table2);
+        self::assertNotFalse($diff);
+        self::assertEmpty($this->platform->getAlterTableSQL($diff));
 
         $table2 = new Table('mytable');
         $table2->addColumn('column_varbinary', 'blob');
@@ -693,25 +705,23 @@ abstract class AbstractPostgreSqlPlatformTestCase extends AbstractPlatformTestCa
         // VARBINARY -> BLOB
         // BINARY    -> BINARY with changed length
         // BLOB      -> BLOB
-        self::assertEmpty($this->platform->getAlterTableSQL($comparator->diffTable($table1, $table2)));
+        $diff = $comparator->diffTable($table1, $table2);
+        self::assertNotFalse($diff);
+        self::assertEmpty($this->platform->getAlterTableSQL($diff));
     }
 
     /**
      * {@inheritDoc}
-     *
-     * @group DBAL-234
      */
-    protected function getAlterTableRenameIndexSQL() : array
+    protected function getAlterTableRenameIndexSQL(): array
     {
         return ['ALTER INDEX idx_foo RENAME TO idx_bar'];
     }
 
     /**
      * {@inheritDoc}
-     *
-     * @group DBAL-234
      */
-    protected function getQuotedAlterTableRenameIndexSQL() : array
+    protected function getQuotedAlterTableRenameIndexSQL(): array
     {
         return [
             'ALTER INDEX "create" RENAME TO "select"',
@@ -724,7 +734,7 @@ abstract class AbstractPostgreSqlPlatformTestCase extends AbstractPlatformTestCa
      *
      * @return mixed[][]
      */
-    public static function pgBooleanProvider() : iterable
+    public static function pgBooleanProvider(): iterable
     {
         return [
             // Database value, prepared statement value, boolean integer value, boolean value.
@@ -751,7 +761,7 @@ abstract class AbstractPostgreSqlPlatformTestCase extends AbstractPlatformTestCa
     /**
      * {@inheritdoc}
      */
-    protected function getQuotedAlterTableRenameColumnSQL() : array
+    protected function getQuotedAlterTableRenameColumnSQL(): array
     {
         return [
             'ALTER TABLE mytable RENAME COLUMN unquoted1 TO unquoted',
@@ -769,7 +779,7 @@ abstract class AbstractPostgreSqlPlatformTestCase extends AbstractPlatformTestCa
     /**
      * {@inheritdoc}
      */
-    protected function getQuotedAlterTableChangeColumnLengthSQL() : array
+    protected function getQuotedAlterTableChangeColumnLengthSQL(): array
     {
         return [
             'ALTER TABLE mytable ALTER unquoted1 TYPE VARCHAR(255)',
@@ -783,20 +793,16 @@ abstract class AbstractPostgreSqlPlatformTestCase extends AbstractPlatformTestCa
 
     /**
      * {@inheritDoc}
-     *
-     * @group DBAL-807
      */
-    protected function getAlterTableRenameIndexInSchemaSQL() : array
+    protected function getAlterTableRenameIndexInSchemaSQL(): array
     {
         return ['ALTER INDEX myschema.idx_foo RENAME TO idx_bar'];
     }
 
     /**
      * {@inheritDoc}
-     *
-     * @group DBAL-807
      */
-    protected function getQuotedAlterTableRenameIndexInSchemaSQL() : array
+    protected function getQuotedAlterTableRenameIndexInSchemaSQL(): array
     {
         return [
             'ALTER INDEX "schema"."create" RENAME TO "select"',
@@ -804,12 +810,12 @@ abstract class AbstractPostgreSqlPlatformTestCase extends AbstractPlatformTestCa
         ];
     }
 
-    protected function getQuotesDropForeignKeySQL() : string
+    protected function getQuotesDropForeignKeySQL(): string
     {
         return 'ALTER TABLE "table" DROP CONSTRAINT "select"';
     }
 
-    public function testGetNullCommentOnColumnSQL() : void
+    public function testGetNullCommentOnColumnSQL(): void
     {
         self::assertEquals(
             'COMMENT ON COLUMN mytable.id IS NULL',
@@ -817,10 +823,7 @@ abstract class AbstractPostgreSqlPlatformTestCase extends AbstractPlatformTestCa
         );
     }
 
-    /**
-     * @group DBAL-423
-     */
-    public function testReturnsGuidTypeDeclarationSQL() : void
+    public function testReturnsGuidTypeDeclarationSQL(): void
     {
         self::assertSame('UUID', $this->platform->getGuidTypeDeclarationSQL([]));
     }
@@ -828,7 +831,7 @@ abstract class AbstractPostgreSqlPlatformTestCase extends AbstractPlatformTestCa
     /**
      * {@inheritdoc}
      */
-    public function getAlterTableRenameColumnSQL() : array
+    public function getAlterTableRenameColumnSQL(): array
     {
         return ['ALTER TABLE foo RENAME COLUMN bar TO baz'];
     }
@@ -836,7 +839,7 @@ abstract class AbstractPostgreSqlPlatformTestCase extends AbstractPlatformTestCa
     /**
      * {@inheritdoc}
      */
-    protected function getQuotesTableIdentifiersInAlterTableSQL() : array
+    protected function getQuotesTableIdentifiersInAlterTableSQL(): array
     {
         return [
             'ALTER TABLE "foo" DROP CONSTRAINT fk1',
@@ -856,7 +859,7 @@ abstract class AbstractPostgreSqlPlatformTestCase extends AbstractPlatformTestCa
     /**
      * {@inheritdoc}
      */
-    protected function getCommentOnColumnSQL() : array
+    protected function getCommentOnColumnSQL(): array
     {
         return [
             'COMMENT ON COLUMN foo.bar IS \'comment\'',
@@ -865,10 +868,7 @@ abstract class AbstractPostgreSqlPlatformTestCase extends AbstractPlatformTestCa
         ];
     }
 
-    /**
-     * @group DBAL-1004
-     */
-    public function testAltersTableColumnCommentWithExplicitlyQuotedIdentifiers() : void
+    public function testAltersTableColumnCommentWithExplicitlyQuotedIdentifiers(): void
     {
         $table1 = new Table('"foo"', [new Column('"bar"', Type::getType('integer'))]);
         $table2 = new Table('"foo"', [new Column('"bar"', Type::getType('integer'), ['comment' => 'baz'])]);
@@ -884,10 +884,7 @@ abstract class AbstractPostgreSqlPlatformTestCase extends AbstractPlatformTestCa
         );
     }
 
-    /**
-     * @group 3158
-     */
-    public function testAltersTableColumnCommentIfRequiredByType() : void
+    public function testAltersTableColumnCommentIfRequiredByType(): void
     {
         $table1 = new Table('"foo"', [new Column('"bar"', Type::getType('datetime'))]);
         $table2 = new Table('"foo"', [new Column('"bar"', Type::getType('datetime_immutable'))]);
@@ -896,7 +893,7 @@ abstract class AbstractPostgreSqlPlatformTestCase extends AbstractPlatformTestCa
 
         $tableDiff = $comparator->diffTable($table1, $table2);
 
-        $this->assertInstanceOf('Doctrine\DBAL\Schema\TableDiff', $tableDiff);
+        $this->assertNotFalse($tableDiff);
         $this->assertSame(
             [
                 'ALTER TABLE "foo" ALTER "bar" TYPE TIMESTAMP(0) WITHOUT TIME ZONE',
@@ -907,26 +904,17 @@ abstract class AbstractPostgreSqlPlatformTestCase extends AbstractPlatformTestCa
         );
     }
 
-    /**
-     * {@inheritdoc}
-     */
-    protected function getQuotesReservedKeywordInUniqueConstraintDeclarationSQL() : string
+    protected function getQuotesReservedKeywordInUniqueConstraintDeclarationSQL(): string
     {
         return 'CONSTRAINT "select" UNIQUE (foo)';
     }
 
-    /**
-     * {@inheritdoc}
-     */
-    protected function getQuotesReservedKeywordInIndexDeclarationSQL() : string
+    protected function getQuotesReservedKeywordInIndexDeclarationSQL(): string
     {
         return 'INDEX "select" (foo)';
     }
 
-    /**
-     * {@inheritdoc}
-     */
-    protected function getQuotesReservedKeywordInTruncateTableSQL() : string
+    protected function getQuotesReservedKeywordInTruncateTableSQL(): string
     {
         return 'TRUNCATE "select"';
     }
@@ -934,7 +922,7 @@ abstract class AbstractPostgreSqlPlatformTestCase extends AbstractPlatformTestCa
     /**
      * {@inheritdoc}
      */
-    protected function getAlterStringToFixedStringSQL() : array
+    protected function getAlterStringToFixedStringSQL(): array
     {
         return ['ALTER TABLE mytable ALTER name TYPE CHAR(2)'];
     }
@@ -942,24 +930,18 @@ abstract class AbstractPostgreSqlPlatformTestCase extends AbstractPlatformTestCa
     /**
      * {@inheritdoc}
      */
-    protected function getGeneratesAlterTableRenameIndexUsedByForeignKeySQL() : array
+    protected function getGeneratesAlterTableRenameIndexUsedByForeignKeySQL(): array
     {
         return ['ALTER INDEX idx_foo RENAME TO idx_foo_renamed'];
     }
 
-    /**
-     * @group DBAL-1142
-     */
-    public function testInitializesTsvectorTypeMapping() : void
+    public function testInitializesTsvectorTypeMapping(): void
     {
         self::assertTrue($this->platform->hasDoctrineTypeMappingFor('tsvector'));
         self::assertEquals('text', $this->platform->getDoctrineTypeMapping('tsvector'));
     }
 
-    /**
-     * @group DBAL-1220
-     */
-    public function testReturnsDisallowDatabaseConnectionsSQL() : void
+    public function testReturnsDisallowDatabaseConnectionsSQL(): void
     {
         self::assertSame(
             "UPDATE pg_database SET datallowconn = 'false' WHERE datname = 'foo'",
@@ -967,10 +949,7 @@ abstract class AbstractPostgreSqlPlatformTestCase extends AbstractPlatformTestCa
         );
     }
 
-    /**
-     * @group DBAL-1220
-     */
-    public function testReturnsCloseActiveDatabaseConnectionsSQL() : void
+    public function testReturnsCloseActiveDatabaseConnectionsSQL(): void
     {
         self::assertSame(
             "SELECT pg_terminate_backend(procpid) FROM pg_stat_activity WHERE datname = 'foo'",
@@ -978,10 +957,7 @@ abstract class AbstractPostgreSqlPlatformTestCase extends AbstractPlatformTestCa
         );
     }
 
-    /**
-     * @group DBAL-2436
-     */
-    public function testQuotesTableNameInListTableForeignKeysSQL() : void
+    public function testQuotesTableNameInListTableForeignKeysSQL(): void
     {
         self::assertStringContainsStringIgnoringCase(
             "'Foo''Bar\\'",
@@ -989,10 +965,7 @@ abstract class AbstractPostgreSqlPlatformTestCase extends AbstractPlatformTestCa
         );
     }
 
-    /**
-     * @group DBAL-2436
-     */
-    public function testQuotesSchemaNameInListTableForeignKeysSQL() : void
+    public function testQuotesSchemaNameInListTableForeignKeysSQL(): void
     {
         self::assertStringContainsStringIgnoringCase(
             "'Foo''Bar\\'",
@@ -1000,10 +973,7 @@ abstract class AbstractPostgreSqlPlatformTestCase extends AbstractPlatformTestCa
         );
     }
 
-    /**
-     * @group DBAL-2436
-     */
-    public function testQuotesTableNameInListTableConstraintsSQL() : void
+    public function testQuotesTableNameInListTableConstraintsSQL(): void
     {
         self::assertStringContainsStringIgnoringCase(
             "'Foo''Bar\\'",
@@ -1011,10 +981,7 @@ abstract class AbstractPostgreSqlPlatformTestCase extends AbstractPlatformTestCa
         );
     }
 
-    /**
-     * @group DBAL-2436
-     */
-    public function testQuotesTableNameInListTableIndexesSQL() : void
+    public function testQuotesTableNameInListTableIndexesSQL(): void
     {
         self::assertStringContainsStringIgnoringCase(
             "'Foo''Bar\\'",
@@ -1022,10 +989,7 @@ abstract class AbstractPostgreSqlPlatformTestCase extends AbstractPlatformTestCa
         );
     }
 
-    /**
-     * @group DBAL-2436
-     */
-    public function testQuotesSchemaNameInListTableIndexesSQL() : void
+    public function testQuotesSchemaNameInListTableIndexesSQL(): void
     {
         self::assertStringContainsStringIgnoringCase(
             "'Foo''Bar\\'",
@@ -1033,10 +997,7 @@ abstract class AbstractPostgreSqlPlatformTestCase extends AbstractPlatformTestCa
         );
     }
 
-    /**
-     * @group DBAL-2436
-     */
-    public function testQuotesTableNameInListTableColumnsSQL() : void
+    public function testQuotesTableNameInListTableColumnsSQL(): void
     {
         self::assertStringContainsStringIgnoringCase(
             "'Foo''Bar\\'",
@@ -1044,10 +1005,7 @@ abstract class AbstractPostgreSqlPlatformTestCase extends AbstractPlatformTestCa
         );
     }
 
-    /**
-     * @group DBAL-2436
-     */
-    public function testQuotesSchemaNameInListTableColumnsSQL() : void
+    public function testQuotesSchemaNameInListTableColumnsSQL(): void
     {
         self::assertStringContainsStringIgnoringCase(
             "'Foo''Bar\\'",
@@ -1055,10 +1013,7 @@ abstract class AbstractPostgreSqlPlatformTestCase extends AbstractPlatformTestCa
         );
     }
 
-    /**
-     * @group DBAL-2436
-     */
-    public function testQuotesDatabaseNameInCloseActiveDatabaseConnectionsSQL() : void
+    public function testQuotesDatabaseNameInCloseActiveDatabaseConnectionsSQL(): void
     {
         self::assertStringContainsStringIgnoringCase(
             "'Foo''Bar\\'",
