@@ -2,7 +2,7 @@
 
 namespace Doctrine\Tests\DBAL\Platforms;
 
-use Doctrine\DBAL\DBALException;
+use Doctrine\DBAL\Exception;
 use Doctrine\DBAL\Platforms\AbstractPlatform;
 use Doctrine\DBAL\Platforms\OraclePlatform;
 use Doctrine\DBAL\Schema\Column;
@@ -14,6 +14,7 @@ use Doctrine\DBAL\Schema\Table;
 use Doctrine\DBAL\Schema\TableDiff;
 use Doctrine\DBAL\TransactionIsolationLevel;
 use Doctrine\DBAL\Types\Type;
+
 use function array_walk;
 use function preg_replace;
 use function sprintf;
@@ -22,10 +23,13 @@ use function uniqid;
 
 class OraclePlatformTest extends AbstractPlatformTestCase
 {
+    /** @var OraclePlatform */
+    protected $platform;
+
     /**
      * @return mixed[][]
      */
-    public static function dataValidIdentifiers() : iterable
+    public static function dataValidIdentifiers(): iterable
     {
         return [
             ['a'],
@@ -43,18 +47,18 @@ class OraclePlatformTest extends AbstractPlatformTestCase
     /**
      * @dataProvider dataValidIdentifiers
      */
-    public function testValidIdentifiers(string $identifier) : void
+    public function testValidIdentifiers(string $identifier): void
     {
         $platform = $this->createPlatform();
         $platform->assertValidIdentifier($identifier);
 
-        $this->addToAssertionCount(1);
+        $this->expectNotToPerformAssertions();
     }
 
     /**
      * @return mixed[][]
      */
-    public static function dataInvalidIdentifiers() : iterable
+    public static function dataInvalidIdentifiers(): iterable
     {
         return [
             ['1'],
@@ -68,28 +72,31 @@ class OraclePlatformTest extends AbstractPlatformTestCase
     /**
      * @dataProvider dataInvalidIdentifiers
      */
-    public function testInvalidIdentifiers(string $identifier) : void
+    public function testInvalidIdentifiers(string $identifier): void
     {
-        $this->expectException(DBALException::class);
+        $this->expectException(Exception::class);
 
         $platform = $this->createPlatform();
         $platform->assertValidIdentifier($identifier);
     }
 
-    public function createPlatform() : AbstractPlatform
+    /**
+     * @return OraclePlatform
+     */
+    public function createPlatform(): AbstractPlatform
     {
         return new OraclePlatform();
     }
 
-    public function getGenerateTableSql() : string
+    public function getGenerateTableSql(): string
     {
         return 'CREATE TABLE test (id NUMBER(10) NOT NULL, test VARCHAR2(255) DEFAULT NULL NULL, PRIMARY KEY(id))';
     }
 
     /**
-     * @return mixed[]
+     * {@inheritDoc}
      */
-    public function getGenerateTableWithMultiColumnUniqueIndexSql() : array
+    public function getGenerateTableWithMultiColumnUniqueIndexSql(): array
     {
         return [
             'CREATE TABLE test (foo VARCHAR2(255) DEFAULT NULL NULL, bar VARCHAR2(255) DEFAULT NULL NULL)',
@@ -100,30 +107,34 @@ class OraclePlatformTest extends AbstractPlatformTestCase
     /**
      * {@inheritDoc}
      */
-    public function getGenerateAlterTableSql() : array
+    public function getGenerateAlterTableSql(): array
     {
         return [
             'ALTER TABLE mytable ADD (quota NUMBER(10) DEFAULT NULL NULL)',
-            "ALTER TABLE mytable MODIFY (baz VARCHAR2(255) DEFAULT 'def' NOT NULL, bloo NUMBER(1) DEFAULT '0' NOT NULL)",
+            "ALTER TABLE mytable MODIFY (baz VARCHAR2(255) DEFAULT 'def' NOT NULL, "
+                . "bloo NUMBER(1) DEFAULT '0' NOT NULL)",
             'ALTER TABLE mytable DROP (foo)',
             'ALTER TABLE mytable RENAME TO userlist',
         ];
     }
 
-    public function testRLike() : void
+    public function testRLike(): void
     {
-        $this->expectException(DBALException::class);
+        $this->expectException(Exception::class);
 
-        self::assertEquals('RLIKE', $this->platform->getRegexpExpression(), 'Regular expression operator is not correct');
+        self::assertEquals('RLIKE', $this->platform->getRegexpExpression());
     }
 
-    public function testGeneratesSqlSnippets() : void
+    public function testGeneratesSqlSnippets(): void
     {
-        self::assertEquals('"', $this->platform->getIdentifierQuoteCharacter(), 'Identifier quote character is not correct');
-        self::assertEquals('column1 || column2 || column3', $this->platform->getConcatExpression('column1', 'column2', 'column3'), 'Concatenation expression is not correct');
+        self::assertEquals('"', $this->platform->getIdentifierQuoteCharacter());
+        self::assertEquals(
+            'column1 || column2 || column3',
+            $this->platform->getConcatExpression('column1', 'column2', 'column3')
+        );
     }
 
-    public function testGeneratesTransactionsCommands() : void
+    public function testGeneratesTransactionsCommands(): void
     {
         self::assertEquals(
             'SET TRANSACTION ISOLATION LEVEL READ UNCOMMITTED',
@@ -143,24 +154,24 @@ class OraclePlatformTest extends AbstractPlatformTestCase
         );
     }
 
-    public function testCreateDatabaseThrowsException() : void
+    public function testCreateDatabaseThrowsException(): void
     {
-        $this->expectException(DBALException::class);
+        $this->expectException(Exception::class);
 
         self::assertEquals('CREATE DATABASE foobar', $this->platform->getCreateDatabaseSQL('foobar'));
     }
 
-    public function testDropDatabaseThrowsException() : void
+    public function testDropDatabaseThrowsException(): void
     {
         self::assertEquals('DROP USER foobar CASCADE', $this->platform->getDropDatabaseSQL('foobar'));
     }
 
-    public function testDropTable() : void
+    public function testDropTable(): void
     {
         self::assertEquals('DROP TABLE foobar', $this->platform->getDropTableSQL('foobar'));
     }
 
-    public function testGeneratesTypeDeclarationForIntegers() : void
+    public function testGeneratesTypeDeclarationForIntegers(): void
     {
         self::assertEquals(
             'NUMBER(10)',
@@ -178,7 +189,7 @@ class OraclePlatformTest extends AbstractPlatformTestCase
         );
     }
 
-    public function testGeneratesTypeDeclarationsForStrings() : void
+    public function testGeneratesTypeDeclarationsForStrings(): void
     {
         self::assertEquals(
             'CHAR(10)',
@@ -188,50 +199,45 @@ class OraclePlatformTest extends AbstractPlatformTestCase
         );
         self::assertEquals(
             'VARCHAR2(50)',
-            $this->platform->getVarcharTypeDeclarationSQL(['length' => 50]),
-            'Variable string declaration is not correct'
+            $this->platform->getVarcharTypeDeclarationSQL(['length' => 50])
         );
         self::assertEquals(
             'VARCHAR2(255)',
-            $this->platform->getVarcharTypeDeclarationSQL([]),
-            'Long string declaration is not correct'
+            $this->platform->getVarcharTypeDeclarationSQL([])
         );
     }
 
-    public function testPrefersIdentityColumns() : void
+    public function testPrefersIdentityColumns(): void
     {
         self::assertFalse($this->platform->prefersIdentityColumns());
     }
 
-    public function testSupportsIdentityColumns() : void
+    public function testSupportsIdentityColumns(): void
     {
         self::assertFalse($this->platform->supportsIdentityColumns());
     }
 
-    public function testSupportsSavePoints() : void
+    public function testSupportsSavePoints(): void
     {
         self::assertTrue($this->platform->supportsSavepoints());
     }
 
-    /**
-     * {@inheritdoc}
-     */
-    protected function supportsCommentOnStatement() : bool
+    protected function supportsCommentOnStatement(): bool
     {
         return true;
     }
 
-    public function getGenerateIndexSql() : string
+    public function getGenerateIndexSql(): string
     {
         return 'CREATE INDEX my_idx ON mytable (user_name, last_login)';
     }
 
-    public function getGenerateUniqueIndexSql() : string
+    public function getGenerateUniqueIndexSql(): string
     {
         return 'CREATE UNIQUE INDEX index_name ON test (test, test2)';
     }
 
-    public function getGenerateForeignKeySql() : string
+    protected function getGenerateForeignKeySql(): string
     {
         return 'ALTER TABLE test ADD FOREIGN KEY (fk_name_id) REFERENCES other_table (id)';
     }
@@ -239,10 +245,9 @@ class OraclePlatformTest extends AbstractPlatformTestCase
     /**
      * @param mixed[] $options
      *
-     * @group DBAL-1097
      * @dataProvider getGeneratesAdvancedForeignKeyOptionsSQLData
      */
-    public function testGeneratesAdvancedForeignKeyOptionsSQL(array $options, string $expectedSql) : void
+    public function testGeneratesAdvancedForeignKeyOptionsSQL(array $options, string $expectedSql): void
     {
         $foreignKey = new ForeignKeyConstraint(['foo'], 'foreign_table', ['bar'], null, $options);
 
@@ -252,7 +257,7 @@ class OraclePlatformTest extends AbstractPlatformTestCase
     /**
      * @return mixed[][]
      */
-    public static function getGeneratesAdvancedForeignKeyOptionsSQLData() : iterable
+    public static function getGeneratesAdvancedForeignKeyOptionsSQLData(): iterable
     {
         return [
             [[], ''],
@@ -267,7 +272,7 @@ class OraclePlatformTest extends AbstractPlatformTestCase
     /**
      * {@inheritdoc}
      */
-    public static function getReturnsForeignKeyReferentialActionSQL() : iterable
+    public static function getReturnsForeignKeyReferentialActionSQL(): iterable
     {
         return [
             ['CASCADE', 'CASCADE'],
@@ -278,43 +283,55 @@ class OraclePlatformTest extends AbstractPlatformTestCase
         ];
     }
 
-    public function testModifyLimitQuery() : void
+    public function testModifyLimitQuery(): void
     {
         $sql = $this->platform->modifyLimitQuery('SELECT * FROM user', 10, 0);
         self::assertEquals('SELECT a.* FROM (SELECT * FROM user) a WHERE ROWNUM <= 10', $sql);
     }
 
-    public function testModifyLimitQueryWithEmptyOffset() : void
+    public function testModifyLimitQueryWithEmptyOffset(): void
     {
         $sql = $this->platform->modifyLimitQuery('SELECT * FROM user', 10);
         self::assertEquals('SELECT a.* FROM (SELECT * FROM user) a WHERE ROWNUM <= 10', $sql);
     }
 
-    public function testModifyLimitQueryWithNonEmptyOffset() : void
+    public function testModifyLimitQueryWithNonEmptyOffset(): void
     {
         $sql = $this->platform->modifyLimitQuery('SELECT * FROM user', 10, 10);
-        self::assertEquals('SELECT * FROM (SELECT a.*, ROWNUM AS doctrine_rownum FROM (SELECT * FROM user) a WHERE ROWNUM <= 20) WHERE doctrine_rownum >= 11', $sql);
+
+        self::assertEquals(
+            'SELECT * FROM ('
+                . 'SELECT a.*, ROWNUM AS doctrine_rownum FROM (SELECT * FROM user) a WHERE ROWNUM <= 20'
+                . ') WHERE doctrine_rownum >= 11',
+            $sql
+        );
     }
 
-    public function testModifyLimitQueryWithEmptyLimit() : void
+    public function testModifyLimitQueryWithEmptyLimit(): void
     {
         $sql = $this->platform->modifyLimitQuery('SELECT * FROM user', null, 10);
-        self::assertEquals('SELECT * FROM (SELECT a.*, ROWNUM AS doctrine_rownum FROM (SELECT * FROM user) a) WHERE doctrine_rownum >= 11', $sql);
+
+        self::assertEquals(
+            'SELECT * FROM ('
+                . 'SELECT a.*, ROWNUM AS doctrine_rownum FROM (SELECT * FROM user) a'
+                . ') WHERE doctrine_rownum >= 11',
+            $sql
+        );
     }
 
-    public function testModifyLimitQueryWithAscOrderBy() : void
+    public function testModifyLimitQueryWithAscOrderBy(): void
     {
         $sql = $this->platform->modifyLimitQuery('SELECT * FROM user ORDER BY username ASC', 10);
         self::assertEquals('SELECT a.* FROM (SELECT * FROM user ORDER BY username ASC) a WHERE ROWNUM <= 10', $sql);
     }
 
-    public function testModifyLimitQueryWithDescOrderBy() : void
+    public function testModifyLimitQueryWithDescOrderBy(): void
     {
         $sql = $this->platform->modifyLimitQuery('SELECT * FROM user ORDER BY username DESC', 10);
         self::assertEquals('SELECT a.* FROM (SELECT * FROM user ORDER BY username DESC) a WHERE ROWNUM <= 10', $sql);
     }
 
-    public function testGenerateTableWithAutoincrement() : void
+    public function testGenerateTableWithAutoincrement(): void
     {
         $columnName = strtoupper('id' . uniqid());
         $tableName  = strtoupper('table' . uniqid());
@@ -324,7 +341,17 @@ class OraclePlatformTest extends AbstractPlatformTestCase
         $targets    = [
             sprintf('CREATE TABLE %s (%s NUMBER(10) NOT NULL)', $tableName, $columnName),
             sprintf(
-                "DECLARE constraints_Count NUMBER; BEGIN SELECT COUNT(CONSTRAINT_NAME) INTO constraints_Count FROM USER_CONSTRAINTS WHERE TABLE_NAME = '%s' AND CONSTRAINT_TYPE = 'P'; IF constraints_Count = 0 OR constraints_Count = '' THEN EXECUTE IMMEDIATE 'ALTER TABLE %s ADD CONSTRAINT %s_AI_PK PRIMARY KEY (%s)'; END IF; END;",
+                'DECLARE constraints_Count NUMBER;'
+                    . ' BEGIN'
+                    . ' SELECT COUNT(CONSTRAINT_NAME)'
+                    . ' INTO constraints_Count'
+                    . ' FROM USER_CONSTRAINTS'
+                    . " WHERE TABLE_NAME = '%s' AND CONSTRAINT_TYPE = 'P';"
+                    . " IF constraints_Count = 0 OR constraints_Count = ''"
+                    . ' THEN EXECUTE IMMEDIATE'
+                    . " 'ALTER TABLE %s ADD CONSTRAINT %s_AI_PK PRIMARY KEY (%s)';"
+                    . ' END IF;'
+                    . ' END;',
                 $tableName,
                 $tableName,
                 $tableName,
@@ -332,7 +359,20 @@ class OraclePlatformTest extends AbstractPlatformTestCase
             ),
             sprintf('CREATE SEQUENCE %s_SEQ START WITH 1 MINVALUE 1 INCREMENT BY 1', $tableName),
             sprintf(
-                "CREATE TRIGGER %s_AI_PK BEFORE INSERT ON %s FOR EACH ROW DECLARE last_Sequence NUMBER; last_InsertID NUMBER; BEGIN SELECT %s_SEQ.NEXTVAL INTO :NEW.%s FROM DUAL; IF (:NEW.%s IS NULL OR :NEW.%s = 0) THEN SELECT %s_SEQ.NEXTVAL INTO :NEW.%s FROM DUAL; ELSE SELECT NVL(Last_Number, 0) INTO last_Sequence FROM User_Sequences WHERE Sequence_Name = '%s_SEQ'; SELECT :NEW.%s INTO last_InsertID FROM DUAL; WHILE (last_InsertID > last_Sequence) LOOP SELECT %s_SEQ.NEXTVAL INTO last_Sequence FROM DUAL; END LOOP; END IF; END;",
+                'CREATE TRIGGER %s_AI_PK BEFORE INSERT ON %s FOR EACH ROW DECLARE last_Sequence NUMBER;'
+                . ' last_InsertID NUMBER;'
+                . ' BEGIN SELECT %s_SEQ.NEXTVAL'
+                . ' INTO :NEW.%s FROM DUAL;'
+                . ' IF (:NEW.%s IS NULL OR :NEW.%s = 0)'
+                . ' THEN SELECT %s_SEQ.NEXTVAL INTO :NEW.%s FROM DUAL;'
+                . ' ELSE SELECT NVL(Last_Number, 0) INTO last_Sequence'
+                . " FROM User_Sequences WHERE Sequence_Name = '%s_SEQ';"
+                . ' SELECT :NEW.%s INTO last_InsertID FROM DUAL;'
+                . ' WHILE (last_InsertID > last_Sequence) LOOP'
+                . ' SELECT %s_SEQ.NEXTVAL INTO last_Sequence FROM DUAL;'
+                . ' END LOOP;'
+                . ' END IF;'
+                . ' END;',
                 $tableName,
                 $tableName,
                 $tableName,
@@ -348,7 +388,7 @@ class OraclePlatformTest extends AbstractPlatformTestCase
         ];
         $statements = $this->platform->getCreateTableSQL($table);
         //strip all the whitespace from the statements
-        array_walk($statements, static function (&$value) : void {
+        array_walk($statements, static function (&$value): void {
             $value = preg_replace('/\s+/', ' ', $value);
         });
         foreach ($targets as $key => $sql) {
@@ -360,7 +400,7 @@ class OraclePlatformTest extends AbstractPlatformTestCase
     /**
      * {@inheritDoc}
      */
-    public function getCreateTableColumnCommentsSQL() : array
+    public function getCreateTableColumnCommentsSQL(): array
     {
         return [
             'CREATE TABLE test (id NUMBER(10) NOT NULL, PRIMARY KEY(id))',
@@ -371,7 +411,7 @@ class OraclePlatformTest extends AbstractPlatformTestCase
     /**
      * {@inheritDoc}
      */
-    public function getCreateTableColumnTypeCommentsSQL() : array
+    public function getCreateTableColumnTypeCommentsSQL(): array
     {
         return [
             'CREATE TABLE test (id NUMBER(10) NOT NULL, data CLOB NOT NULL, PRIMARY KEY(id))',
@@ -382,7 +422,7 @@ class OraclePlatformTest extends AbstractPlatformTestCase
     /**
      * {@inheritDoc}
      */
-    public function getAlterTableColumnCommentsSQL() : array
+    public function getAlterTableColumnCommentsSQL(): array
     {
         return [
             'ALTER TABLE mytable ADD (quota NUMBER(10) NOT NULL)',
@@ -392,12 +432,12 @@ class OraclePlatformTest extends AbstractPlatformTestCase
         ];
     }
 
-    public function getBitAndComparisonExpressionSql(string $value1, string $value2) : string
+    public function getBitAndComparisonExpressionSql(string $value1, string $value2): string
     {
         return 'BITAND(' . $value1 . ', ' . $value2 . ')';
     }
 
-    public function getBitOrComparisonExpressionSql(string $value1, string $value2) : string
+    public function getBitOrComparisonExpressionSql(string $value1, string $value2): string
     {
         return '(' . $value1 . '-' .
         $this->getBitAndComparisonExpressionSql($value1, $value2)
@@ -405,17 +445,17 @@ class OraclePlatformTest extends AbstractPlatformTestCase
     }
 
     /**
-     * @return mixed[]
+     * {@inheritDoc}
      */
-    protected function getQuotedColumnInPrimaryKeySQL() : array
+    protected function getQuotedColumnInPrimaryKeySQL(): array
     {
         return ['CREATE TABLE "quoted" ("create" VARCHAR2(255) NOT NULL, PRIMARY KEY("create"))'];
     }
 
     /**
-     * @return mixed[]
+     * {@inheritDoc}
      */
-    protected function getQuotedColumnInIndexSQL() : array
+    protected function getQuotedColumnInIndexSQL(): array
     {
         return [
             'CREATE TABLE "quoted" ("create" VARCHAR2(255) NOT NULL)',
@@ -424,9 +464,9 @@ class OraclePlatformTest extends AbstractPlatformTestCase
     }
 
     /**
-     * @return mixed[]
+     * {@inheritDoc}
      */
-    protected function getQuotedNameInIndexSQL() : array
+    protected function getQuotedNameInIndexSQL(): array
     {
         return [
             'CREATE TABLE test (column1 VARCHAR2(255) NOT NULL)',
@@ -435,23 +475,23 @@ class OraclePlatformTest extends AbstractPlatformTestCase
     }
 
     /**
-     * @return mixed[]
+     * {@inheritDoc}
      */
-    protected function getQuotedColumnInForeignKeySQL() : array
+    protected function getQuotedColumnInForeignKeySQL(): array
     {
         return [
-            'CREATE TABLE "quoted" ("create" VARCHAR2(255) NOT NULL, foo VARCHAR2(255) NOT NULL, "bar" VARCHAR2(255) NOT NULL)',
-            'ALTER TABLE "quoted" ADD CONSTRAINT FK_WITH_RESERVED_KEYWORD FOREIGN KEY ("create", foo, "bar") REFERENCES foreign ("create", bar, "foo-bar")',
-            'ALTER TABLE "quoted" ADD CONSTRAINT FK_WITH_NON_RESERVED_KEYWORD FOREIGN KEY ("create", foo, "bar") REFERENCES foo ("create", bar, "foo-bar")',
-            'ALTER TABLE "quoted" ADD CONSTRAINT FK_WITH_INTENDED_QUOTATION FOREIGN KEY ("create", foo, "bar") REFERENCES "foo-bar" ("create", bar, "foo-bar")',
+            'CREATE TABLE "quoted" ("create" VARCHAR2(255) NOT NULL, foo VARCHAR2(255) NOT NULL, '
+                . '"bar" VARCHAR2(255) NOT NULL)',
+            'ALTER TABLE "quoted" ADD CONSTRAINT FK_WITH_RESERVED_KEYWORD FOREIGN KEY ("create", foo, "bar")'
+                . ' REFERENCES foreign ("create", bar, "foo-bar")',
+            'ALTER TABLE "quoted" ADD CONSTRAINT FK_WITH_NON_RESERVED_KEYWORD FOREIGN KEY ("create", foo, "bar")'
+                . ' REFERENCES foo ("create", bar, "foo-bar")',
+            'ALTER TABLE "quoted" ADD CONSTRAINT FK_WITH_INTENDED_QUOTATION FOREIGN KEY ("create", foo, "bar")'
+                . ' REFERENCES "foo-bar" ("create", bar, "foo-bar")',
         ];
     }
 
-    /**
-     * @group DBAL-472
-     * @group DBAL-1001
-     */
-    public function testAlterTableNotNULL() : void
+    public function testAlterTableNotNULL(): void
     {
         $tableDiff                          = new TableDiff('mytable');
         $tableDiff->changedColumns['foo']   = new ColumnDiff(
@@ -482,14 +522,15 @@ class OraclePlatformTest extends AbstractPlatformTestCase
             ['notnull']
         );
 
-        $expectedSql = ["ALTER TABLE mytable MODIFY (foo VARCHAR2(255) DEFAULT 'bla', baz VARCHAR2(255) DEFAULT 'bla' NOT NULL, metar VARCHAR2(2000) DEFAULT NULL NULL)"];
+        $expectedSql = [
+            "ALTER TABLE mytable MODIFY (foo VARCHAR2(255) DEFAULT 'bla', baz VARCHAR2(255) DEFAULT 'bla' NOT NULL, "
+                . 'metar VARCHAR2(2000) DEFAULT NULL NULL)',
+        ];
+
         self::assertEquals($expectedSql, $this->platform->getAlterTableSQL($tableDiff));
     }
 
-    /**
-     * @group DBAL-2555
-     */
-    public function testInitializesDoctrineTypeMappings() : void
+    public function testInitializesDoctrineTypeMappings(): void
     {
         self::assertTrue($this->platform->hasDoctrineTypeMappingFor('long raw'));
         self::assertSame('blob', $this->platform->getDoctrineTypeMapping('long raw'));
@@ -501,12 +542,12 @@ class OraclePlatformTest extends AbstractPlatformTestCase
         self::assertSame('date', $this->platform->getDoctrineTypeMapping('date'));
     }
 
-    protected function getBinaryMaxLength() : int
+    protected function getBinaryMaxLength(): int
     {
         return 2000;
     }
 
-    public function testReturnsBinaryTypeDeclarationSQL() : void
+    public function testReturnsBinaryTypeDeclarationSQL(): void
     {
         self::assertSame('RAW(255)', $this->platform->getBinaryTypeDeclarationSQL([]));
         self::assertSame('RAW(2000)', $this->platform->getBinaryTypeDeclarationSQL(['length' => 0]));
@@ -514,20 +555,20 @@ class OraclePlatformTest extends AbstractPlatformTestCase
 
         self::assertSame('RAW(255)', $this->platform->getBinaryTypeDeclarationSQL(['fixed' => true]));
         self::assertSame('RAW(2000)', $this->platform->getBinaryTypeDeclarationSQL(['fixed' => true, 'length' => 0]));
-        self::assertSame('RAW(2000)', $this->platform->getBinaryTypeDeclarationSQL(['fixed' => true, 'length' => 2000]));
+
+        self::assertSame(
+            'RAW(2000)',
+            $this->platform->getBinaryTypeDeclarationSQL(['fixed' => true, 'length' => 2000])
+        );
     }
 
-    /**
-     * @group legacy
-     * @expectedDeprecation Binary field length 2001 is greater than supported by the platform (2000). Reduce the field length or use a BLOB field instead.
-     */
-    public function testReturnsBinaryTypeLongerThanMaxDeclarationSQL() : void
+    public function testReturnsBinaryTypeLongerThanMaxDeclarationSQL(): void
     {
         self::assertSame('BLOB', $this->platform->getBinaryTypeDeclarationSQL(['length' => 2001]));
         self::assertSame('BLOB', $this->platform->getBinaryTypeDeclarationSQL(['fixed' => true, 'length' => 2001]));
     }
 
-    public function testDoesNotPropagateUnnecessaryTableAlterationOnBinaryType() : void
+    public function testDoesNotPropagateUnnecessaryTableAlterationOnBinaryType(): void
     {
         $table1 = new Table('mytable');
         $table1->addColumn('column_varbinary', 'binary');
@@ -541,22 +582,17 @@ class OraclePlatformTest extends AbstractPlatformTestCase
 
         // VARBINARY -> BINARY
         // BINARY    -> VARBINARY
-        self::assertEmpty($this->platform->getAlterTableSQL($comparator->diffTable($table1, $table2)));
+        $diff = (new Comparator())->diffTable($table1, $table2);
+        self::assertNotFalse($diff);
+        self::assertEmpty($this->platform->getAlterTableSQL($diff));
     }
 
-    /**
-     * @group DBAL-563
-     */
-    public function testUsesSequenceEmulatedIdentityColumns() : void
+    public function testUsesSequenceEmulatedIdentityColumns(): void
     {
         self::assertTrue($this->platform->usesSequenceEmulatedIdentityColumns());
     }
 
-    /**
-     * @group DBAL-563
-     * @group DBAL-831
-     */
-    public function testReturnsIdentitySequenceName() : void
+    public function testReturnsIdentitySequenceName(): void
     {
         self::assertSame('MYTABLE_SEQ', $this->platform->getIdentitySequenceName('mytable', 'mycolumn'));
         self::assertSame('"mytable_SEQ"', $this->platform->getIdentitySequenceName('"mytable"', 'mycolumn'));
@@ -566,9 +602,8 @@ class OraclePlatformTest extends AbstractPlatformTestCase
 
     /**
      * @dataProvider dataCreateSequenceWithCache
-     * @group DBAL-139
      */
-    public function testCreateSequenceWithCache(int $cacheSize, string $expectedSql) : void
+    public function testCreateSequenceWithCache(int $cacheSize, string $expectedSql): void
     {
         $sequence = new Sequence('foo', 1, 1, $cacheSize);
         self::assertStringContainsString($expectedSql, $this->platform->getCreateSequenceSQL($sequence));
@@ -577,7 +612,7 @@ class OraclePlatformTest extends AbstractPlatformTestCase
     /**
      * @return mixed[][]
      */
-    public static function dataCreateSequenceWithCache() : iterable
+    public static function dataCreateSequenceWithCache(): iterable
     {
         return [
             [1, 'NOCACHE'],
@@ -588,20 +623,16 @@ class OraclePlatformTest extends AbstractPlatformTestCase
 
     /**
      * {@inheritDoc}
-     *
-     * @group DBAL-234
      */
-    protected function getAlterTableRenameIndexSQL() : array
+    protected function getAlterTableRenameIndexSQL(): array
     {
         return ['ALTER INDEX idx_foo RENAME TO idx_bar'];
     }
 
     /**
      * {@inheritDoc}
-     *
-     * @group DBAL-234
      */
-    protected function getQuotedAlterTableRenameIndexSQL() : array
+    protected function getQuotedAlterTableRenameIndexSQL(): array
     {
         return [
             'ALTER INDEX "create" RENAME TO "select"',
@@ -612,7 +643,7 @@ class OraclePlatformTest extends AbstractPlatformTestCase
     /**
      * {@inheritdoc}
      */
-    protected function getQuotedAlterTableRenameColumnSQL() : array
+    protected function getQuotedAlterTableRenameColumnSQL(): array
     {
         return [
             'ALTER TABLE mytable RENAME COLUMN unquoted1 TO unquoted',
@@ -630,27 +661,23 @@ class OraclePlatformTest extends AbstractPlatformTestCase
     /**
      * {@inheritdoc}
      */
-    protected function getQuotedAlterTableChangeColumnLengthSQL() : array
+    protected function getQuotedAlterTableChangeColumnLengthSQL(): array
     {
         $this->markTestIncomplete('Not implemented yet');
     }
 
     /**
      * {@inheritDoc}
-     *
-     * @group DBAL-807
      */
-    protected function getAlterTableRenameIndexInSchemaSQL() : array
+    protected function getAlterTableRenameIndexInSchemaSQL(): array
     {
         return ['ALTER INDEX myschema.idx_foo RENAME TO idx_bar'];
     }
 
     /**
      * {@inheritDoc}
-     *
-     * @group DBAL-807
      */
-    protected function getQuotedAlterTableRenameIndexInSchemaSQL() : array
+    protected function getQuotedAlterTableRenameIndexInSchemaSQL(): array
     {
         return [
             'ALTER INDEX "schema"."create" RENAME TO "select"',
@@ -658,15 +685,12 @@ class OraclePlatformTest extends AbstractPlatformTestCase
         ];
     }
 
-    protected function getQuotesDropForeignKeySQL() : string
+    protected function getQuotesDropForeignKeySQL(): string
     {
         return 'ALTER TABLE "table" DROP CONSTRAINT "select"';
     }
 
-    /**
-     * @group DBAL-423
-     */
-    public function testReturnsGuidTypeDeclarationSQL() : void
+    public function testReturnsGuidTypeDeclarationSQL(): void
     {
         self::assertSame('CHAR(36)', $this->platform->getGuidTypeDeclarationSQL([]));
     }
@@ -674,7 +698,7 @@ class OraclePlatformTest extends AbstractPlatformTestCase
     /**
      * {@inheritdoc}
      */
-    public function getAlterTableRenameColumnSQL() : array
+    public function getAlterTableRenameColumnSQL(): array
     {
         return ['ALTER TABLE foo RENAME COLUMN bar TO baz'];
     }
@@ -683,9 +707,8 @@ class OraclePlatformTest extends AbstractPlatformTestCase
      * @param string[] $expectedSql
      *
      * @dataProvider getReturnsDropAutoincrementSQL
-     * @group DBAL-831
      */
-    public function testReturnsDropAutoincrementSQL(string $table, array $expectedSql) : void
+    public function testReturnsDropAutoincrementSQL(string $table, array $expectedSql): void
     {
         self::assertSame($expectedSql, $this->platform->getDropAutoincrementSql($table));
     }
@@ -693,7 +716,7 @@ class OraclePlatformTest extends AbstractPlatformTestCase
     /**
      * @return mixed[][]
      */
-    public static function getReturnsDropAutoincrementSQL() : iterable
+    public static function getReturnsDropAutoincrementSQL(): iterable
     {
         return [
             [
@@ -726,7 +749,7 @@ class OraclePlatformTest extends AbstractPlatformTestCase
     /**
      * {@inheritdoc}
      */
-    protected function getQuotesTableIdentifiersInAlterTableSQL() : array
+    protected function getQuotesTableIdentifiersInAlterTableSQL(): array
     {
         return [
             'ALTER TABLE "foo" DROP CONSTRAINT fk1',
@@ -744,7 +767,7 @@ class OraclePlatformTest extends AbstractPlatformTestCase
     /**
      * {@inheritdoc}
      */
-    protected function getCommentOnColumnSQL() : array
+    protected function getCommentOnColumnSQL(): array
     {
         return [
             'COMMENT ON COLUMN foo.bar IS \'comment\'',
@@ -753,10 +776,7 @@ class OraclePlatformTest extends AbstractPlatformTestCase
         ];
     }
 
-    /**
-     * @group DBAL-1004
-     */
-    public function testAltersTableColumnCommentWithExplicitlyQuotedIdentifiers() : void
+    public function testAltersTableColumnCommentWithExplicitlyQuotedIdentifiers(): void
     {
         $table1 = new Table('"foo"', [new Column('"bar"', Type::getType('integer'))]);
         $table2 = new Table('"foo"', [new Column('"bar"', Type::getType('integer'), ['comment' => 'baz'])]);
@@ -772,7 +792,7 @@ class OraclePlatformTest extends AbstractPlatformTestCase
         );
     }
 
-    public function testQuotedTableNames() : void
+    public function testQuotedTableNames(): void
     {
         $table = new Table('"test"');
         $table->addColumn('"id"', 'integer', ['autoincrement' => true]);
@@ -814,9 +834,8 @@ EOD;
 
     /**
      * @dataProvider getReturnsGetListTableColumnsSQL
-     * @group DBAL-831
      */
-    public function testReturnsGetListTableColumnsSQL(?string $database, string $expectedSql) : void
+    public function testReturnsGetListTableColumnsSQL(?string $database, string $expectedSql): void
     {
         // note: this assertion is a bit strict, as it compares a full SQL string.
         // Should this break in future, then please try to reduce the matching to substring matching while reworking
@@ -827,7 +846,7 @@ EOD;
     /**
      * @return mixed[][]
      */
-    public static function getReturnsGetListTableColumnsSQL() : iterable
+    public static function getReturnsGetListTableColumnsSQL(): iterable
     {
         return [
             [
@@ -844,7 +863,7 @@ FROM     user_tab_columns c
 WHERE    c.table_name = 'test'
 ORDER BY c.column_id
 SQL
-                ,
+,
             ],
             [
                 '/',
@@ -860,7 +879,7 @@ FROM     user_tab_columns c
 WHERE    c.table_name = 'test'
 ORDER BY c.column_id
 SQL
-                ,
+,
             ],
             [
                 'scott',
@@ -876,31 +895,22 @@ FROM     all_tab_columns c
 WHERE    c.table_name = 'test' AND c.owner = 'SCOTT'
 ORDER BY c.column_id
 SQL
-                ,
+,
             ],
         ];
     }
 
-    /**
-     * {@inheritdoc}
-     */
-    protected function getQuotesReservedKeywordInUniqueConstraintDeclarationSQL() : string
+    protected function getQuotesReservedKeywordInUniqueConstraintDeclarationSQL(): string
     {
         return 'CONSTRAINT "select" UNIQUE (foo)';
     }
 
-    /**
-     * {@inheritdoc}
-     */
-    protected function getQuotesReservedKeywordInIndexDeclarationSQL() : string
+    protected function getQuotesReservedKeywordInIndexDeclarationSQL(): string
     {
         return 'INDEX "select" (foo)';
     }
 
-    /**
-     * {@inheritdoc}
-     */
-    protected function getQuotesReservedKeywordInTruncateTableSQL() : string
+    protected function getQuotesReservedKeywordInTruncateTableSQL(): string
     {
         return 'TRUNCATE TABLE "select"';
     }
@@ -908,7 +918,7 @@ SQL
     /**
      * {@inheritdoc}
      */
-    protected function getAlterStringToFixedStringSQL() : array
+    protected function getAlterStringToFixedStringSQL(): array
     {
         return ['ALTER TABLE mytable MODIFY (name CHAR(2) DEFAULT NULL)'];
     }
@@ -916,15 +926,12 @@ SQL
     /**
      * {@inheritdoc}
      */
-    protected function getGeneratesAlterTableRenameIndexUsedByForeignKeySQL() : array
+    protected function getGeneratesAlterTableRenameIndexUsedByForeignKeySQL(): array
     {
         return ['ALTER INDEX idx_foo RENAME TO idx_foo_renamed'];
     }
 
-    /**
-     * @group DBAL-2436
-     */
-    public function testQuotesDatabaseNameInListSequencesSQL() : void
+    public function testQuotesDatabaseNameInListSequencesSQL(): void
     {
         self::assertStringContainsStringIgnoringCase(
             "'Foo''Bar\\'",
@@ -932,10 +939,7 @@ SQL
         );
     }
 
-    /**
-     * @group DBAL-2436
-     */
-    public function testQuotesTableNameInListTableIndexesSQL() : void
+    public function testQuotesTableNameInListTableIndexesSQL(): void
     {
         self::assertStringContainsStringIgnoringCase(
             "'Foo''Bar\\'",
@@ -943,10 +947,7 @@ SQL
         );
     }
 
-    /**
-     * @group DBAL-2436
-     */
-    public function testQuotesTableNameInListTableForeignKeysSQL() : void
+    public function testQuotesTableNameInListTableForeignKeysSQL(): void
     {
         self::assertStringContainsStringIgnoringCase(
             "'Foo''Bar\\'",
@@ -954,10 +955,7 @@ SQL
         );
     }
 
-    /**
-     * @group DBAL-2436
-     */
-    public function testQuotesTableNameInListTableConstraintsSQL() : void
+    public function testQuotesTableNameInListTableConstraintsSQL(): void
     {
         self::assertStringContainsStringIgnoringCase(
             "'Foo''Bar\\'",
@@ -965,10 +963,7 @@ SQL
         );
     }
 
-    /**
-     * @group DBAL-2436
-     */
-    public function testQuotesTableNameInListTableColumnsSQL() : void
+    public function testQuotesTableNameInListTableColumnsSQL(): void
     {
         self::assertStringContainsStringIgnoringCase(
             "'Foo''Bar\\'",
@@ -976,14 +971,22 @@ SQL
         );
     }
 
-    /**
-     * @group DBAL-2436
-     */
-    public function testQuotesDatabaseNameInListTableColumnsSQL() : void
+    public function testQuotesDatabaseNameInListTableColumnsSQL(): void
     {
         self::assertStringContainsStringIgnoringCase(
             "'Foo''Bar\\'",
             $this->platform->getListTableColumnsSQL('foo_table', "Foo'Bar\\")
         );
     }
+
+    /**
+     * @return array<int, array{string, array<string, mixed>}>
+     */
+    public function asciiStringSqlDeclarationDataProvider(): array
+    {
+        return [
+            ['VARCHAR2(12)', ['length' => 12]],
+            ['CHAR(12)', ['length' => 12, 'fixed' => true]],
+        ];
+    }
 }
