@@ -2,7 +2,7 @@
 
 namespace Doctrine\Tests\DBAL\Platforms;
 
-use Doctrine\DBAL\DBALException;
+use Doctrine\DBAL\Exception;
 use Doctrine\DBAL\Platforms\AbstractPlatform;
 use Doctrine\DBAL\Platforms\SqlitePlatform;
 use Doctrine\DBAL\Schema\Column;
@@ -13,12 +13,18 @@ use Doctrine\DBAL\Types\Type;
 
 class SqlitePlatformTest extends AbstractPlatformTestCase
 {
-    public function createPlatform() : AbstractPlatform
+    /** @var SqlitePlatform */
+    protected $platform;
+
+    /**
+     * @return SqlitePlatform
+     */
+    public function createPlatform(): AbstractPlatform
     {
         return new SqlitePlatform();
     }
 
-    public function getGenerateTableSql() : string
+    public function getGenerateTableSql(): string
     {
         return 'CREATE TABLE test (id INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL, test VARCHAR(255) DEFAULT NULL)';
     }
@@ -26,7 +32,7 @@ class SqlitePlatformTest extends AbstractPlatformTestCase
     /**
      * {@inheritDoc}
      */
-    public function getGenerateTableWithMultiColumnUniqueIndexSql() : array
+    public function getGenerateTableWithMultiColumnUniqueIndexSql(): array
     {
         return [
             'CREATE TABLE test (foo VARCHAR(255) DEFAULT NULL, bar VARCHAR(255) DEFAULT NULL)',
@@ -34,14 +40,14 @@ class SqlitePlatformTest extends AbstractPlatformTestCase
         ];
     }
 
-    public function testGeneratesSqlSnippets() : void
+    public function testGeneratesSqlSnippets(): void
     {
-        self::assertEquals('REGEXP', $this->platform->getRegexpExpression(), 'Regular expression operator is not correct');
-        self::assertEquals('SUBSTR(column, 5, LENGTH(column))', $this->platform->getSubstringExpression('column', 5), 'Substring expression without length is not correct');
-        self::assertEquals('SUBSTR(column, 0, 5)', $this->platform->getSubstringExpression('column', 0, 5), 'Substring expression with length is not correct');
+        self::assertEquals('REGEXP', $this->platform->getRegexpExpression());
+        self::assertEquals('SUBSTR(column, 5, LENGTH(column))', $this->platform->getSubstringExpression('column', 5));
+        self::assertEquals('SUBSTR(column, 0, 5)', $this->platform->getSubstringExpression('column', 0, 5));
     }
 
-    public function testGeneratesTransactionCommands() : void
+    public function testGeneratesTransactionCommands(): void
     {
         self::assertEquals(
             'PRAGMA read_uncommitted = 0',
@@ -61,12 +67,12 @@ class SqlitePlatformTest extends AbstractPlatformTestCase
         );
     }
 
-    public function testPrefersIdentityColumns() : void
+    public function testPrefersIdentityColumns(): void
     {
         self::assertTrue($this->platform->prefersIdentityColumns());
     }
 
-    public function testIgnoresUnsignedIntegerDeclarationForAutoIncrementalIntegers() : void
+    public function testIgnoresUnsignedIntegerDeclarationForAutoIncrementalIntegers(): void
     {
         self::assertSame(
             'INTEGER PRIMARY KEY AUTOINCREMENT',
@@ -74,11 +80,7 @@ class SqlitePlatformTest extends AbstractPlatformTestCase
         );
     }
 
-    /**
-     * @group DBAL-752
-     * @group DBAL-924
-     */
-    public function testGeneratesTypeDeclarationForTinyIntegers() : void
+    public function testGeneratesTypeDeclarationForTinyIntegers(): void
     {
         self::assertEquals(
             'TINYINT',
@@ -104,11 +106,7 @@ class SqlitePlatformTest extends AbstractPlatformTestCase
         );
     }
 
-    /**
-     * @group DBAL-752
-     * @group DBAL-924
-     */
-    public function testGeneratesTypeDeclarationForSmallIntegers() : void
+    public function testGeneratesTypeDeclarationForSmallIntegers(): void
     {
         self::assertEquals(
             'SMALLINT',
@@ -138,11 +136,7 @@ class SqlitePlatformTest extends AbstractPlatformTestCase
         );
     }
 
-    /**
-     * @group DBAL-752
-     * @group DBAL-924
-     */
-    public function testGeneratesTypeDeclarationForMediumIntegers() : void
+    public function testGeneratesTypeDeclarationForMediumIntegers(): void
     {
         self::assertEquals(
             'MEDIUMINT',
@@ -172,7 +166,7 @@ class SqlitePlatformTest extends AbstractPlatformTestCase
         );
     }
 
-    public function testGeneratesTypeDeclarationForIntegers() : void
+    public function testGeneratesTypeDeclarationForIntegers(): void
     {
         self::assertEquals(
             'INTEGER',
@@ -202,11 +196,7 @@ class SqlitePlatformTest extends AbstractPlatformTestCase
         );
     }
 
-    /**
-     * @group DBAL-752
-     * @group DBAL-924
-     */
-    public function testGeneratesTypeDeclarationForBigIntegers() : void
+    public function testGeneratesTypeDeclarationForBigIntegers(): void
     {
         self::assertEquals(
             'BIGINT',
@@ -236,7 +226,7 @@ class SqlitePlatformTest extends AbstractPlatformTestCase
         );
     }
 
-    public function testGeneratesTypeDeclarationForStrings() : void
+    public function testGeneratesTypeDeclarationForStrings(): void
     {
         self::assertEquals(
             'CHAR(10)',
@@ -246,58 +236,56 @@ class SqlitePlatformTest extends AbstractPlatformTestCase
         );
         self::assertEquals(
             'VARCHAR(50)',
-            $this->platform->getVarcharTypeDeclarationSQL(['length' => 50]),
-            'Variable string declaration is not correct'
+            $this->platform->getVarcharTypeDeclarationSQL(['length' => 50])
         );
         self::assertEquals(
             'VARCHAR(255)',
-            $this->platform->getVarcharTypeDeclarationSQL([]),
-            'Long string declaration is not correct'
+            $this->platform->getVarcharTypeDeclarationSQL([])
         );
     }
 
-    public function getGenerateIndexSql() : string
+    public function getGenerateIndexSql(): string
     {
         return 'CREATE INDEX my_idx ON mytable (user_name, last_login)';
     }
 
-    public function getGenerateUniqueIndexSql() : string
+    public function getGenerateUniqueIndexSql(): string
     {
         return 'CREATE UNIQUE INDEX index_name ON test (test, test2)';
     }
 
-    public function testGeneratesForeignKeyCreationSql() : void
+    public function testGeneratesForeignKeyCreationSql(): void
     {
-        $this->expectException(DBALException::class);
+        $this->expectException(Exception::class);
 
         parent::testGeneratesForeignKeyCreationSql();
     }
 
-    public function testGeneratesConstraintCreationSql() : void
+    public function testGeneratesConstraintCreationSql(): void
     {
-        $this->expectException(DBALException::class);
+        $this->expectException(Exception::class);
 
         parent::testGeneratesConstraintCreationSql();
     }
 
-    public function getGenerateForeignKeySql() : string
+    protected function getGenerateForeignKeySql(): string
     {
-        return null;
+        return '';
     }
 
-    public function testModifyLimitQuery() : void
+    public function testModifyLimitQuery(): void
     {
         $sql = $this->platform->modifyLimitQuery('SELECT * FROM user', 10, 0);
         self::assertEquals('SELECT * FROM user LIMIT 10', $sql);
     }
 
-    public function testModifyLimitQueryWithEmptyOffset() : void
+    public function testModifyLimitQueryWithEmptyOffset(): void
     {
         $sql = $this->platform->modifyLimitQuery('SELECT * FROM user', 10);
         self::assertEquals('SELECT * FROM user LIMIT 10', $sql);
     }
 
-    public function testModifyLimitQueryWithOffsetAndEmptyLimit() : void
+    public function testModifyLimitQueryWithOffsetAndEmptyLimit(): void
     {
         $sql = $this->platform->modifyLimitQuery('SELECT * FROM user', null, 10);
         self::assertEquals('SELECT * FROM user LIMIT -1 OFFSET 10', $sql);
@@ -306,22 +294,22 @@ class SqlitePlatformTest extends AbstractPlatformTestCase
     /**
      * {@inheritDoc}
      */
-    public function getGenerateAlterTableSql() : array
+    public function getGenerateAlterTableSql(): array
     {
         return [
             'CREATE TEMPORARY TABLE __temp__mytable AS SELECT id, bar, bloo FROM mytable',
             'DROP TABLE mytable',
-            "CREATE TABLE mytable (id INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL, baz VARCHAR(255) DEFAULT 'def' NOT NULL, bloo BOOLEAN DEFAULT '0' NOT NULL, quota INTEGER DEFAULT NULL)",
+            'CREATE TABLE mytable (id INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL, '
+                . "baz VARCHAR(255) DEFAULT 'def' NOT NULL, "
+                . "bloo BOOLEAN DEFAULT '0' NOT NULL, "
+                . 'quota INTEGER DEFAULT NULL)',
             'INSERT INTO mytable (id, baz, bloo) SELECT id, bar, bloo FROM __temp__mytable',
             'DROP TABLE __temp__mytable',
             'ALTER TABLE mytable RENAME TO userlist',
         ];
     }
 
-    /**
-     * @group DDC-1845
-     */
-    public function testGenerateTableSqlShouldNotAutoQuotePrimaryKey() : void
+    public function testGenerateTableSqlShouldNotAutoQuotePrimaryKey(): void
     {
         $table = new Table('test');
         $table->addColumn('"like"', 'integer', ['notnull' => true, 'autoincrement' => true]);
@@ -334,11 +322,15 @@ class SqlitePlatformTest extends AbstractPlatformTestCase
         );
     }
 
-    public function testAlterTableAddColumns() : void
+    public function testAlterTableAddColumns(): void
     {
-        $diff                        = new TableDiff('user');
+        $diff = new TableDiff('user');
+
         $diff->addedColumns['foo']   = new Column('foo', Type::getType('string'));
-        $diff->addedColumns['count'] = new Column('count', Type::getType('integer'), ['notnull' => false, 'default' => 1]);
+        $diff->addedColumns['count'] = new Column('count', Type::getType('integer'), [
+            'notnull' => false,
+            'default' => 1,
+        ]);
 
         $expected = [
             'ALTER TABLE user ADD COLUMN foo VARCHAR(255) NOT NULL',
@@ -351,9 +343,9 @@ class SqlitePlatformTest extends AbstractPlatformTestCase
     /**
      * @dataProvider complexDiffProvider
      */
-    public function testAlterTableAddComplexColumns(TableDiff $diff) : void
+    public function testAlterTableAddComplexColumns(TableDiff $diff): void
     {
-        $this->expectException(DBALException::class);
+        $this->expectException(Exception::class);
 
         $this->platform->getAlterTableSQL($diff);
     }
@@ -361,7 +353,7 @@ class SqlitePlatformTest extends AbstractPlatformTestCase
     /**
      * @return mixed[][]
      */
-    public static function complexDiffProvider() : iterable
+    public static function complexDiffProvider(): iterable
     {
         $date                       = new TableDiff('user');
         $date->addedColumns['time'] = new Column('time', Type::getType('date'), ['default' => 'CURRENT_DATE']);
@@ -375,7 +367,7 @@ class SqlitePlatformTest extends AbstractPlatformTestCase
         ];
     }
 
-    public function testCreateTableWithDeferredForeignKeys() : void
+    public function testCreateTableWithDeferredForeignKeys(): void
     {
         $table = new Table('user');
         $table->addColumn('id', 'integer');
@@ -391,9 +383,12 @@ class SqlitePlatformTest extends AbstractPlatformTestCase
             'CREATE TABLE user ('
                 . 'id INTEGER NOT NULL, article INTEGER NOT NULL, post INTEGER NOT NULL, parent INTEGER NOT NULL'
                 . ', PRIMARY KEY(id)'
-                . ', CONSTRAINT FK_8D93D64923A0E66 FOREIGN KEY (article) REFERENCES article (id) DEFERRABLE INITIALLY IMMEDIATE'
-                . ', CONSTRAINT FK_8D93D6495A8A6C8D FOREIGN KEY (post) REFERENCES post (id) NOT DEFERRABLE INITIALLY DEFERRED'
-                . ', CONSTRAINT FK_8D93D6493D8E604F FOREIGN KEY (parent) REFERENCES user (id) DEFERRABLE INITIALLY DEFERRED'
+                . ', CONSTRAINT FK_8D93D64923A0E66 FOREIGN KEY (article)'
+                . ' REFERENCES article (id) DEFERRABLE INITIALLY IMMEDIATE'
+                . ', CONSTRAINT FK_8D93D6495A8A6C8D FOREIGN KEY (post)'
+                . ' REFERENCES post (id) NOT DEFERRABLE INITIALLY DEFERRED'
+                . ', CONSTRAINT FK_8D93D6493D8E604F FOREIGN KEY (parent)'
+                . ' REFERENCES user (id) DEFERRABLE INITIALLY DEFERRED'
                 . ')',
             'CREATE INDEX IDX_8D93D64923A0E66 ON user (article)',
             'CREATE INDEX IDX_8D93D6495A8A6C8D ON user (post)',
@@ -403,7 +398,7 @@ class SqlitePlatformTest extends AbstractPlatformTestCase
         self::assertEquals($sql, $this->platform->getCreateTableSQL($table));
     }
 
-    public function testAlterTable() : void
+    public function testAlterTable(): void
     {
         $table = new Table('user');
         $table->addColumn('id', 'integer');
@@ -434,8 +429,10 @@ class SqlitePlatformTest extends AbstractPlatformTestCase
             'CREATE TABLE user ('
                 . '"key" INTEGER NOT NULL, article INTEGER NOT NULL, comment INTEGER NOT NULL'
                 . ', PRIMARY KEY("key")'
-                . ', CONSTRAINT FK_8D93D64923A0E66 FOREIGN KEY (article) REFERENCES article (id) DEFERRABLE INITIALLY IMMEDIATE'
-                . ', CONSTRAINT FK_8D93D6495A8A6C8D FOREIGN KEY (comment) REFERENCES post (id) NOT DEFERRABLE INITIALLY DEFERRED'
+                . ', CONSTRAINT FK_8D93D64923A0E66 FOREIGN KEY (article)'
+                . ' REFERENCES article (id) DEFERRABLE INITIALLY IMMEDIATE'
+                . ', CONSTRAINT FK_8D93D6495A8A6C8D FOREIGN KEY (comment)'
+                . ' REFERENCES post (id) NOT DEFERRABLE INITIALLY DEFERRED'
                 . ')',
             'INSERT INTO user ("key", article, comment) SELECT id, article, post FROM __temp__user',
             'DROP TABLE __temp__user',
@@ -450,7 +447,7 @@ class SqlitePlatformTest extends AbstractPlatformTestCase
     /**
      * {@inheritDoc}
      */
-    protected function getQuotedColumnInPrimaryKeySQL() : array
+    protected function getQuotedColumnInPrimaryKeySQL(): array
     {
         return ['CREATE TABLE "quoted" ("create" VARCHAR(255) NOT NULL, PRIMARY KEY("create"))'];
     }
@@ -458,7 +455,7 @@ class SqlitePlatformTest extends AbstractPlatformTestCase
     /**
      * {@inheritDoc}
      */
-    protected function getQuotedColumnInIndexSQL() : array
+    protected function getQuotedColumnInIndexSQL(): array
     {
         return [
             'CREATE TABLE "quoted" ("create" VARCHAR(255) NOT NULL)',
@@ -469,7 +466,7 @@ class SqlitePlatformTest extends AbstractPlatformTestCase
     /**
      * {@inheritDoc}
      */
-    protected function getQuotedNameInIndexSQL() : array
+    protected function getQuotedNameInIndexSQL(): array
     {
         return [
             'CREATE TABLE test (column1 VARCHAR(255) NOT NULL)',
@@ -480,28 +477,31 @@ class SqlitePlatformTest extends AbstractPlatformTestCase
     /**
      * {@inheritDoc}
      */
-    protected function getQuotedColumnInForeignKeySQL() : array
+    protected function getQuotedColumnInForeignKeySQL(): array
     {
         return [
             'CREATE TABLE "quoted" (' .
             '"create" VARCHAR(255) NOT NULL, foo VARCHAR(255) NOT NULL, "bar" VARCHAR(255) NOT NULL, ' .
-            'CONSTRAINT FK_WITH_RESERVED_KEYWORD FOREIGN KEY ("create", foo, "bar") REFERENCES "foreign" ("create", bar, "foo-bar") NOT DEFERRABLE INITIALLY IMMEDIATE, ' .
-            'CONSTRAINT FK_WITH_NON_RESERVED_KEYWORD FOREIGN KEY ("create", foo, "bar") REFERENCES foo ("create", bar, "foo-bar") NOT DEFERRABLE INITIALLY IMMEDIATE, ' .
-            'CONSTRAINT FK_WITH_INTENDED_QUOTATION FOREIGN KEY ("create", foo, "bar") REFERENCES "foo-bar" ("create", bar, "foo-bar") NOT DEFERRABLE INITIALLY IMMEDIATE)',
+            'CONSTRAINT FK_WITH_RESERVED_KEYWORD FOREIGN KEY ("create", foo, "bar") ' .
+            'REFERENCES "foreign" ("create", bar, "foo-bar") NOT DEFERRABLE INITIALLY IMMEDIATE, ' .
+            'CONSTRAINT FK_WITH_NON_RESERVED_KEYWORD FOREIGN KEY ("create", foo, "bar") ' .
+            'REFERENCES foo ("create", bar, "foo-bar") NOT DEFERRABLE INITIALLY IMMEDIATE, ' .
+            'CONSTRAINT FK_WITH_INTENDED_QUOTATION FOREIGN KEY ("create", foo, "bar") ' .
+            'REFERENCES "foo-bar" ("create", bar, "foo-bar") NOT DEFERRABLE INITIALLY IMMEDIATE)',
         ];
     }
 
-    protected function getBinaryDefaultLength() : int
+    protected function getBinaryDefaultLength(): int
     {
         return 0;
     }
 
-    protected function getBinaryMaxLength() : int
+    protected function getBinaryMaxLength(): int
     {
         return 0;
     }
 
-    public function testReturnsBinaryTypeDeclarationSQL() : void
+    public function testReturnsBinaryTypeDeclarationSQL(): void
     {
         self::assertSame('BLOB', $this->platform->getBinaryTypeDeclarationSQL([]));
         self::assertSame('BLOB', $this->platform->getBinaryTypeDeclarationSQL(['length' => 0]));
@@ -514,10 +514,8 @@ class SqlitePlatformTest extends AbstractPlatformTestCase
 
     /**
      * {@inheritDoc}
-     *
-     * @group DBAL-234
      */
-    protected function getAlterTableRenameIndexSQL() : array
+    protected function getAlterTableRenameIndexSQL(): array
     {
         return [
             'CREATE TEMPORARY TABLE __temp__mytable AS SELECT id FROM mytable',
@@ -531,10 +529,8 @@ class SqlitePlatformTest extends AbstractPlatformTestCase
 
     /**
      * {@inheritDoc}
-     *
-     * @group DBAL-234
      */
-    protected function getQuotedAlterTableRenameIndexSQL() : array
+    protected function getQuotedAlterTableRenameIndexSQL(): array
     {
         return [
             'CREATE TEMPORARY TABLE __temp__table AS SELECT id FROM "table"',
@@ -550,10 +546,11 @@ class SqlitePlatformTest extends AbstractPlatformTestCase
     /**
      * {@inheritdoc}
      */
-    protected function getQuotedAlterTableRenameColumnSQL() : array
+    protected function getQuotedAlterTableRenameColumnSQL(): array
     {
         return [
-            'CREATE TEMPORARY TABLE __temp__mytable AS SELECT unquoted1, unquoted2, unquoted3, "create", "table", "select", "quoted1", "quoted2", "quoted3" FROM mytable',
+            'CREATE TEMPORARY TABLE __temp__mytable AS SELECT unquoted1, unquoted2, unquoted3, '
+                . '"create", "table", "select", "quoted1", "quoted2", "quoted3" FROM mytable',
             'DROP TABLE mytable',
             'CREATE TABLE mytable (unquoted INTEGER NOT NULL --Unquoted 1
 , "where" INTEGER NOT NULL --Unquoted 2
@@ -565,7 +562,9 @@ class SqlitePlatformTest extends AbstractPlatformTestCase
 , "and" INTEGER NOT NULL --Quoted 2
 , "baz" INTEGER NOT NULL --Quoted 3
 )',
-            'INSERT INTO mytable (unquoted, "where", "foo", reserved_keyword, "from", "bar", quoted, "and", "baz") SELECT unquoted1, unquoted2, unquoted3, "create", "table", "select", "quoted1", "quoted2", "quoted3" FROM __temp__mytable',
+            'INSERT INTO mytable (unquoted, "where", "foo", reserved_keyword, "from", "bar", quoted, "and", "baz") '
+                . 'SELECT unquoted1, unquoted2, unquoted3, "create", "table", "select", '
+                . '"quoted1", "quoted2", "quoted3" FROM __temp__mytable',
             'DROP TABLE __temp__mytable',
         ];
     }
@@ -573,10 +572,11 @@ class SqlitePlatformTest extends AbstractPlatformTestCase
     /**
      * {@inheritdoc}
      */
-    protected function getQuotedAlterTableChangeColumnLengthSQL() : array
+    protected function getQuotedAlterTableChangeColumnLengthSQL(): array
     {
         return [
-            'CREATE TEMPORARY TABLE __temp__mytable AS SELECT unquoted1, unquoted2, unquoted3, "create", "table", "select" FROM mytable',
+            'CREATE TEMPORARY TABLE __temp__mytable AS SELECT unquoted1, unquoted2, unquoted3, '
+                . '"create", "table", "select" FROM mytable',
             'DROP TABLE mytable',
             'CREATE TABLE mytable (unquoted1 VARCHAR(255) NOT NULL --Unquoted 1
 , unquoted2 VARCHAR(255) NOT NULL --Unquoted 2
@@ -585,15 +585,13 @@ class SqlitePlatformTest extends AbstractPlatformTestCase
 , "table" VARCHAR(255) NOT NULL --Reserved keyword 2
 , "select" VARCHAR(255) NOT NULL --Reserved keyword 3
 )',
-            'INSERT INTO mytable (unquoted1, unquoted2, unquoted3, "create", "table", "select") SELECT unquoted1, unquoted2, unquoted3, "create", "table", "select" FROM __temp__mytable',
+            'INSERT INTO mytable (unquoted1, unquoted2, unquoted3, "create", "table", "select") '
+                . 'SELECT unquoted1, unquoted2, unquoted3, "create", "table", "select" FROM __temp__mytable',
             'DROP TABLE __temp__mytable',
         ];
     }
 
-    /**
-     * @group DBAL-807
-     */
-    public function testAlterTableRenameIndexInSchema() : void
+    public function testAlterTableRenameIndexInSchema(): void
     {
         $this->markTestIncomplete(
             'Test currently produces broken SQL due to SQLLitePlatform::getAlterTable being broken ' .
@@ -601,10 +599,7 @@ class SqlitePlatformTest extends AbstractPlatformTestCase
         );
     }
 
-    /**
-     * @group DBAL-807
-     */
-    public function testQuotesAlterTableRenameIndexInSchema() : void
+    public function testQuotesAlterTableRenameIndexInSchema(): void
     {
         $this->markTestIncomplete(
             'Test currently produces broken SQL due to SQLLitePlatform::getAlterTable being broken ' .
@@ -612,10 +607,7 @@ class SqlitePlatformTest extends AbstractPlatformTestCase
         );
     }
 
-    /**
-     * @group DBAL-423
-     */
-    public function testReturnsGuidTypeDeclarationSQL() : void
+    public function testReturnsGuidTypeDeclarationSQL(): void
     {
         self::assertSame('CHAR(36)', $this->platform->getGuidTypeDeclarationSQL([]));
     }
@@ -623,7 +615,7 @@ class SqlitePlatformTest extends AbstractPlatformTestCase
     /**
      * {@inheritdoc}
      */
-    public function getAlterTableRenameColumnSQL() : array
+    public function getAlterTableRenameColumnSQL(): array
     {
         return [
             'CREATE TEMPORARY TABLE __temp__foo AS SELECT bar FROM foo',
@@ -638,15 +630,15 @@ class SqlitePlatformTest extends AbstractPlatformTestCase
     /**
      * {@inheritdoc}
      */
-    protected function getQuotesTableIdentifiersInAlterTableSQL() : array
+    protected function getQuotesTableIdentifiersInAlterTableSQL(): array
     {
         return [
             'DROP INDEX IDX_8C736521A81E660E',
             'DROP INDEX IDX_8C736521FDC58D6C',
             'CREATE TEMPORARY TABLE __temp__foo AS SELECT fk, fk2, id, fk3, bar FROM "foo"',
             'DROP TABLE "foo"',
-            'CREATE TABLE "foo" (fk2 INTEGER NOT NULL, fk3 INTEGER NOT NULL, fk INTEGER NOT NULL, war INTEGER NOT NULL, ' .
-            'bar INTEGER DEFAULT NULL, bloo INTEGER NOT NULL, ' .
+            'CREATE TABLE "foo" (fk2 INTEGER NOT NULL, fk3 INTEGER NOT NULL, fk INTEGER NOT NULL, ' .
+            'war INTEGER NOT NULL, bar INTEGER DEFAULT NULL, bloo INTEGER NOT NULL, ' .
             'CONSTRAINT fk2 FOREIGN KEY (fk2) REFERENCES fk_table2 (id) NOT DEFERRABLE INITIALLY IMMEDIATE, ' .
             'CONSTRAINT fk_add FOREIGN KEY (fk3) REFERENCES fk_table (id) NOT DEFERRABLE INITIALLY IMMEDIATE)',
             'INSERT INTO "foo" (fk, fk2, war, fk3, bar) SELECT fk, fk2, id, fk3, bar FROM __temp__foo',
@@ -660,7 +652,7 @@ class SqlitePlatformTest extends AbstractPlatformTestCase
     /**
      * {@inheritdoc}
      */
-    protected function getCommentOnColumnSQL() : array
+    protected function getCommentOnColumnSQL(): array
     {
         return [
             'COMMENT ON COLUMN foo.bar IS \'comment\'',
@@ -669,46 +661,37 @@ class SqlitePlatformTest extends AbstractPlatformTestCase
         ];
     }
 
-    protected static function getInlineColumnCommentDelimiter() : string
+    protected static function getInlineColumnCommentDelimiter(): string
     {
         return "\n";
     }
 
-    protected static function getInlineColumnRegularCommentSQL() : string
+    protected static function getInlineColumnRegularCommentSQL(): string
     {
         return "--Regular comment\n";
     }
 
-    protected static function getInlineColumnCommentRequiringEscapingSQL() : string
+    protected static function getInlineColumnCommentRequiringEscapingSQL(): string
     {
         return "--Using inline comment delimiter \n-- works\n";
     }
 
-    protected static function getInlineColumnEmptyCommentSQL() : string
+    protected static function getInlineColumnEmptyCommentSQL(): string
     {
         return "--\n";
     }
 
-    /**
-     * {@inheritdoc}
-     */
-    protected function getQuotesReservedKeywordInUniqueConstraintDeclarationSQL() : string
+    protected function getQuotesReservedKeywordInUniqueConstraintDeclarationSQL(): string
     {
         return 'CONSTRAINT "select" UNIQUE (foo)';
     }
 
-    /**
-     * {@inheritdoc}
-     */
-    protected function getQuotesReservedKeywordInIndexDeclarationSQL() : string
+    protected function getQuotesReservedKeywordInIndexDeclarationSQL(): string
     {
         return 'INDEX "select" (foo)';
     }
 
-    /**
-     * {@inheritdoc}
-     */
-    protected function getQuotesReservedKeywordInTruncateTableSQL() : string
+    protected function getQuotesReservedKeywordInTruncateTableSQL(): string
     {
         return 'DELETE FROM "select"';
     }
@@ -716,7 +699,7 @@ class SqlitePlatformTest extends AbstractPlatformTestCase
     /**
      * {@inheritdoc}
      */
-    protected function getAlterStringToFixedStringSQL() : array
+    protected function getAlterStringToFixedStringSQL(): array
     {
         return [
             'CREATE TEMPORARY TABLE __temp__mytable AS SELECT name FROM mytable',
@@ -730,14 +713,18 @@ class SqlitePlatformTest extends AbstractPlatformTestCase
     /**
      * {@inheritdoc}
      */
-    protected function getGeneratesAlterTableRenameIndexUsedByForeignKeySQL() : array
+    protected function getGeneratesAlterTableRenameIndexUsedByForeignKeySQL(): array
     {
         return [
             'DROP INDEX idx_foo',
             'DROP INDEX idx_bar',
             'CREATE TEMPORARY TABLE __temp__mytable AS SELECT foo, bar, baz FROM mytable',
             'DROP TABLE mytable',
-            'CREATE TABLE mytable (foo INTEGER NOT NULL, bar INTEGER NOT NULL, baz INTEGER NOT NULL, CONSTRAINT fk_foo FOREIGN KEY (foo) REFERENCES foreign_table (id) NOT DEFERRABLE INITIALLY IMMEDIATE, CONSTRAINT fk_bar FOREIGN KEY (bar) REFERENCES foreign_table (id) NOT DEFERRABLE INITIALLY IMMEDIATE)',
+            'CREATE TABLE mytable (foo INTEGER NOT NULL, bar INTEGER NOT NULL, baz INTEGER NOT NULL, '
+                . 'CONSTRAINT fk_foo FOREIGN KEY (foo) REFERENCES foreign_table (id)'
+                . ' NOT DEFERRABLE INITIALLY IMMEDIATE, '
+                . 'CONSTRAINT fk_bar FOREIGN KEY (bar) REFERENCES foreign_table (id)'
+                . ' NOT DEFERRABLE INITIALLY IMMEDIATE)',
             'INSERT INTO mytable (foo, bar, baz) SELECT foo, bar, baz FROM __temp__mytable',
             'DROP TABLE __temp__mytable',
             'CREATE INDEX idx_bar ON mytable (bar)',
@@ -745,10 +732,7 @@ class SqlitePlatformTest extends AbstractPlatformTestCase
         ];
     }
 
-    /**
-     * @group DBAL-2436
-     */
-    public function testQuotesTableNameInListTableConstraintsSQL() : void
+    public function testQuotesTableNameInListTableConstraintsSQL(): void
     {
         self::assertStringContainsStringIgnoringCase(
             "'Foo''Bar\\'",
@@ -756,10 +740,7 @@ class SqlitePlatformTest extends AbstractPlatformTestCase
         );
     }
 
-    /**
-     * @group DBAL-2436
-     */
-    public function testQuotesTableNameInListTableColumnsSQL() : void
+    public function testQuotesTableNameInListTableColumnsSQL(): void
     {
         self::assertStringContainsStringIgnoringCase(
             "'Foo''Bar\\'",
@@ -767,10 +748,7 @@ class SqlitePlatformTest extends AbstractPlatformTestCase
         );
     }
 
-    /**
-     * @group DBAL-2436
-     */
-    public function testQuotesTableNameInListTableIndexesSQL() : void
+    public function testQuotesTableNameInListTableIndexesSQL(): void
     {
         self::assertStringContainsStringIgnoringCase(
             "'Foo''Bar\\'",
@@ -778,10 +756,7 @@ class SqlitePlatformTest extends AbstractPlatformTestCase
         );
     }
 
-    /**
-     * @group DBAL-2436
-     */
-    public function testQuotesTableNameInListTableForeignKeysSQL() : void
+    public function testQuotesTableNameInListTableForeignKeysSQL(): void
     {
         self::assertStringContainsStringIgnoringCase(
             "'Foo''Bar\\'",
@@ -789,22 +764,28 @@ class SqlitePlatformTest extends AbstractPlatformTestCase
         );
     }
 
-    public function testDateAddStaticNumberOfDays() : void
+    public function testDateAddStaticNumberOfDays(): void
     {
-        self::assertSame("DATE(rentalBeginsOn,'+12 DAY')", $this->platform->getDateAddDaysExpression('rentalBeginsOn', 12));
+        self::assertSame(
+            "DATE(rentalBeginsOn,'+12 DAY')",
+            $this->platform->getDateAddDaysExpression('rentalBeginsOn', 12)
+        );
     }
 
-    public function testDateAddNumberOfDaysFromColumn() : void
+    public function testDateAddNumberOfDaysFromColumn(): void
     {
-        self::assertSame("DATE(rentalBeginsOn,'+' || duration || ' DAY')", $this->platform->getDateAddDaysExpression('rentalBeginsOn', 'duration'));
+        self::assertSame(
+            "DATE(rentalBeginsOn,'+' || duration || ' DAY')",
+            $this->platform->getDateAddDaysExpression('rentalBeginsOn', 'duration')
+        );
     }
 
-    public function testSupportsColumnCollation() : void
+    public function testSupportsColumnCollation(): void
     {
         self::assertTrue($this->platform->supportsColumnCollation());
     }
 
-    public function testColumnCollationDeclarationSQL() : void
+    public function testColumnCollationDeclarationSQL(): void
     {
         self::assertSame(
             'COLLATE NOCASE',
@@ -812,16 +793,18 @@ class SqlitePlatformTest extends AbstractPlatformTestCase
         );
     }
 
-    public function testGetCreateTableSQLWithColumnCollation() : void
+    public function testGetCreateTableSQLWithColumnCollation(): void
     {
         $table = new Table('foo');
         $table->addColumn('no_collation', 'string');
         $table->addColumn('column_collation', 'string')->setPlatformOption('collation', 'NOCASE');
 
         self::assertSame(
-            ['CREATE TABLE foo (no_collation VARCHAR(255) NOT NULL, column_collation VARCHAR(255) NOT NULL COLLATE NOCASE)'],
-            $this->platform->getCreateTableSQL($table),
-            'Column "no_collation" will use the default collation (BINARY) and "column_collation" overwrites the collation on this column'
+            [
+                'CREATE TABLE foo (no_collation VARCHAR(255) NOT NULL, '
+                    . 'column_collation VARCHAR(255) NOT NULL COLLATE NOCASE)',
+            ],
+            $this->platform->getCreateTableSQL($table)
         );
     }
 }
