@@ -9,15 +9,12 @@ use Doctrine\DBAL\Query\QueryBuilder;
 use Doctrine\DBAL\Query\QueryException;
 use Doctrine\Tests\DbalTestCase;
 
-/**
- * @group DBAL-12
- */
 class QueryBuilderTest extends DbalTestCase
 {
     /** @var Connection */
     protected $conn;
 
-    protected function setUp() : void
+    protected function setUp(): void
     {
         $this->conn = $this->createMock(Connection::class);
 
@@ -28,10 +25,7 @@ class QueryBuilderTest extends DbalTestCase
                    ->will($this->returnValue($expressionBuilder));
     }
 
-    /**
-     * @group DBAL-2291
-     */
-    public function testSimpleSelectWithoutFrom() : void
+    public function testSimpleSelectWithoutFrom(): void
     {
         $qb = new QueryBuilder($this->conn);
 
@@ -40,7 +34,7 @@ class QueryBuilderTest extends DbalTestCase
         self::assertEquals('SELECT some_function()', (string) $qb);
     }
 
-    public function testSimpleSelect() : void
+    public function testSimpleSelect(): void
     {
         $qb = new QueryBuilder($this->conn);
 
@@ -50,7 +44,7 @@ class QueryBuilderTest extends DbalTestCase
         self::assertEquals('SELECT u.id FROM users u', (string) $qb);
     }
 
-    public function testSimpleSelectWithDistinct() : void
+    public function testSimpleSelectWithDistinct(): void
     {
         $qb = new QueryBuilder($this->conn);
 
@@ -61,19 +55,19 @@ class QueryBuilderTest extends DbalTestCase
         self::assertEquals('SELECT DISTINCT u.id FROM users u', (string) $qb);
     }
 
-    public function testSelectWithSimpleWhere() : void
+    public function testSelectWithSimpleWhere(): void
     {
         $qb   = new QueryBuilder($this->conn);
         $expr = $qb->expr();
 
         $qb->select('u.id')
            ->from('users', 'u')
-           ->where($expr->andX($expr->eq('u.nickname', '?')));
+           ->where($expr->and($expr->eq('u.nickname', '?')));
 
         self::assertEquals('SELECT u.id FROM users u WHERE u.nickname = ?', (string) $qb);
     }
 
-    public function testSelectWithLeftJoin() : void
+    public function testSelectWithLeftJoin(): void
     {
         $qb   = new QueryBuilder($this->conn);
         $expr = $qb->expr();
@@ -85,7 +79,7 @@ class QueryBuilderTest extends DbalTestCase
         self::assertEquals('SELECT u.*, p.* FROM users u LEFT JOIN phones p ON p.user_id = u.id', (string) $qb);
     }
 
-    public function testSelectWithJoin() : void
+    public function testSelectWithJoin(): void
     {
         $qb   = new QueryBuilder($this->conn);
         $expr = $qb->expr();
@@ -97,7 +91,7 @@ class QueryBuilderTest extends DbalTestCase
         self::assertEquals('SELECT u.*, p.* FROM users u INNER JOIN phones p ON p.user_id = u.id', (string) $qb);
     }
 
-    public function testSelectWithJoinNoCondition() : void
+    public function testSelectWithJoinNoCondition(): void
     {
         $qb = new QueryBuilder($this->conn);
 
@@ -108,7 +102,7 @@ class QueryBuilderTest extends DbalTestCase
         self::assertEquals('SELECT u.*, p.* FROM users u INNER JOIN phones p', (string) $qb);
     }
 
-    public function testSelectWithInnerJoin() : void
+    public function testSelectWithInnerJoin(): void
     {
         $qb   = new QueryBuilder($this->conn);
         $expr = $qb->expr();
@@ -120,7 +114,7 @@ class QueryBuilderTest extends DbalTestCase
         self::assertEquals('SELECT u.*, p.* FROM users u INNER JOIN phones p ON p.user_id = u.id', (string) $qb);
     }
 
-    public function testSelectWithRightJoin() : void
+    public function testSelectWithRightJoin(): void
     {
         $qb   = new QueryBuilder($this->conn);
         $expr = $qb->expr();
@@ -132,7 +126,7 @@ class QueryBuilderTest extends DbalTestCase
         self::assertEquals('SELECT u.*, p.* FROM users u RIGHT JOIN phones p ON p.user_id = u.id', (string) $qb);
     }
 
-    public function testSelectWithAndWhereConditions() : void
+    public function testSelectWithAndWhereConditions(): void
     {
         $qb   = new QueryBuilder($this->conn);
         $expr = $qb->expr();
@@ -145,7 +139,7 @@ class QueryBuilderTest extends DbalTestCase
         self::assertEquals('SELECT u.*, p.* FROM users u WHERE (u.username = ?) AND (u.name = ?)', (string) $qb);
     }
 
-    public function testSelectWithOrWhereConditions() : void
+    public function testSelectWithOrWhereConditions(): void
     {
         $qb   = new QueryBuilder($this->conn);
         $expr = $qb->expr();
@@ -158,7 +152,7 @@ class QueryBuilderTest extends DbalTestCase
         self::assertEquals('SELECT u.*, p.* FROM users u WHERE (u.username = ?) OR (u.name = ?)', (string) $qb);
     }
 
-    public function testSelectWithOrOrWhereConditions() : void
+    public function testSelectWithOrOrWhereConditions(): void
     {
         $qb   = new QueryBuilder($this->conn);
         $expr = $qb->expr();
@@ -171,7 +165,7 @@ class QueryBuilderTest extends DbalTestCase
         self::assertEquals('SELECT u.*, p.* FROM users u WHERE (u.username = ?) OR (u.name = ?)', (string) $qb);
     }
 
-    public function testSelectWithAndOrWhereConditions() : void
+    public function testSelectWithAndOrWhereConditions(): void
     {
         $qb   = new QueryBuilder($this->conn);
         $expr = $qb->expr();
@@ -183,10 +177,14 @@ class QueryBuilderTest extends DbalTestCase
            ->orWhere('u.name = ?')
            ->andWhere('u.name = ?');
 
-        self::assertEquals('SELECT u.*, p.* FROM users u WHERE (((u.username = ?) AND (u.username = ?)) OR (u.name = ?)) AND (u.name = ?)', (string) $qb);
+        self::assertEquals(
+            'SELECT u.*, p.* FROM users u'
+                . ' WHERE (((u.username = ?) AND (u.username = ?)) OR (u.name = ?)) AND (u.name = ?)',
+            (string) $qb
+        );
     }
 
-    public function testSelectGroupBy() : void
+    public function testSelectGroupBy(): void
     {
         $qb   = new QueryBuilder($this->conn);
         $expr = $qb->expr();
@@ -198,7 +196,7 @@ class QueryBuilderTest extends DbalTestCase
         self::assertEquals('SELECT u.*, p.* FROM users u GROUP BY u.id', (string) $qb);
     }
 
-    public function testSelectEmptyGroupBy() : void
+    public function testSelectEmptyGroupBy(): void
     {
         $qb   = new QueryBuilder($this->conn);
         $expr = $qb->expr();
@@ -210,7 +208,7 @@ class QueryBuilderTest extends DbalTestCase
         self::assertEquals('SELECT u.*, p.* FROM users u', (string) $qb);
     }
 
-    public function testSelectEmptyAddGroupBy() : void
+    public function testSelectEmptyAddGroupBy(): void
     {
         $qb   = new QueryBuilder($this->conn);
         $expr = $qb->expr();
@@ -222,7 +220,7 @@ class QueryBuilderTest extends DbalTestCase
         self::assertEquals('SELECT u.*, p.* FROM users u', (string) $qb);
     }
 
-    public function testSelectAddGroupBy() : void
+    public function testSelectAddGroupBy(): void
     {
         $qb   = new QueryBuilder($this->conn);
         $expr = $qb->expr();
@@ -235,7 +233,7 @@ class QueryBuilderTest extends DbalTestCase
         self::assertEquals('SELECT u.*, p.* FROM users u GROUP BY u.id, u.foo', (string) $qb);
     }
 
-    public function testSelectAddGroupBys() : void
+    public function testSelectAddGroupBys(): void
     {
         $qb   = new QueryBuilder($this->conn);
         $expr = $qb->expr();
@@ -248,7 +246,7 @@ class QueryBuilderTest extends DbalTestCase
         self::assertEquals('SELECT u.*, p.* FROM users u GROUP BY u.id, u.foo, u.bar', (string) $qb);
     }
 
-    public function testSelectHaving() : void
+    public function testSelectHaving(): void
     {
         $qb   = new QueryBuilder($this->conn);
         $expr = $qb->expr();
@@ -261,7 +259,7 @@ class QueryBuilderTest extends DbalTestCase
         self::assertEquals('SELECT u.*, p.* FROM users u GROUP BY u.id HAVING u.name = ?', (string) $qb);
     }
 
-    public function testSelectAndHaving() : void
+    public function testSelectAndHaving(): void
     {
         $qb   = new QueryBuilder($this->conn);
         $expr = $qb->expr();
@@ -274,7 +272,7 @@ class QueryBuilderTest extends DbalTestCase
         self::assertEquals('SELECT u.*, p.* FROM users u GROUP BY u.id HAVING u.name = ?', (string) $qb);
     }
 
-    public function testSelectHavingAndHaving() : void
+    public function testSelectHavingAndHaving(): void
     {
         $qb   = new QueryBuilder($this->conn);
         $expr = $qb->expr();
@@ -285,10 +283,13 @@ class QueryBuilderTest extends DbalTestCase
            ->having('u.name = ?')
            ->andHaving('u.username = ?');
 
-        self::assertEquals('SELECT u.*, p.* FROM users u GROUP BY u.id HAVING (u.name = ?) AND (u.username = ?)', (string) $qb);
+        self::assertEquals(
+            'SELECT u.*, p.* FROM users u GROUP BY u.id HAVING (u.name = ?) AND (u.username = ?)',
+            (string) $qb
+        );
     }
 
-    public function testSelectHavingOrHaving() : void
+    public function testSelectHavingOrHaving(): void
     {
         $qb   = new QueryBuilder($this->conn);
         $expr = $qb->expr();
@@ -299,10 +300,13 @@ class QueryBuilderTest extends DbalTestCase
            ->having('u.name = ?')
            ->orHaving('u.username = ?');
 
-        self::assertEquals('SELECT u.*, p.* FROM users u GROUP BY u.id HAVING (u.name = ?) OR (u.username = ?)', (string) $qb);
+        self::assertEquals(
+            'SELECT u.*, p.* FROM users u GROUP BY u.id HAVING (u.name = ?) OR (u.username = ?)',
+            (string) $qb
+        );
     }
 
-    public function testSelectOrHavingOrHaving() : void
+    public function testSelectOrHavingOrHaving(): void
     {
         $qb   = new QueryBuilder($this->conn);
         $expr = $qb->expr();
@@ -313,10 +317,13 @@ class QueryBuilderTest extends DbalTestCase
            ->orHaving('u.name = ?')
            ->orHaving('u.username = ?');
 
-        self::assertEquals('SELECT u.*, p.* FROM users u GROUP BY u.id HAVING (u.name = ?) OR (u.username = ?)', (string) $qb);
+        self::assertEquals(
+            'SELECT u.*, p.* FROM users u GROUP BY u.id HAVING (u.name = ?) OR (u.username = ?)',
+            (string) $qb
+        );
     }
 
-    public function testSelectHavingAndOrHaving() : void
+    public function testSelectHavingAndOrHaving(): void
     {
         $qb   = new QueryBuilder($this->conn);
         $expr = $qb->expr();
@@ -328,10 +335,13 @@ class QueryBuilderTest extends DbalTestCase
            ->orHaving('u.username = ?')
            ->andHaving('u.username = ?');
 
-        self::assertEquals('SELECT u.*, p.* FROM users u GROUP BY u.id HAVING ((u.name = ?) OR (u.username = ?)) AND (u.username = ?)', (string) $qb);
+        self::assertEquals(
+            'SELECT u.*, p.* FROM users u GROUP BY u.id HAVING ((u.name = ?) OR (u.username = ?)) AND (u.username = ?)',
+            (string) $qb
+        );
     }
 
-    public function testSelectOrderBy() : void
+    public function testSelectOrderBy(): void
     {
         $qb   = new QueryBuilder($this->conn);
         $expr = $qb->expr();
@@ -343,7 +353,7 @@ class QueryBuilderTest extends DbalTestCase
         self::assertEquals('SELECT u.*, p.* FROM users u ORDER BY u.name ASC', (string) $qb);
     }
 
-    public function testSelectAddOrderBy() : void
+    public function testSelectAddOrderBy(): void
     {
         $qb   = new QueryBuilder($this->conn);
         $expr = $qb->expr();
@@ -356,7 +366,7 @@ class QueryBuilderTest extends DbalTestCase
         self::assertEquals('SELECT u.*, p.* FROM users u ORDER BY u.name ASC, u.username DESC', (string) $qb);
     }
 
-    public function testSelectAddAddOrderBy() : void
+    public function testSelectAddAddOrderBy(): void
     {
         $qb   = new QueryBuilder($this->conn);
         $expr = $qb->expr();
@@ -369,7 +379,7 @@ class QueryBuilderTest extends DbalTestCase
         self::assertEquals('SELECT u.*, p.* FROM users u ORDER BY u.name ASC, u.username DESC', (string) $qb);
     }
 
-    public function testEmptySelect() : void
+    public function testEmptySelect(): void
     {
         $qb  = new QueryBuilder($this->conn);
         $qb2 = $qb->select();
@@ -378,7 +388,7 @@ class QueryBuilderTest extends DbalTestCase
         self::assertEquals(QueryBuilder::SELECT, $qb->getType());
     }
 
-    public function testSelectAddSelect() : void
+    public function testSelectAddSelect(): void
     {
         $qb   = new QueryBuilder($this->conn);
         $expr = $qb->expr();
@@ -390,7 +400,7 @@ class QueryBuilderTest extends DbalTestCase
         self::assertEquals('SELECT u.*, p.* FROM users u', (string) $qb);
     }
 
-    public function testEmptyAddSelect() : void
+    public function testEmptyAddSelect(): void
     {
         $qb  = new QueryBuilder($this->conn);
         $qb2 = $qb->addSelect();
@@ -399,7 +409,7 @@ class QueryBuilderTest extends DbalTestCase
         self::assertEquals(QueryBuilder::SELECT, $qb->getType());
     }
 
-    public function testSelectMultipleFrom() : void
+    public function testSelectMultipleFrom(): void
     {
         $qb   = new QueryBuilder($this->conn);
         $expr = $qb->expr();
@@ -412,7 +422,7 @@ class QueryBuilderTest extends DbalTestCase
         self::assertEquals('SELECT u.*, p.* FROM users u, phonenumbers p', (string) $qb);
     }
 
-    public function testUpdate() : void
+    public function testUpdate(): void
     {
         $qb = new QueryBuilder($this->conn);
         $qb->update('users', 'u')
@@ -423,7 +433,7 @@ class QueryBuilderTest extends DbalTestCase
         self::assertEquals('UPDATE users u SET u.foo = ?, u.bar = ?', (string) $qb);
     }
 
-    public function testUpdateWithoutAlias() : void
+    public function testUpdateWithoutAlias(): void
     {
         $qb = new QueryBuilder($this->conn);
         $qb->update('users')
@@ -433,7 +443,7 @@ class QueryBuilderTest extends DbalTestCase
         self::assertEquals('UPDATE users SET foo = ?, bar = ?', (string) $qb);
     }
 
-    public function testUpdateWhere() : void
+    public function testUpdateWhere(): void
     {
         $qb = new QueryBuilder($this->conn);
         $qb->update('users', 'u')
@@ -443,7 +453,7 @@ class QueryBuilderTest extends DbalTestCase
         self::assertEquals('UPDATE users u SET u.foo = ? WHERE u.foo = ?', (string) $qb);
     }
 
-    public function testEmptyUpdate() : void
+    public function testEmptyUpdate(): void
     {
         $qb  = new QueryBuilder($this->conn);
         $qb2 = $qb->update();
@@ -452,7 +462,7 @@ class QueryBuilderTest extends DbalTestCase
         self::assertSame($qb2, $qb);
     }
 
-    public function testDelete() : void
+    public function testDelete(): void
     {
         $qb = new QueryBuilder($this->conn);
         $qb->delete('users', 'u');
@@ -461,7 +471,7 @@ class QueryBuilderTest extends DbalTestCase
         self::assertEquals('DELETE FROM users u', (string) $qb);
     }
 
-    public function testDeleteWithoutAlias() : void
+    public function testDeleteWithoutAlias(): void
     {
         $qb = new QueryBuilder($this->conn);
         $qb->delete('users');
@@ -470,7 +480,7 @@ class QueryBuilderTest extends DbalTestCase
         self::assertEquals('DELETE FROM users', (string) $qb);
     }
 
-    public function testDeleteWhere() : void
+    public function testDeleteWhere(): void
     {
         $qb = new QueryBuilder($this->conn);
         $qb->delete('users', 'u')
@@ -479,7 +489,7 @@ class QueryBuilderTest extends DbalTestCase
         self::assertEquals('DELETE FROM users u WHERE u.foo = ?', (string) $qb);
     }
 
-    public function testEmptyDelete() : void
+    public function testEmptyDelete(): void
     {
         $qb  = new QueryBuilder($this->conn);
         $qb2 = $qb->delete();
@@ -488,7 +498,7 @@ class QueryBuilderTest extends DbalTestCase
         self::assertSame($qb2, $qb);
     }
 
-    public function testInsertValues() : void
+    public function testInsertValues(): void
     {
         $qb = new QueryBuilder($this->conn);
         $qb->insert('users')
@@ -503,7 +513,7 @@ class QueryBuilderTest extends DbalTestCase
         self::assertEquals('INSERT INTO users (foo, bar) VALUES(?, ?)', (string) $qb);
     }
 
-    public function testInsertReplaceValues() : void
+    public function testInsertReplaceValues(): void
     {
         $qb = new QueryBuilder($this->conn);
         $qb->insert('users')
@@ -524,7 +534,7 @@ class QueryBuilderTest extends DbalTestCase
         self::assertEquals('INSERT INTO users (bar, foo) VALUES(?, ?)', (string) $qb);
     }
 
-    public function testInsertSetValue() : void
+    public function testInsertSetValue(): void
     {
         $qb = new QueryBuilder($this->conn);
         $qb->insert('users')
@@ -536,7 +546,7 @@ class QueryBuilderTest extends DbalTestCase
         self::assertEquals('INSERT INTO users (foo, bar) VALUES(?, ?)', (string) $qb);
     }
 
-    public function testInsertValuesSetValue() : void
+    public function testInsertValuesSetValue(): void
     {
         $qb = new QueryBuilder($this->conn);
         $qb->insert('users')
@@ -549,7 +559,7 @@ class QueryBuilderTest extends DbalTestCase
         self::assertEquals('INSERT INTO users (foo, bar) VALUES(?, ?)', (string) $qb);
     }
 
-    public function testEmptyInsert() : void
+    public function testEmptyInsert(): void
     {
         $qb  = new QueryBuilder($this->conn);
         $qb2 = $qb->insert();
@@ -558,13 +568,13 @@ class QueryBuilderTest extends DbalTestCase
         self::assertSame($qb2, $qb);
     }
 
-    public function testGetConnection() : void
+    public function testGetConnection(): void
     {
         $qb = new QueryBuilder($this->conn);
         self::assertSame($this->conn, $qb->getConnection());
     }
 
-    public function testGetState() : void
+    public function testGetState(): void
     {
         $qb = new QueryBuilder($this->conn);
 
@@ -583,7 +593,7 @@ class QueryBuilderTest extends DbalTestCase
     /**
      * @dataProvider maxResultsProvider
      */
-    public function testSetMaxResults(?int $maxResults) : void
+    public function testSetMaxResults(?int $maxResults): void
     {
         $qb = new QueryBuilder($this->conn);
         $qb->setMaxResults($maxResults);
@@ -595,7 +605,7 @@ class QueryBuilderTest extends DbalTestCase
     /**
      * @return mixed[][]
      */
-    public static function maxResultsProvider() : iterable
+    public static function maxResultsProvider(): iterable
     {
         return [
             'non-null' => [10],
@@ -603,7 +613,7 @@ class QueryBuilderTest extends DbalTestCase
         ];
     }
 
-    public function testSetFirstResult() : void
+    public function testSetFirstResult(): void
     {
         $qb = new QueryBuilder($this->conn);
         $qb->setFirstResult(10);
@@ -612,7 +622,7 @@ class QueryBuilderTest extends DbalTestCase
         self::assertEquals(10, $qb->getFirstResult());
     }
 
-    public function testResetQueryPart() : void
+    public function testResetQueryPart(): void
     {
         $qb = new QueryBuilder($this->conn);
 
@@ -623,7 +633,7 @@ class QueryBuilderTest extends DbalTestCase
         self::assertEquals('SELECT u.* FROM users u', (string) $qb);
     }
 
-    public function testResetQueryParts() : void
+    public function testResetQueryParts(): void
     {
         $qb = new QueryBuilder($this->conn);
 
@@ -634,7 +644,7 @@ class QueryBuilderTest extends DbalTestCase
         self::assertEquals('SELECT u.* FROM users u', (string) $qb);
     }
 
-    public function testCreateNamedParameter() : void
+    public function testCreateNamedParameter(): void
     {
         $qb = new QueryBuilder($this->conn);
 
@@ -647,7 +657,7 @@ class QueryBuilderTest extends DbalTestCase
         self::assertEquals(ParameterType::INTEGER, $qb->getParameterType('dcValue1'));
     }
 
-    public function testCreateNamedParameterCustomPlaceholder() : void
+    public function testCreateNamedParameterCustomPlaceholder(): void
     {
         $qb = new QueryBuilder($this->conn);
 
@@ -660,7 +670,7 @@ class QueryBuilderTest extends DbalTestCase
         self::assertEquals(ParameterType::INTEGER, $qb->getParameterType('test'));
     }
 
-    public function testCreatePositionalParameter() : void
+    public function testCreatePositionalParameter(): void
     {
         $qb = new QueryBuilder($this->conn);
 
@@ -673,10 +683,7 @@ class QueryBuilderTest extends DbalTestCase
         self::assertEquals(ParameterType::INTEGER, $qb->getParameterType(1));
     }
 
-    /**
-     * @group DBAL-172
-     */
-    public function testReferenceJoinFromJoin() : void
+    public function testReferenceJoinFromJoin(): void
     {
         $qb = new QueryBuilder($this->conn);
 
@@ -688,14 +695,14 @@ class QueryBuilderTest extends DbalTestCase
             ->where('nt.lang = :lang AND n.deleted != 1');
 
         $this->expectException(QueryException::class);
-        $this->expectExceptionMessage("The given alias 'invalid' is not part of any FROM or JOIN clause table. The currently registered aliases are: news, nv.");
+        $this->expectExceptionMessage(
+            "The given alias 'invalid' is not part of any FROM or JOIN clause table. "
+                . 'The currently registered aliases are: news, nv.'
+        );
         self::assertEquals('', $qb->getSQL());
     }
 
-    /**
-     * @group DBAL-172
-     */
-    public function testSelectFromMasterWithWhereOnJoinedTables() : void
+    public function testSelectFromMasterWithWhereOnJoinedTables(): void
     {
         $qb = new QueryBuilder($this->conn);
 
@@ -707,13 +714,16 @@ class QueryBuilderTest extends DbalTestCase
             ->where('nt.lang = ?')
             ->andWhere('n.deleted = 0');
 
-        self::assertEquals("SELECT COUNT(DISTINCT news.id) FROM newspages news INNER JOIN nodeversion nv ON nv.refId = news.id AND nv.refEntityname='Entity\\News' INNER JOIN nodetranslation nt ON nv.nodetranslation = nt.id INNER JOIN node n ON nt.node = n.id WHERE (nt.lang = ?) AND (n.deleted = 0)", $qb->getSQL());
+        self::assertEquals(
+            'SELECT COUNT(DISTINCT news.id) FROM newspages news'
+                . " INNER JOIN nodeversion nv ON nv.refId = news.id AND nv.refEntityname='Entity\\News'"
+                . ' INNER JOIN nodetranslation nt ON nv.nodetranslation = nt.id'
+                . ' INNER JOIN node n ON nt.node = n.id WHERE (nt.lang = ?) AND (n.deleted = 0)',
+            $qb->getSQL()
+        );
     }
 
-    /**
-     * @group DBAL-442
-     */
-    public function testSelectWithMultipleFromAndJoins() : void
+    public function testSelectWithMultipleFromAndJoins(): void
     {
         $qb = new QueryBuilder($this->conn);
 
@@ -725,13 +735,16 @@ class QueryBuilderTest extends DbalTestCase
             ->where('u.id = a.user_id')
             ->andWhere('p.read = 1');
 
-        self::assertEquals('SELECT DISTINCT u.id FROM users u INNER JOIN permissions p ON p.user_id = u.id, articles a INNER JOIN comments c ON c.article_id = a.id WHERE (u.id = a.user_id) AND (p.read = 1)', $qb->getSQL());
+        self::assertEquals(
+            'SELECT DISTINCT u.id FROM users u'
+            . ' INNER JOIN permissions p ON p.user_id = u.id, articles a'
+            . ' INNER JOIN comments c ON c.article_id = a.id'
+            . ' WHERE (u.id = a.user_id) AND (p.read = 1)',
+            $qb->getSQL()
+        );
     }
 
-    /**
-     * @group DBAL-774
-     */
-    public function testSelectWithJoinsWithMultipleOnConditionsParseOrder() : void
+    public function testSelectWithJoinsWithMultipleOnConditionsParseOrder(): void
     {
         $qb = new QueryBuilder($this->conn);
 
@@ -753,10 +766,7 @@ class QueryBuilderTest extends DbalTestCase
         );
     }
 
-    /**
-     * @group DBAL-774
-     */
-    public function testSelectWithMultipleFromsAndJoinsWithMultipleOnConditionsParseOrder() : void
+    public function testSelectWithMultipleFromsAndJoinsWithMultipleOnConditionsParseOrder(): void
     {
         $qb = new QueryBuilder($this->conn);
 
@@ -782,7 +792,7 @@ class QueryBuilderTest extends DbalTestCase
         );
     }
 
-    public function testClone() : void
+    public function testClone(): void
     {
         $qb = new QueryBuilder($this->conn);
 
@@ -792,17 +802,17 @@ class QueryBuilderTest extends DbalTestCase
 
         $qb->setParameter(':test', (object) 1);
 
-        $qb_clone = clone $qb;
+        $qbClone = clone $qb;
 
-        self::assertEquals((string) $qb, (string) $qb_clone);
+        self::assertEquals((string) $qb, (string) $qbClone);
 
         $qb->andWhere('u.id = 1');
 
-        self::assertNotSame($qb->getQueryParts(), $qb_clone->getQueryParts());
-        self::assertNotSame($qb->getParameters(), $qb_clone->getParameters());
+        self::assertNotSame($qb->getQueryParts(), $qbClone->getQueryParts());
+        self::assertNotSame($qb->getParameters(), $qbClone->getParameters());
     }
 
-    public function testSimpleSelectWithoutTableAlias() : void
+    public function testSimpleSelectWithoutTableAlias(): void
     {
         $qb = new QueryBuilder($this->conn);
 
@@ -812,7 +822,7 @@ class QueryBuilderTest extends DbalTestCase
         self::assertEquals('SELECT id FROM users', (string) $qb);
     }
 
-    public function testSelectWithSimpleWhereWithoutTableAlias() : void
+    public function testSelectWithSimpleWhereWithoutTableAlias(): void
     {
         $qb = new QueryBuilder($this->conn);
 
@@ -823,7 +833,7 @@ class QueryBuilderTest extends DbalTestCase
         self::assertEquals('SELECT id, name FROM users WHERE awesome=9001', (string) $qb);
     }
 
-    public function testComplexSelectWithoutTableAliases() : void
+    public function testComplexSelectWithoutTableAliases(): void
     {
         $qb = new QueryBuilder($this->conn);
 
@@ -835,10 +845,16 @@ class QueryBuilderTest extends DbalTestCase
             ->where('users.id = articles.user_id')
             ->andWhere('p.read = 1');
 
-        self::assertEquals('SELECT DISTINCT users.id FROM users INNER JOIN permissions p ON p.user_id = users.id, articles INNER JOIN comments c ON c.article_id = articles.id WHERE (users.id = articles.user_id) AND (p.read = 1)', $qb->getSQL());
+        self::assertEquals(
+            'SELECT DISTINCT users.id FROM users'
+                . ' INNER JOIN permissions p ON p.user_id = users.id, articles'
+                . ' INNER JOIN comments c ON c.article_id = articles.id'
+                . ' WHERE (users.id = articles.user_id) AND (p.read = 1)',
+            $qb->getSQL()
+        );
     }
 
-    public function testComplexSelectWithSomeTableAliases() : void
+    public function testComplexSelectWithSomeTableAliases(): void
     {
         $qb = new QueryBuilder($this->conn);
 
@@ -848,10 +864,15 @@ class QueryBuilderTest extends DbalTestCase
             ->innerJoin('u', 'permissions', 'p', 'p.user_id = u.id')
             ->innerJoin('articles', 'comments', 'c', 'c.article_id = articles.id');
 
-        self::assertEquals('SELECT u.id FROM users u INNER JOIN permissions p ON p.user_id = u.id, articles INNER JOIN comments c ON c.article_id = articles.id', $qb->getSQL());
+        self::assertEquals(
+            'SELECT u.id FROM users u'
+                . ' INNER JOIN permissions p ON p.user_id = u.id, articles'
+                . ' INNER JOIN comments c ON c.article_id = articles.id',
+            $qb->getSQL()
+        );
     }
 
-    public function testSelectAllFromTableWithoutTableAlias() : void
+    public function testSelectAllFromTableWithoutTableAlias(): void
     {
         $qb = new QueryBuilder($this->conn);
 
@@ -861,7 +882,7 @@ class QueryBuilderTest extends DbalTestCase
         self::assertEquals('SELECT users.* FROM users', (string) $qb);
     }
 
-    public function testSelectAllWithoutTableAlias() : void
+    public function testSelectAllWithoutTableAlias(): void
     {
         $qb = new QueryBuilder($this->conn);
 
@@ -871,10 +892,7 @@ class QueryBuilderTest extends DbalTestCase
         self::assertEquals('SELECT * FROM users', (string) $qb);
     }
 
-    /**
-     * @group DBAL-959
-     */
-    public function testGetParameterType() : void
+    public function testGetParameterType(): void
     {
         $qb = new QueryBuilder($this->conn);
 
@@ -892,10 +910,7 @@ class QueryBuilderTest extends DbalTestCase
         self::assertSame(ParameterType::STRING, $qb->getParameterType('name'));
     }
 
-    /**
-     * @group DBAL-959
-     */
-    public function testGetParameterTypes() : void
+    public function testGetParameterTypes(): void
     {
         $qb = new QueryBuilder($this->conn);
 
@@ -919,10 +934,7 @@ class QueryBuilderTest extends DbalTestCase
         ], $qb->getParameterTypes());
     }
 
-    /**
-     * @group DBAL-1137
-     */
-    public function testJoinWithNonUniqueAliasThrowsException() : void
+    public function testJoinWithNonUniqueAliasThrowsException(): void
     {
         $qb = new QueryBuilder($this->conn);
 
@@ -931,8 +943,136 @@ class QueryBuilderTest extends DbalTestCase
             ->join('a', 'table_b', 'a', 'a.fk_b = a.id');
 
         $this->expectException(QueryException::class);
-        $this->expectExceptionMessage("The given alias 'a' is not unique in FROM and JOIN clause table. The currently registered aliases are: a.");
+        $this->expectExceptionMessage(
+            "The given alias 'a' is not unique in FROM and JOIN clause table. The currently registered aliases are: a."
+        );
 
         $qb->getSQL();
     }
+
+    public function testWhereExpressionAndWhereEmptyString(): void
+    {
+        $qb = new QueryBuilder($this->conn);
+
+        $qb->select('id')
+            ->from('foo')
+            ->where('a = b');
+
+        $qb->andWhere('');
+
+        self::assertSame('SELECT id FROM foo WHERE a = b', $qb->getSQL());
+    }
+
+    public function testAndWhereEmptyStringStartingWithEmptyExpression(): void
+    {
+        $qb = new QueryBuilder($this->conn);
+
+        $qb->select('id')
+            ->from('foo');
+
+        $qb->andWhere('', 'a = b');
+
+        self::assertSame('SELECT id FROM foo WHERE a = b', $qb->getSQL());
+    }
+
+    public function testAndWhereEmptyStringStartingWithNonEmptyExpression(): void
+    {
+        $qb = new QueryBuilder($this->conn);
+
+        $qb->select('id')
+            ->from('foo')
+            ->where('a = b');
+
+        $qb->andWhere('', 'c = d');
+
+        self::assertSame('SELECT id FROM foo WHERE (a = b) AND (c = d)', $qb->getSQL());
+    }
+
+    public function testWhereExpressionOrWhereEmptyString(): void
+    {
+        $qb = new QueryBuilder($this->conn);
+
+        $qb->select('id')
+            ->from('foo')
+            ->orWhere('a = b');
+
+        $qb->orWhere('');
+
+        self::assertSame('SELECT id FROM foo WHERE a = b', $qb->getSQL());
+    }
+
+    public function testOrWhereEmptyStringStartingWithEmptyExpression(): void
+    {
+        $qb = new QueryBuilder($this->conn);
+
+        $qb->select('id')
+            ->from('foo');
+
+        $qb->orWhere('', 'a = b');
+
+        self::assertSame('SELECT id FROM foo WHERE a = b', $qb->getSQL());
+    }
+
+    public function testOrWhereEmptyStringStartingWithNonEmptyExpression(): void
+    {
+        $qb = new QueryBuilder($this->conn);
+
+        $qb->select('id')
+            ->from('foo')
+            ->where('a = b');
+
+        $qb->orWhere('', 'c = d');
+
+        self::assertSame('SELECT id FROM foo WHERE (a = b) OR (c = d)', $qb->getSQL());
+    }
+
+    public function testAndHavingEmptyStringStartingWithEmptyExpression(): void
+    {
+        $qb = new QueryBuilder($this->conn);
+
+        $qb->select('id')
+            ->from('foo');
+
+        $qb->andHaving('', 'a = b');
+
+        self::assertSame('SELECT id FROM foo HAVING a = b', $qb->getSQL());
+    }
+
+    public function testAndHavingEmptyStringStartingWithNonEmptyExpression(): void
+    {
+        $qb = new QueryBuilder($this->conn);
+
+        $qb->select('id')
+            ->from('foo')
+            ->having('a = b');
+
+        $qb->andHaving('', 'c = d');
+
+        self::assertSame('SELECT id FROM foo HAVING (a = b) AND (c = d)', $qb->getSQL());
+    }
+
+    public function testOrHavingEmptyStringStartingWithEmptyExpression(): void
+    {
+        $qb = new QueryBuilder($this->conn);
+
+        $qb->select('id')
+            ->from('foo');
+
+        $qb->orHaving('', 'a = b');
+
+        self::assertSame('SELECT id FROM foo HAVING a = b', $qb->getSQL());
+    }
+
+    public function testOrHavingEmptyStringStartingWithNonEmptyExpression(): void
+    {
+        $qb = new QueryBuilder($this->conn);
+
+        $qb->select('id')
+            ->from('foo')
+            ->having('a = b');
+
+        $qb->orHaving('', 'c = d');
+
+        self::assertSame('SELECT id FROM foo HAVING (a = b) OR (c = d)', $qb->getSQL());
+    }
 }
