@@ -2,7 +2,7 @@
 
 namespace Doctrine\Tests\DBAL\Schema;
 
-use Doctrine\DBAL\DBALException;
+use Doctrine\DBAL\Exception;
 use Doctrine\DBAL\Platforms\MySqlPlatform;
 use Doctrine\DBAL\Platforms\SqlitePlatform;
 use Doctrine\DBAL\Schema\Column;
@@ -12,25 +12,26 @@ use Doctrine\DBAL\Schema\SchemaException;
 use Doctrine\DBAL\Schema\Table;
 use Doctrine\DBAL\Types\Type;
 use Doctrine\Tests\DbalTestCase;
+
 use function array_shift;
 use function current;
 
 class TableTest extends DbalTestCase
 {
-    public function testCreateWithInvalidTableName() : void
+    public function testCreateWithInvalidTableName(): void
     {
-        $this->expectException(DBALException::class);
+        $this->expectException(Exception::class);
 
         new Table('');
     }
 
-    public function testGetName() : void
+    public function testGetName(): void
     {
         $table =  new Table('foo', [], [], []);
         self::assertEquals('foo', $table->getName());
     }
 
-    public function testColumns() : void
+    public function testColumns(): void
     {
         $type      = Type::getType('integer');
         $columns   = [];
@@ -48,7 +49,7 @@ class TableTest extends DbalTestCase
         self::assertCount(2, $table->getColumns());
     }
 
-    public function testColumnsCaseInsensitive() : void
+    public function testColumnsCaseInsensitive(): void
     {
         $table  = new Table('foo');
         $column = $table->addColumn('Foo', 'integer');
@@ -62,7 +63,7 @@ class TableTest extends DbalTestCase
         self::assertSame($column, $table->getColumn('FOO'));
     }
 
-    public function testCreateColumn() : void
+    public function testCreateColumn(): void
     {
         $type = Type::getType('integer');
 
@@ -74,7 +75,7 @@ class TableTest extends DbalTestCase
         self::assertSame($type, $table->getColumn('bar')->getType());
     }
 
-    public function testDropColumn() : void
+    public function testDropColumn(): void
     {
         $type      = Type::getType('integer');
         $columns   = [];
@@ -91,7 +92,7 @@ class TableTest extends DbalTestCase
         self::assertFalse($table->hasColumn('bar'));
     }
 
-    public function testGetUnknownColumnThrowsException() : void
+    public function testGetUnknownColumnThrowsException(): void
     {
         $this->expectException(SchemaException::class);
 
@@ -99,7 +100,7 @@ class TableTest extends DbalTestCase
         $table->getColumn('unknown');
     }
 
-    public function testAddColumnTwiceThrowsException() : void
+    public function testAddColumnTwiceThrowsException(): void
     {
         $this->expectException(SchemaException::class);
 
@@ -110,7 +111,7 @@ class TableTest extends DbalTestCase
         $table     = new Table('foo', $columns, [], []);
     }
 
-    public function testCreateIndex() : void
+    public function testCreateIndex(): void
     {
         $type    = Type::getType('integer');
         $columns = [new Column('foo', $type), new Column('bar', $type), new Column('baz', $type)];
@@ -123,7 +124,7 @@ class TableTest extends DbalTestCase
         self::assertTrue($table->hasIndex('foo_bar_baz_uniq'));
     }
 
-    public function testIndexCaseInsensitive() : void
+    public function testIndexCaseInsensitive(): void
     {
         $type    = Type::getType('integer');
         $columns = [
@@ -140,7 +141,7 @@ class TableTest extends DbalTestCase
         self::assertTrue($table->hasIndex('FOO_IDX'));
     }
 
-    public function testAddIndexes() : void
+    public function testAddIndexes(): void
     {
         $type    = Type::getType('integer');
         $columns = [
@@ -162,7 +163,7 @@ class TableTest extends DbalTestCase
         self::assertInstanceOf(Index::class, $table->getIndex('bar_idx'));
     }
 
-    public function testGetUnknownIndexThrowsException() : void
+    public function testGetUnknownIndexThrowsException(): void
     {
         $this->expectException(SchemaException::class);
 
@@ -170,7 +171,7 @@ class TableTest extends DbalTestCase
         $table->getIndex('unknownIndex');
     }
 
-    public function testAddTwoPrimaryThrowsException() : void
+    public function testAddTwoPrimaryThrowsException(): void
     {
         $this->expectException(SchemaException::class);
 
@@ -183,7 +184,7 @@ class TableTest extends DbalTestCase
         $table   = new Table('foo', $columns, $indexes, []);
     }
 
-    public function testAddTwoIndexesWithSameNameThrowsException() : void
+    public function testAddTwoIndexesWithSameNameThrowsException(): void
     {
         $this->expectException(SchemaException::class);
 
@@ -196,7 +197,7 @@ class TableTest extends DbalTestCase
         $table   = new Table('foo', $columns, $indexes, []);
     }
 
-    public function testConstraints() : void
+    public function testConstraints(): void
     {
         $constraint = new ForeignKeyConstraint([], 'foo', []);
 
@@ -207,15 +208,15 @@ class TableTest extends DbalTestCase
         self::assertSame($constraint, array_shift($constraints));
     }
 
-    public function testOptions() : void
+    public function testOptions(): void
     {
-        $table = new Table('foo', [], [], [], false, ['foo' => 'bar']);
+        $table = new Table('foo', [], [], [], 0, ['foo' => 'bar']);
 
         self::assertTrue($table->hasOption('foo'));
         self::assertEquals('bar', $table->getOption('foo'));
     }
 
-    public function testBuilderSetPrimaryKey() : void
+    public function testBuilderSetPrimaryKey(): void
     {
         $table = new Table('foo');
 
@@ -228,7 +229,7 @@ class TableTest extends DbalTestCase
         self::assertTrue($table->getIndex('primary')->isPrimary());
     }
 
-    public function testBuilderAddUniqueIndex() : void
+    public function testBuilderAddUniqueIndex(): void
     {
         $table = new Table('foo');
 
@@ -240,7 +241,7 @@ class TableTest extends DbalTestCase
         self::assertFalse($table->getIndex('my_idx')->isPrimary());
     }
 
-    public function testBuilderAddIndex() : void
+    public function testBuilderAddIndex(): void
     {
         $table = new Table('foo');
 
@@ -252,7 +253,7 @@ class TableTest extends DbalTestCase
         self::assertFalse($table->getIndex('my_idx')->isPrimary());
     }
 
-    public function testBuilderAddIndexWithInvalidNameThrowsException() : void
+    public function testBuilderAddIndexWithInvalidNameThrowsException(): void
     {
         $this->expectException(SchemaException::class);
 
@@ -261,7 +262,7 @@ class TableTest extends DbalTestCase
         $table->addIndex(['bar'], 'invalid name %&/');
     }
 
-    public function testBuilderAddIndexWithUnknownColumnThrowsException() : void
+    public function testBuilderAddIndexWithUnknownColumnThrowsException(): void
     {
         $this->expectException(SchemaException::class);
 
@@ -269,7 +270,7 @@ class TableTest extends DbalTestCase
         $table->addIndex(['bar'], 'invalidName');
     }
 
-    public function testBuilderOptions() : void
+    public function testBuilderOptions(): void
     {
         $table = new Table('foo');
         $table->addOption('foo', 'bar');
@@ -277,7 +278,7 @@ class TableTest extends DbalTestCase
         self::assertEquals('bar', $table->getOption('foo'));
     }
 
-    public function testAddForeignKeyConstraintUnknownLocalColumnThrowsException() : void
+    public function testAddForeignKeyConstraintUnknownLocalColumnThrowsException(): void
     {
         $this->expectException(SchemaException::class);
 
@@ -290,7 +291,7 @@ class TableTest extends DbalTestCase
         $table->addForeignKeyConstraint($foreignTable, ['foo'], ['id']);
     }
 
-    public function testAddForeignKeyConstraintUnknownForeignColumnThrowsException() : void
+    public function testAddForeignKeyConstraintUnknownForeignColumnThrowsException(): void
     {
         $this->expectException(SchemaException::class);
 
@@ -303,7 +304,7 @@ class TableTest extends DbalTestCase
         $table->addForeignKeyConstraint($foreignTable, ['id'], ['foo']);
     }
 
-    public function testAddForeignKeyConstraint() : void
+    public function testAddForeignKeyConstraint(): void
     {
         $table = new Table('foo');
         $table->addColumn('id', 'integer');
@@ -323,7 +324,7 @@ class TableTest extends DbalTestCase
         self::assertEquals('bar', $constraint->getOption('foo'));
     }
 
-    public function testAddIndexWithCaseSensitiveColumnProblem() : void
+    public function testAddIndexWithCaseSensitiveColumnProblem(): void
     {
         $table = new Table('foo');
         $table->addColumn('id', 'integer');
@@ -335,7 +336,7 @@ class TableTest extends DbalTestCase
         self::assertTrue($table->getIndex('my_idx')->spansColumns(['id']));
     }
 
-    public function testAddPrimaryKeyColumnsAreExplicitlySetToNotNull() : void
+    public function testAddPrimaryKeyColumnsAreExplicitlySetToNotNull(): void
     {
         $table  = new Table('foo');
         $column = $table->addColumn('id', 'integer', ['notnull' => false]);
@@ -347,10 +348,7 @@ class TableTest extends DbalTestCase
         self::assertTrue($column->getNotnull());
     }
 
-    /**
-     * @group DDC-133
-     */
-    public function testAllowImplicitSchemaTableInAutogeneratedIndexNames() : void
+    public function testAllowImplicitSchemaTableInAutogeneratedIndexNames(): void
     {
         $table = new Table('foo.bar');
         $table->addColumn('baz', 'integer', []);
@@ -359,10 +357,7 @@ class TableTest extends DbalTestCase
         self::assertCount(1, $table->getIndexes());
     }
 
-    /**
-     * @group DBAL-50
-     */
-    public function testAddForeignKeyIndexImplicitly() : void
+    public function testAddForeignKeyIndexImplicitly(): void
     {
         $table = new Table('foo');
         $table->addColumn('id', 'integer');
@@ -380,10 +375,7 @@ class TableTest extends DbalTestCase
         self::assertEquals(['id'], $index->getColumns());
     }
 
-    /**
-     * @group DBAL-1063
-     */
-    public function testAddForeignKeyDoesNotCreateDuplicateIndex() : void
+    public function testAddForeignKeyDoesNotCreateDuplicateIndex(): void
     {
         $table = new Table('foo');
         $table->addColumn('bar', 'integer');
@@ -399,10 +391,7 @@ class TableTest extends DbalTestCase
         self::assertSame(['bar'], $table->getIndex('bar_idx')->getColumns());
     }
 
-    /**
-     * @group DBAL-1063
-     */
-    public function testAddForeignKeyAddsImplicitIndexIfIndexColumnsDoNotSpan() : void
+    public function testAddForeignKeyAddsImplicitIndexIfIndexColumnsDoNotSpan(): void
     {
         $table = new Table('foo');
         $table->addColumn('bar', 'integer');
@@ -426,11 +415,7 @@ class TableTest extends DbalTestCase
         self::assertSame(['bar', 'baz'], $table->getIndex('idx_8c73652176ff8caa78240498')->getColumns());
     }
 
-    /**
-     * @group DBAL-50
-     * @group DBAL-1063
-     */
-    public function testOverrulingIndexDoesNotDropOverruledIndex() : void
+    public function testOverrulingIndexDoesNotDropOverruledIndex(): void
     {
         $table = new Table('bar');
         $table->addColumn('baz', 'integer', []);
@@ -445,10 +430,7 @@ class TableTest extends DbalTestCase
         self::assertTrue($table->hasIndex($index->getName()));
     }
 
-    /**
-     * @group DBAL-1063
-     */
-    public function testAllowsAddingDuplicateIndexesBasedOnColumns() : void
+    public function testAllowsAddingDuplicateIndexesBasedOnColumns(): void
     {
         $table = new Table('foo');
         $table->addColumn('bar', 'integer');
@@ -462,10 +444,7 @@ class TableTest extends DbalTestCase
         self::assertSame(['bar'], $table->getIndex('duplicate_idx')->getColumns());
     }
 
-    /**
-     * @group DBAL-1063
-     */
-    public function testAllowsAddingFulfillingIndexesBasedOnColumns() : void
+    public function testAllowsAddingFulfillingIndexesBasedOnColumns(): void
     {
         $table = new Table('foo');
         $table->addColumn('bar', 'integer');
@@ -480,11 +459,7 @@ class TableTest extends DbalTestCase
         self::assertSame(['bar', 'baz'], $table->getIndex('fulfilling_idx')->getColumns());
     }
 
-    /**
-     * @group DBAL-50
-     * @group DBAL-1063
-     */
-    public function testPrimaryKeyOverrulingUniqueIndexDoesNotDropUniqueIndex() : void
+    public function testPrimaryKeyOverrulingUniqueIndexDoesNotDropUniqueIndex(): void
     {
         $table = new Table('bar');
         $table->addColumn('baz', 'integer', []);
@@ -493,13 +468,15 @@ class TableTest extends DbalTestCase
         $table->setPrimaryKey(['baz']);
 
         $indexes = $table->getIndexes();
-        self::assertCount(2, $indexes, 'Table should only contain both the primary key table index and the unique one, even though it was overruled.');
+
+        // Table should only contain both the primary key table index and the unique one, even though it was overruled
+        self::assertCount(2, $indexes);
 
         self::assertTrue($table->hasPrimaryKey());
         self::assertTrue($table->hasIndex('idx_unique'));
     }
 
-    public function testAddingFulfillingRegularIndexOverridesImplicitForeignKeyConstraintIndex() : void
+    public function testAddingFulfillingRegularIndexOverridesImplicitForeignKeyConstraintIndex(): void
     {
         $foreignTable = new Table('foreign');
         $foreignTable->addColumn('id', 'integer');
@@ -516,7 +493,7 @@ class TableTest extends DbalTestCase
         self::assertTrue($localTable->hasIndex('explicit_idx'));
     }
 
-    public function testAddingFulfillingUniqueIndexOverridesImplicitForeignKeyConstraintIndex() : void
+    public function testAddingFulfillingUniqueIndexOverridesImplicitForeignKeyConstraintIndex(): void
     {
         $foreignTable = new Table('foreign');
         $foreignTable->addColumn('id', 'integer');
@@ -533,7 +510,7 @@ class TableTest extends DbalTestCase
         self::assertTrue($localTable->hasIndex('explicit_idx'));
     }
 
-    public function testAddingFulfillingPrimaryKeyOverridesImplicitForeignKeyConstraintIndex() : void
+    public function testAddingFulfillingPrimaryKeyOverridesImplicitForeignKeyConstraintIndex(): void
     {
         $foreignTable = new Table('foreign');
         $foreignTable->addColumn('id', 'integer');
@@ -550,7 +527,7 @@ class TableTest extends DbalTestCase
         self::assertTrue($localTable->hasIndex('explicit_idx'));
     }
 
-    public function testAddingFulfillingExplicitIndexOverridingImplicitForeignKeyConstraintIndexWithSameNameDoesNotThrowException() : void
+    public function testAddingFulfillingExplicitIndexOverridingImplicitForeignKeyConstraintIndexWithSameName(): void
     {
         $foreignTable = new Table('foreign');
         $foreignTable->addColumn('id', 'integer');
@@ -571,10 +548,7 @@ class TableTest extends DbalTestCase
         self::assertNotSame($implicitIndex, $localTable->getIndex('IDX_8BD688E8BF396750'));
     }
 
-    /**
-     * @group DBAL-64
-     */
-    public function testQuotedTableName() : void
+    public function testQuotedTableName(): void
     {
         $table = new Table('`bar`');
 
@@ -586,10 +560,7 @@ class TableTest extends DbalTestCase
         self::assertEquals('"bar"', $table->getQuotedName($sqlitePlatform));
     }
 
-    /**
-     * @group DBAL-79
-     */
-    public function testTableHasPrimaryKey() : void
+    public function testTableHasPrimaryKey(): void
     {
         $table = new Table('test');
 
@@ -601,10 +572,7 @@ class TableTest extends DbalTestCase
         self::assertTrue($table->hasPrimaryKey());
     }
 
-    /**
-     * @group DBAL-91
-     */
-    public function testAddIndexWithQuotedColumns() : void
+    public function testAddIndexWithQuotedColumns(): void
     {
         $table = new Table('test');
         $table->addColumn('"foo"', 'integer');
@@ -614,10 +582,7 @@ class TableTest extends DbalTestCase
         self::assertTrue($table->columnsAreIndexed(['"foo"', '"bar"']));
     }
 
-    /**
-     * @group DBAL-91
-     */
-    public function testAddForeignKeyWithQuotedColumnsAndTable() : void
+    public function testAddForeignKeyWithQuotedColumnsAndTable(): void
     {
         $table = new Table('test');
         $table->addColumn('"foo"', 'integer');
@@ -627,20 +592,14 @@ class TableTest extends DbalTestCase
         self::assertCount(1, $table->getForeignKeys());
     }
 
-    /**
-     * @group DBAL-177
-     */
-    public function testQuoteSchemaPrefixed() : void
+    public function testQuoteSchemaPrefixed(): void
     {
         $table = new Table('`test`.`test`');
         self::assertEquals('test.test', $table->getName());
         self::assertEquals('`test`.`test`', $table->getQuotedName(new MySqlPlatform()));
     }
 
-    /**
-     * @group DBAL-204
-     */
-    public function testFullQualifiedTableName() : void
+    public function testFullQualifiedTableName(): void
     {
         $table = new Table('`test`.`test`');
         self::assertEquals('test.test', $table->getFullQualifiedName('test'));
@@ -651,10 +610,7 @@ class TableTest extends DbalTestCase
         self::assertEquals('other.test', $table->getFullQualifiedName('other'));
     }
 
-    /**
-     * @group DBAL-224
-     */
-    public function testDropIndex() : void
+    public function testDropIndex(): void
     {
         $table = new Table('test');
         $table->addColumn('id', 'integer');
@@ -666,10 +622,7 @@ class TableTest extends DbalTestCase
         self::assertFalse($table->hasIndex('idx'));
     }
 
-    /**
-     * @group DBAL-224
-     */
-    public function testDropPrimaryKey() : void
+    public function testDropPrimaryKey(): void
     {
         $table = new Table('test');
         $table->addColumn('id', 'integer');
@@ -681,10 +634,7 @@ class TableTest extends DbalTestCase
         self::assertFalse($table->hasPrimaryKey());
     }
 
-    /**
-     * @group DBAL-234
-     */
-    public function testRenameIndex() : void
+    public function testRenameIndex(): void
     {
         $table = new Table('test');
         $table->addColumn('id', 'integer');
@@ -753,10 +703,7 @@ class TableTest extends DbalTestCase
         self::assertTrue($table->hasIndex('UNIQ_D87F7E0C76FF8CAA78240498'));
     }
 
-    /**
-     * @group DBAL-2508
-     */
-    public function testKeepsIndexOptionsOnRenamingRegularIndex() : void
+    public function testKeepsIndexOptionsOnRenamingRegularIndex(): void
     {
         $table = new Table('foo');
         $table->addColumn('id', 'integer');
@@ -767,10 +714,7 @@ class TableTest extends DbalTestCase
         self::assertSame(['where' => '1 = 1'], $table->getIndex('idx_baz')->getOptions());
     }
 
-    /**
-     * @group DBAL-2508
-     */
-    public function testKeepsIndexOptionsOnRenamingUniqueIndex() : void
+    public function testKeepsIndexOptionsOnRenamingUniqueIndex(): void
     {
         $table = new Table('foo');
         $table->addColumn('id', 'integer');
@@ -781,10 +725,7 @@ class TableTest extends DbalTestCase
         self::assertSame(['where' => '1 = 1'], $table->getIndex('idx_baz')->getOptions());
     }
 
-    /**
-     * @group DBAL-234
-     */
-    public function testThrowsExceptionOnRenamingNonExistingIndex() : void
+    public function testThrowsExceptionOnRenamingNonExistingIndex(): void
     {
         $table = new Table('test');
         $table->addColumn('id', 'integer');
@@ -795,10 +736,7 @@ class TableTest extends DbalTestCase
         $table->renameIndex('foo', 'bar');
     }
 
-    /**
-     * @group DBAL-234
-     */
-    public function testThrowsExceptionOnRenamingToAlreadyExistingIndex() : void
+    public function testThrowsExceptionOnRenamingToAlreadyExistingIndex(): void
     {
         $table = new Table('test');
         $table->addColumn('id', 'integer');
@@ -813,9 +751,8 @@ class TableTest extends DbalTestCase
 
     /**
      * @dataProvider getNormalizesAssetNames
-     * @group DBAL-831
      */
-    public function testNormalizesColumnNames(string $assetName) : void
+    public function testNormalizesColumnNames(string $assetName): void
     {
         $table = new Table('test');
 
@@ -872,7 +809,7 @@ class TableTest extends DbalTestCase
     /**
      * @return mixed[][]
      */
-    public static function getNormalizesAssetNames() : iterable
+    public static function getNormalizesAssetNames(): iterable
     {
         return [
             ['foo'],
@@ -886,7 +823,7 @@ class TableTest extends DbalTestCase
         ];
     }
 
-    public function testTableComment() : void
+    public function testTableComment(): void
     {
         $table = new Table('bar');
         self::assertNull($table->getComment());
