@@ -4,30 +4,29 @@ namespace Doctrine\Tests\DBAL\Types;
 
 use Doctrine\DBAL\Platforms\AbstractPlatform;
 use Doctrine\DBAL\Types\DecimalType;
-use Doctrine\DBAL\Types\Type;
 use Doctrine\Tests\DbalTestCase;
 use PHPUnit\Framework\MockObject\MockObject;
 
 class DecimalTest extends DbalTestCase
 {
-    /** @var AbstractPlatform|MockObject */
+    /** @var AbstractPlatform&MockObject */
     private $platform;
 
     /** @var DecimalType */
     private $type;
 
-    protected function setUp() : void
+    protected function setUp(): void
     {
         $this->platform = $this->createMock(AbstractPlatform::class);
-        $this->type     = Type::getType('decimal');
+        $this->type     = new DecimalType();
     }
 
-    public function testDecimalConvertsToPHPValue() : void
+    public function testDecimalConvertsToPHPValue(): void
     {
         self::assertIsString($this->type->convertToPHPValue('5.5', $this->platform));
     }
 
-    public function testDecimalNullConvertsToPHPValue() : void
+    public function testDecimalNullConvertsToPHPValue(): void
     {
         self::assertNull($this->type->convertToPHPValue(null, $this->platform));
     }
