@@ -4,40 +4,39 @@ namespace Doctrine\Tests\DBAL\Types;
 
 use Doctrine\DBAL\Platforms\AbstractPlatform;
 use Doctrine\DBAL\Types\FloatType;
-use Doctrine\DBAL\Types\Type;
 use Doctrine\Tests\DbalTestCase;
 use PHPUnit\Framework\MockObject\MockObject;
 
 class FloatTest extends DbalTestCase
 {
-    /** @var AbstractPlatform|MockObject */
+    /** @var AbstractPlatform&MockObject */
     private $platform;
 
     /** @var FloatType */
     private $type;
 
-    protected function setUp() : void
+    protected function setUp(): void
     {
         $this->platform = $this->createMock(AbstractPlatform::class);
-        $this->type     = Type::getType('float');
+        $this->type     = new FloatType();
     }
 
-    public function testFloatConvertsToPHPValue() : void
+    public function testFloatConvertsToPHPValue(): void
     {
         self::assertIsFloat($this->type->convertToPHPValue('5.5', $this->platform));
     }
 
-    public function testFloatNullConvertsToPHPValue() : void
+    public function testFloatNullConvertsToPHPValue(): void
     {
         self::assertNull($this->type->convertToPHPValue(null, $this->platform));
     }
 
-    public function testFloatConvertToDatabaseValue() : void
+    public function testFloatConvertToDatabaseValue(): void
     {
         self::assertIsFloat($this->type->convertToDatabaseValue(5.5, $this->platform));
     }
 
-    public function testFloatNullConvertToDatabaseValue() : void
+    public function testFloatNullConvertToDatabaseValue(): void
     {
         self::assertNull($this->type->convertToDatabaseValue(null, $this->platform));
     }
