@@ -4,31 +4,30 @@ namespace Doctrine\Tests\DBAL\Types;
 
 use Doctrine\DBAL\Platforms\AbstractPlatform;
 use Doctrine\DBAL\Types\SmallIntType;
-use Doctrine\DBAL\Types\Type;
 use Doctrine\Tests\DbalTestCase;
 use PHPUnit\Framework\MockObject\MockObject;
 
 class SmallIntTest extends DbalTestCase
 {
-    /** @var AbstractPlatform|MockObject */
+    /** @var AbstractPlatform&MockObject */
     private $platform;
 
     /** @var SmallIntType */
     private $type;
 
-    protected function setUp() : void
+    protected function setUp(): void
     {
         $this->platform = $this->createMock(AbstractPlatform::class);
-        $this->type     = Type::getType('smallint');
+        $this->type     = new SmallIntType();
     }
 
-    public function testSmallIntConvertsToPHPValue() : void
+    public function testSmallIntConvertsToPHPValue(): void
     {
         self::assertIsInt($this->type->convertToPHPValue('1', $this->platform));
         self::assertIsInt($this->type->convertToPHPValue('0', $this->platform));
     }
 
-    public function testSmallIntNullConvertsToPHPValue() : void
+    public function testSmallIntNullConvertsToPHPValue(): void
     {
         self::assertNull($this->type->convertToPHPValue(null, $this->platform));
     }
