@@ -2,27 +2,25 @@
 
 namespace Doctrine\Tests\DBAL\Types;
 
+use DateTime;
 use Doctrine\DBAL\Types\ConversionException;
-use Doctrine\DBAL\Types\Type;
+use Doctrine\DBAL\Types\TimeType;
 
 class TimeTest extends BaseDateTypeTestCase
 {
-    /**
-     * {@inheritDoc}
-     */
-    protected function setUp() : void
+    protected function setUp(): void
     {
-        $this->type = Type::getType('time');
+        $this->type = new TimeType();
 
         parent::setUp();
     }
 
-    public function testTimeConvertsToPHPValue() : void
+    public function testTimeConvertsToPHPValue(): void
     {
-        self::assertInstanceOf('DateTime', $this->type->convertToPHPValue('5:30:55', $this->platform));
+        self::assertInstanceOf(DateTime::class, $this->type->convertToPHPValue('5:30:55', $this->platform));
     }
 
-    public function testDateFieldResetInPHPValue() : void
+    public function testDateFieldResetInPHPValue(): void
     {
         $time = $this->type->convertToPHPValue('01:23:34', $this->platform);
 
@@ -30,7 +28,7 @@ class TimeTest extends BaseDateTypeTestCase
         self::assertEquals('1970-01-01', $time->format('Y-m-d'));
     }
 
-    public function testInvalidTimeFormatConversion() : void
+    public function testInvalidTimeFormatConversion(): void
     {
         $this->expectException(ConversionException::class);
         $this->type->convertToPHPValue('abcdefg', $this->platform);
