@@ -13,22 +13,25 @@ class TypeTest extends TestCase
     /**
      * @dataProvider defaultTypesProvider()
      */
-    public function testDefaultTypesAreRegistered(string $name) : void
+    public function testDefaultTypesAreRegistered(string $name): void
     {
         self::assertTrue(Type::hasType($name));
     }
 
     /**
-     * @return string[][]
+     * @return iterable<string[]>
      */
-    public function defaultTypesProvider() : iterable
+    public function defaultTypesProvider(): iterable
     {
         foreach ((new ReflectionClass(Type::class))->getReflectionConstants() as $constant) {
             if (! $constant->isPublic()) {
                 continue;
             }
 
-            yield [$constant->getValue()];
+            $constantValue = $constant->getValue();
+            self::assertIsString($constantValue);
+
+            yield [$constantValue];
         }
     }
 }
